(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    411034,       7957]
NotebookOptionsPosition[    409285,       7892]
NotebookOutlinePosition[    409648,       7908]
CellTagsIndexPosition[    409605,       7905]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
Dynamics of the Bush-Mosteller learning algorithm in 2x2 games - Figure 2\
\>", "Title",
 CellChangeTimes->{
  3.392868462984375*^9, 3.393369208765625*^9, {3.39340978734375*^9, 
   3.39340982559375*^9}, 3.3934485475*^9, 3.393472294546875*^9, 
   3.39347263853125*^9}],

Cell["Luis R. Izquierdo and Segismundo S. Izquierdo", "Subtitle"],

Cell["\<\
This program was used to generate figure 2 in the chapter of the \
reinforcement learning book: Izquierdo,L.R. & Izquierdo,S.S.(2007). Dynamics \
of the Bush-Mosteller 
learning algorithm in 2x2 games.
The output of this program is a phase plane with several arrows representing \
the expected motion at various states of the system, and with a sample \
simulation run.\
\>", "Subsubtitle",
 CellChangeTimes->{{3.392868458*^9, 3.392868472875*^9}, {3.393369210125*^9, 
   3.39336925375*^9}, {3.393409827703125*^9, 3.39340982940625*^9}, {
   3.39344854853125*^9, 3.393448548890625*^9}, 3.3934713865625*^9, {
   3.393472295796875*^9, 3.393472297015625*^9}, {3.393472639296875*^9, 
   3.393472639640625*^9}}],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Licence", "Section"]], "Section"],

Cell["\<\
Copyright (C) 2007 Luis R. Izquierdo & Segismundo S. Izquierdo

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version. 

This program is distributed in the hope that it will be useful, 
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details. 

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, \
USA.\
\>", "Subsubtitle"]
}, Closed]],

Cell[CellGroupData[{

Cell["Setting the Environment", "Section"],

Cell[BoxData[
 RowBox[{"Off", "[", 
  RowBox[{"General", "::", "spell"}], "]"}]], "Input",
 CellChangeTimes->{{3.392687636046875*^9, 3.392687636953125*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Parameters", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "Payoffs", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"T", "=", "4"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"R", "=", "3"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"P", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"S", "=", "0"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Aspiration", " ", "Threshold"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"A", "=", "2"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Learning", " ", "rate"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"l", "=", 
     RowBox[{"1", "/", "16"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", "Noise", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"noise", "=", "0"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Distance", " ", "between", " ", "consecutive", " ", "trajectories", " ", 
     "in", " ", "the", " ", "perimeter", " ", "of", " ", "the", " ", "state", 
     " ", "space"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"step", "=", 
     RowBox[{"5", "/", "100"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Simulation", " ", "parameters"}], "*)"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"SeedRandom", "[", "3", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"nOfIterations", "=", "1000"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"initialProb1", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"initialProb2", "=", "0"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "Directory", " ", "where", " ", "the", " ", "figure", " ", "will", " ", 
     "be", " ", "saved"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"SetDirectory", "[", "\"\<C:\\\\temp\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"File", " ", "extensions", " ", "required"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"extensions", "=", 
     RowBox[{"{", "\"\<.png\>\"", "}"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"figureSize", " ", "=", " ", "600"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"textScaleFactor", "=", 
     RowBox[{"figureSize", "/", "600"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.392707136859375*^9, 3.392707138125*^9}, {
   3.392707253765625*^9, 3.39270725534375*^9}, {3.392759847390625*^9, 
   3.39275985003125*^9}, {3.39276092778125*^9, 3.392760938890625*^9}, {
   3.392763584703125*^9, 3.3927635946875*^9}, {3.39276372115625*^9, 
   3.392763728890625*^9}, {3.392763943625*^9, 3.392763943859375*^9}, 
   3.39285697478125*^9, {3.392857065765625*^9, 3.392857088984375*^9}, {
   3.39285722871875*^9, 3.392857229140625*^9}, 3.39285748475*^9, {
   3.39286376171875*^9, 3.39286376225*^9}, {3.39286848396875*^9, 
   3.39286849909375*^9}, {3.392868853015625*^9, 3.392868894921875*^9}, {
   3.393307754984375*^9, 3.393307755578125*^9}, {3.393307855421875*^9, 
   3.393307855890625*^9}, {3.393309662828125*^9, 3.393309666046875*^9}, {
   3.393367267140625*^9, 3.3933672673125*^9}, {3.3934484293125*^9, 
   3.39344843171875*^9}, {3.393448606828125*^9, 3.39344860753125*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Definition of functions and labels", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Labels", ".", " ", "This"}], " ", "is", " ", "done", " ", "for", 
    " ", "efficiency", " ", "and", " ", "code", " ", "readability"}], "*)"}], 
  "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"Cooperate", "=", "0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Defect", "=", "1"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"CC", "=", "0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"CD", "=", "1"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"DC", "=", "2"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"DD", "=", "3"}], ";"}], "\n", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Calculation", " ", "of", " ", "possible", " ", 
     RowBox[{"stimuli", ".", " ", "These"}], " ", "operations", " ", "are", 
     " ", "performed", " ", "only", " ", "once", " ", "for", " ", 
     "efficiency"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"divisor", "=", 
     RowBox[{"Max", "[", 
      RowBox[{
       RowBox[{"Abs", "[", 
        RowBox[{"T", "-", "A"}], "]"}], ",", 
       RowBox[{"Abs", "[", 
        RowBox[{"R", "-", "A"}], "]"}], ",", 
       RowBox[{"Abs", "[", 
        RowBox[{"P", "-", "A"}], "]"}], ",", 
       RowBox[{"Abs", "[", 
        RowBox[{"S", "-", "A"}], "]"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"stimulusAfterCC", " ", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"R", "-", "A"}], ")"}], "/", "divisor"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"stimulusAfterCD", " ", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"S", "-", "A"}], ")"}], "/", "divisor"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"stimulusAfterDC", " ", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"T", "-", "A"}], ")"}], "/", "divisor"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"stimulusAfterDD", " ", "=", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"P", "-", "A"}], ")"}], "/", "divisor"}]}], ";"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{"(*", 
    RowBox[{"Stimulus", " ", "after", " ", "a", " ", "certain", " ", 
     RowBox[{"outcome", ".", " ", "This"}], " ", "function", " ", "returns", 
     " ", "the", " ", "stimulus", " ", "after", " ", "a", " ", "given", " ", 
     "outcome", " ", 
     RowBox[{"(", 
      RowBox[{"e", ".", "g", ".", " ", "CD"}], ")"}], " ", "for", " ", "the", 
     " ", "agent", " ", "who", " ", "has", " ", "selected", " ", "the", " ", 
     "action", " ", "indicated", " ", "by", " ", "the", " ", "first", " ", 
     "letter", " ", "of", " ", "the", " ", "outcome", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"e", ".", "g", ".", " ", "C"}], ")"}], "."}]}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"stimulusAfter", "[", "x_", "]"}], ":=", 
     RowBox[{"Switch", "[", 
      RowBox[{
      "x", ",", "\[IndentingNewLine]", "CC", ",", "stimulusAfterCC", ",", 
       "\[IndentingNewLine]", "CD", ",", "stimulusAfterCD", ",", 
       "\[IndentingNewLine]", "DC", ",", "stimulusAfterDC", ",", 
       "\[IndentingNewLine]", "DD", ",", "stimulusAfterDD"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "Changes", " ", "in", " ", "the", " ", "probability", " ", "of", " ", 
      "cooperating", " ", "after", " ", "given", " ", 
      RowBox[{"outcomes", ".", " ", "The"}], " ", "first", " ", "argument", 
      " ", "is", " ", "the", " ", "outcome"}], ",", " ", 
     RowBox[{
     "and", " ", "the", " ", "second", " ", "argument", " ", "is", " ", "the",
       " ", "probability", " ", "to", " ", "be", " ", 
      RowBox[{"updated", ".", " ", "This"}], " ", "function", " ", "returns", 
      " ", "the", " ", "change", " ", "on", " ", "the", " ", "probability", 
      " ", "indicated", " ", "by", " ", "the", " ", "second", " ", "argument",
       " ", "after", " ", "the", " ", "outcome", " ", "indicated", " ", "in", 
      " ", "the", " ", "first", " ", "argument", " ", 
      RowBox[{"(", 
       RowBox[{"e", ".", "g", ".", " ", "CD"}], ")"}], " ", "for", " ", "the",
       " ", "agent", " ", "who", " ", "has", " ", "selected", " ", "the", " ",
       "action", " ", "indicated", " ", "by", " ", "the", " ", "first", " ", 
      "letter", " ", "of", " ", "the", " ", "outcome", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"e", ".", "g", ".", " ", "C"}], ")"}], "."}]}]}], "*)"}], 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"changeAfterOn", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], ":=", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"x", "\[Equal]", "CC"}], ")"}], "||", 
        RowBox[{"(", 
         RowBox[{"x", "\[Equal]", "CD"}], ")"}]}], ",", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{"Agent", " ", "has", " ", "cooperated"}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"stimulusAfter", "[", "x", "]"}], "\[GreaterEqual]", "0"}], 
         ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "y"}], ")"}], "*", "l", "*", 
          RowBox[{"stimulusAfter", "[", "x", "]"}]}], ",", 
         RowBox[{"y", "*", "l", "*", 
          RowBox[{"stimulusAfter", "[", "x", "]"}]}]}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{"Agent", " ", "has", " ", "defected"}], "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"stimulusAfter", "[", "x", "]"}], "\[GreaterEqual]", "0"}], 
         ",", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{"y", "*", "l", "*", 
            RowBox[{"stimulusAfter", "[", "x", "]"}]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"1", "-", "y"}], ")"}]}], "*", "l", "*", 
          RowBox[{"stimulusAfter", "[", "x", "]"}]}]}], "]"}]}], 
      "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"Expected", " ", "change", " ", "in", " ", "the", " ", 
     RowBox[{"probability", " ", "/", " ", "propensity"}], " ", "to", " ", 
     "cooperate"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"expectedChangeX", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"x", "*", 
          RowBox[{"(", 
           RowBox[{"1", "-", "noise"}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "x"}], ")"}], "*", "noise"}]}], ")"}], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"y", "*", 
          RowBox[{"(", 
           RowBox[{"1", "-", "noise"}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "y"}], ")"}], "*", "noise"}]}], ")"}], "*", 
       RowBox[{"changeAfterOn", "[", 
        RowBox[{"CC", ",", "x"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"x", "*", 
          RowBox[{"(", 
           RowBox[{"1", "-", "noise"}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "x"}], ")"}], "*", "noise"}]}], ")"}], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "y"}], ")"}], "*", 
          RowBox[{"(", 
           RowBox[{"1", "-", "noise"}], ")"}]}], "+", 
         RowBox[{"y", "*", "noise"}]}], ")"}], "*", 
       RowBox[{"changeAfterOn", "[", 
        RowBox[{"CD", ",", "x"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "x"}], ")"}], "*", 
          RowBox[{"(", 
           RowBox[{"1", "-", "noise"}], ")"}]}], "+", 
         RowBox[{"x", "*", "noise"}]}], ")"}], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"y", "*", 
          RowBox[{"(", 
           RowBox[{"1", "-", "noise"}], ")"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "y"}], ")"}], "*", "noise"}]}], ")"}], "*", 
       RowBox[{"changeAfterOn", "[", 
        RowBox[{"DC", ",", "x"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "x"}], ")"}], "*", 
          RowBox[{"(", 
           RowBox[{"1", "-", "noise"}], ")"}]}], "+", 
         RowBox[{"x", "*", "noise"}]}], ")"}], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "y"}], ")"}], "*", 
          RowBox[{"(", 
           RowBox[{"1", "-", "noise"}], ")"}]}], "+", 
         RowBox[{"y", "*", "noise"}]}], ")"}], "*", 
       RowBox[{"changeAfterOn", "[", 
        RowBox[{"DD", ",", "x"}], "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"expectedChangeY", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
     RowBox[{"expectedChangeX", "[", 
      RowBox[{"y", ",", "x"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"expChangeNorm", "[", 
      RowBox[{"x_", ",", "y_"}], "]"}], ":=", 
     RowBox[{"Norm", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"expectedChangeX", "[", 
         RowBox[{"x", ",", "y"}], "]"}], ",", 
        RowBox[{"expectedChangeY", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}], "}"}], "]"}]}], ";"}]}]}]], "Input",\

 CellChangeTimes->{{3.393407910046875*^9, 3.3934079104375*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Expected Movement Phase Plane - Initialisation", "Section"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"expectedMovementArrows", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"points", "=", 
   RowBox[{"{", "}"}]}], ";"}]}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Expected Movement Phase Plane - Creation", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"x", "=", "0"}], ",", 
    RowBox[{"x", "\[LessEqual]", 
     RowBox[{"1", "+", 
      FractionBox["step", "2"]}]}], ",", 
    RowBox[{"x", "=", 
     RowBox[{"x", "+", "step"}]}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"y", "=", "0"}], ",", 
       RowBox[{"y", "\[LessEqual]", 
        RowBox[{"1", "+", 
         FractionBox["step", "2"]}]}], ",", 
       RowBox[{"y", "=", 
        RowBox[{"y", "+", "step"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"v", "=", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"expectedChangeX", "[", 
            RowBox[{"x", ",", "y"}], "]"}], ",", 
           RowBox[{"expectedChangeY", "[", 
            RowBox[{"x", ",", "y"}], "]"}]}], "}"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Norm", "[", "v", "]"}], "\[Equal]", "0"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"AppendTo", "[", 
           RowBox[{"points", ",", 
            RowBox[{"Point", "[", 
             RowBox[{"{", 
              RowBox[{"x", ",", "y"}], "}"}], "]"}]}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"AppendTo", "[", 
            RowBox[{"expectedMovementArrows", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"Arrowheads", "[", "0.02", "]"}], ",", 
               RowBox[{"Arrow", "[", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"x", ",", "y"}], "}"}], ",", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{"x", ",", "y"}], "}"}], "+", "v"}]}], "}"}], 
                "]"}]}], "}"}]}], "]"}], ";"}]}], "\[IndentingNewLine]", 
         "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]}], 
   "\[IndentingNewLine]", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{"x", ",", "y"}], "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"expectedMovementArrowsAndPoints", "=", 
   RowBox[{"Append", "[", 
    RowBox[{"expectedMovementArrows", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"PointSize", "[", "0.008`", "]"}], ",", "points"}], "}"}]}], 
    "]"}]}], ";"}], "\n", 
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Graphics", "[", "expectedMovementArrowsAndPoints", "]"}], ",", 
   RowBox[{"AxesOrigin", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.025`"}], ",", 
      RowBox[{"-", "0.025`"}]}], "}"}]}], ",", 
   RowBox[{"Axes", "\[Rule]", "True"}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<Prob C Player1\>\"", ",", "\"\<Prob C Player2\>\""}], 
     "}"}]}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Expected Change\>\""}]}], 
  "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{
  3.392687991390625*^9, {3.39268821234375*^9, 3.392688264265625*^9}, {
   3.39268829559375*^9, 3.392688332421875*^9}, {3.39268840528125*^9, 
   3.392688428734375*^9}, 3.392688468578125*^9, {3.392688559453125*^9, 
   3.39268856296875*^9}, {3.392689613390625*^9, 3.3926896175*^9}, {
   3.39268965665625*^9, 3.392689689515625*^9}, {3.39268977840625*^9, 
   3.392689779171875*^9}, {3.392689820703125*^9, 3.3926898510625*^9}, {
   3.39269538959375*^9, 3.392695394578125*^9}, {3.39275277975*^9, 
   3.392752792140625*^9}, 3.39286967659375*^9}],

Cell[BoxData[
 GraphicsBox[{
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{0, 0}, {Rational[1, 32], Rational[1, 32]}}, {{0, 0}, {
       0.03125, 0.03125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{0, Rational[1, 20]}, {
       Rational[19, 640], Rational[999, 12800]}}, {{0, 0.05}, {0.0296875, 
       0.078046875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{0, Rational[1, 10]}, {
       Rational[9, 320], Rational[399, 3200]}}, {{0, 0.1}, {0.028125, 
       0.1246875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{0, Rational[3, 20]}, {
       Rational[17, 640], Rational[2191, 12800]}}, {{0, 0.15}, {0.0265625, 
       0.171171875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{0, Rational[1, 5]}, {
       Rational[1, 40], Rational[87, 400]}}, {{0, 0.2}, {0.025, 0.2175}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{0, Rational[1, 4]}, {
       Rational[3, 128], Rational[135, 512]}}, {{0, 0.25}, {0.0234375, 
       0.263671875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{0, Rational[3, 10]}, {
       Rational[7, 320], Rational[991, 3200]}}, {{0, 0.3}, {0.021875, 
       0.3096875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{0, Rational[7, 20]}, {
       Rational[13, 640], Rational[4551, 12800]}}, {{0, 0.35}, {0.0203125, 
       0.355546875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{0, Rational[2, 5]}, {
       Rational[3, 160], Rational[321, 800]}}, {{0, 0.4}, {0.01875, 
       0.40125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{0, Rational[9, 20]}, {
       Rational[11, 640], Rational[5719, 12800]}}, {{0, 0.45}, {0.0171875, 
       0.446796875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{0, Rational[1, 2]}, {
       Rational[1, 64], Rational[63, 128]}}, {{0, 0.5}, {0.015625, 
       0.4921875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{0, Rational[11, 20]}, {
       Rational[9, 640], Rational[6879, 12800]}}, {{0, 0.55}, {0.0140625, 
       0.537421875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{0, Rational[3, 5]}, {
       Rational[1, 80], Rational[233, 400]}}, {{0, 0.6}, {0.0125, 
       0.5825}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{0, Rational[13, 20]}, {
       Rational[7, 640], Rational[8031, 12800]}}, {{0, 0.65}, {0.0109375, 
       0.627421875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{0, Rational[7, 10]}, {
       Rational[3, 320], Rational[2151, 3200]}}, {{0, 0.7}, {0.009375, 
       0.6721875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{0, Rational[3, 4]}, {
       Rational[1, 128], Rational[367, 512]}}, {{0, 0.75}, {0.0078125, 
       0.716796875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{0, Rational[4, 5]}, {
       Rational[1, 160], Rational[609, 800]}}, {{0, 0.8}, {0.00625, 
       0.76125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{0, Rational[17, 20]}, {
       Rational[3, 640], Rational[10311, 12800]}}, {{0, 0.85}, {0.0046875, 
       0.805546875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{0, Rational[9, 10]}, {
       Rational[1, 320], Rational[2719, 3200]}}, {{0, 0.9}, {0.003125, 
       0.8496875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{0, Rational[19, 20]}, {
       Rational[1, 640], Rational[11439, 12800]}}, {{0, 0.95}, {0.0015625, 
       0.893671875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{0, 1}, {0, Rational[15, 16]}}, {{0, 1}, {
       0, 0.9375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 20], 0}, {
       Rational[999, 12800], Rational[19, 640]}}, {{0.05, 0}, {0.078046875, 
       0.0296875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 20], Rational[1, 20]}, {
       Rational[9801, 128000], Rational[9801, 128000]}}, {{0.05, 0.05}, {
      0.0765703125, 0.0765703125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 20], Rational[1, 10]}, {
       Rational[2403, 32000], Rational[1973, 16000]}}, {{0.05, 0.1}, {
      0.07509375, 0.1233125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 20], Rational[3, 20]}, {
       Rational[9423, 128000], Rational[21749, 128000]}}, {{0.05, 0.15}, {
      0.0736171875, 0.1699140625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 20], Rational[1, 5]}, {
       Rational[4617, 64000], Rational[1731, 8000]}}, {{0.05, 0.2}, {
      0.072140625, 0.216375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 20], Rational[1, 4]}, {
       Rational[1809, 25600], Rational[269, 1024]}}, {{0.05, 0.25}, {
      0.0706640625, 0.2626953125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 20], Rational[3, 10]}, {
       Rational[1107, 16000], Rational[2471, 8000]}}, {{0.05, 0.3}, {
      0.0691875, 0.308875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 20], Rational[7, 20]}, {
       Rational[8667, 128000], Rational[45429, 128000]}}, {{0.05, 0.35}, {
      0.0677109375, 0.3549140625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 20], Rational[2, 5]}, {
       Rational[4239, 64000], Rational[6413, 16000]}}, {{0.05, 0.4}, {
      0.066234375, 0.4008125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 20], Rational[9, 20]}, {
       Rational[8289, 128000], Rational[57161, 128000]}}, {{0.05, 0.45}, {
      0.0647578125, 0.4465703125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 20], Rational[1, 2]}, {
       Rational[81, 1280], Rational[63, 128]}}, {{0.05, 0.5}, {0.06328125, 
      0.4921875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 20], Rational[11, 20]}, {
       Rational[7911, 128000], Rational[68821, 128000]}}, {{0.05, 0.55}, {
      0.0618046875, 0.5376640625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 20], Rational[3, 5]}, {
       Rational[3861, 64000], Rational[583, 1000]}}, {{0.05, 0.6}, {
      0.060328125, 0.583}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 20], Rational[13, 20]}, {
       Rational[7533, 128000], Rational[80409, 128000]}}, {{0.05, 0.65}, {
      0.0588515625, 0.6281953125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 20], Rational[7, 10]}, {
       Rational[459, 8000], Rational[2693, 4000]}}, {{0.05, 0.7}, {0.057375, 
      0.67325}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 20], Rational[3, 4]}, {
       Rational[1431, 25600], Rational[3677, 5120]}}, {{0.05, 0.75}, {
      0.0558984375, 0.7181640625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 20], Rational[4, 5]}, {
       Rational[3483, 64000], Rational[12207, 16000]}}, {{0.05, 0.8}, {
      0.054421875, 0.7629375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 20], Rational[17, 20]}, {
       Rational[6777, 128000], Rational[103369, 128000]}}, {{0.05, 0.85}, {
      0.0529453125, 0.8075703125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 20], Rational[9, 10]}, {
       Rational[1647, 32000], Rational[13633, 16000]}}, {{0.05, 0.9}, {
      0.05146875, 0.8520625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 20], Rational[19, 20]}, {
       Rational[6399, 128000], Rational[114741, 128000]}}, {{0.05, 0.95}, {
      0.0499921875, 0.8964140625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 20], 1}, {
       Rational[621, 12800], Rational[301, 320]}}, {{0.05, 1}, {0.048515625, 
       0.940625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 10], 0}, {
       Rational[399, 3200], Rational[9, 320]}}, {{0.1, 0}, {0.1246875, 
       0.028125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 10], Rational[1, 20]}, {
       Rational[1973, 16000], Rational[2403, 32000]}}, {{0.1, 0.05}, {
      0.1233125, 0.07509375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 10], Rational[1, 10]}, {
       Rational[1951, 16000], Rational[1951, 16000]}}, {{0.1, 0.1}, {
      0.1219375, 0.1219375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 10], Rational[3, 20]}, {
       Rational[1929, 16000], Rational[5397, 32000]}}, {{0.1, 0.15}, {
      0.1205625, 0.16865625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 10], Rational[1, 5]}, {
       Rational[1907, 16000], Rational[861, 4000]}}, {{0.1, 0.2}, {0.1191875, 
      0.21525}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 10], Rational[1, 4]}, {
       Rational[377, 3200], Rational[67, 256]}}, {{0.1, 0.25}, {0.1178125, 
      0.26171875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 10], Rational[3, 10]}, {
       Rational[1863, 16000], Rational[4929, 16000]}}, {{0.1, 0.3}, {
      0.1164375, 0.3080625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 10], Rational[7, 20]}, {
       Rational[1841, 16000], Rational[11337, 32000]}}, {{0.1, 0.35}, {
      0.1150625, 0.35428125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 10], Rational[2, 5]}, {
       Rational[1819, 16000], Rational[3203, 8000]}}, {{0.1, 0.4}, {0.1136875,
       0.400375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 10], Rational[9, 20]}, {
       Rational[1797, 16000], Rational[14283, 32000]}}, {{0.1, 0.45}, {
      0.1123125, 0.44634375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 10], Rational[1, 2]}, {
       Rational[71, 640], Rational[63, 128]}}, {{0.1, 0.5}, {0.1109375, 
      0.4921875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 10], Rational[11, 20]}, {
       Rational[1753, 16000], Rational[17213, 32000]}}, {{0.1, 0.55}, {
      0.1095625, 0.53790625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 10], Rational[3, 5]}, {
       Rational[1731, 16000], Rational[1167, 2000]}}, {{0.1, 0.6}, {0.1081875,
       0.5835}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 10], Rational[13, 20]}, {
       Rational[1709, 16000], Rational[20127, 32000]}}, {{0.1, 0.65}, {
      0.1068125, 0.62896875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 10], Rational[7, 10]}, {
       Rational[1687, 16000], Rational[10789, 16000]}}, {{0.1, 0.7}, {
      0.1054375, 0.6743125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 10], Rational[3, 4]}, {
       Rational[333, 3200], Rational[921, 1280]}}, {{0.1, 0.75}, {0.1040625, 
      0.71953125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 10], Rational[4, 5]}, {
       Rational[1643, 16000], Rational[6117, 8000]}}, {{0.1, 0.8}, {0.1026875,
       0.764625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 10], Rational[17, 20]}, {
       Rational[1621, 16000], Rational[25907, 32000]}}, {{0.1, 0.85}, {
      0.1013125, 0.80959375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 10], Rational[9, 10]}, {
       Rational[1599, 16000], Rational[13671, 16000]}}, {{0.1, 0.9}, {
      0.0999375, 0.8544375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 10], Rational[19, 20]}, {
       Rational[1577, 16000], Rational[28773, 32000]}}, {{0.1, 0.95}, {
      0.0985625, 0.89915625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 10], 1}, {
       Rational[311, 3200], Rational[151, 160]}}, {{0.1, 1}, {0.0971875, 
       0.94375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 20], 0}, {
       Rational[2191, 12800], Rational[17, 640]}}, {{0.15, 0}, {0.171171875, 
       0.0265625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 20], Rational[1, 20]}, {
       Rational[21749, 128000], Rational[9423, 128000]}}, {{0.15, 0.05}, {
      0.1699140625, 0.0736171875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 20], Rational[1, 10]}, {
       Rational[5397, 32000], Rational[1929, 16000]}}, {{0.15, 0.1}, {
      0.16865625, 0.1205625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 20], Rational[3, 20]}, {
       Rational[21427, 128000], Rational[21427, 128000]}}, {{0.15, 0.15}, {
      0.1673984375, 0.1673984375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 20], Rational[1, 5]}, {
       Rational[10633, 64000], Rational[1713, 8000]}}, {{0.15, 0.2}, {
      0.166140625, 0.214125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 20], Rational[1, 4]}, {
       Rational[4221, 25600], Rational[267, 1024]}}, {{0.15, 0.25}, {
      0.1648828125, 0.2607421875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 20], Rational[3, 10]}, {
       Rational[1309, 8000], Rational[1229, 4000]}}, {{0.15, 0.3}, {0.163625, 
      0.30725}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[
     NCache[{{Rational[3, 20], Rational[7, 20]}, {
       Rational[20783, 128000], Rational[45267, 128000]}}, {{0.15, 0.35}, {
      0.1623671875, 0.3536484375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 20], Rational[2, 5]}, {
       Rational[10311, 64000], Rational[6399, 16000]}}, {{0.15, 0.4}, {
      0.161109375, 0.3999375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 20], Rational[9, 20]}, {
       Rational[20461, 128000], Rational[57103, 128000]}}, {{0.15, 0.45}, {
      0.1598515625, 0.4461171875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 20], Rational[1, 2]}, {
       Rational[203, 1280], Rational[63, 128]}}, {{0.15, 0.5}, {0.15859375, 
      0.4921875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 20], Rational[11, 20]}, {
       Rational[20139, 128000], Rational[68883, 128000]}}, {{0.15, 0.55}, {
      0.1573359375, 0.5381484375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 20], Rational[3, 5]}, {
       Rational[9989, 64000], Rational[73, 125]}}, {{0.15, 0.6}, {0.156078125,
       0.584}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 20], Rational[13, 20]}, {
       Rational[19817, 128000], Rational[80607, 128000]}}, {{0.15, 0.65}, {
      0.1548203125, 0.6297421875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 20], Rational[7, 10]}, {
       Rational[2457, 16000], Rational[5403, 8000]}}, {{0.15, 0.7}, {
      0.1535625, 0.675375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 20], Rational[3, 4]}, {
       Rational[3899, 25600], Rational[3691, 5120]}}, {{0.15, 0.75}, {
      0.1523046875, 0.7208984375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 20], Rational[4, 5]}, {
       Rational[9667, 64000], Rational[12261, 16000]}}, {{0.15, 0.8}, {
      0.151046875, 0.7663125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 20], Rational[17, 20]}, {
       Rational[19173, 128000], Rational[103887, 128000]}}, {{0.15, 0.85}, {
      0.1497890625, 0.8116171875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 20], Rational[9, 10]}, {
       Rational[4753, 32000], Rational[13709, 16000]}}, {{0.15, 0.9}, {
      0.14853125, 0.8568125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 20], Rational[19, 20]}, {
       Rational[18851, 128000], Rational[115443, 128000]}}, {{0.15, 0.95}, {
      0.1472734375, 0.9018984375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 20], 1}, {
       Rational[1869, 12800], Rational[303, 320]}}, {{0.15, 1}, {0.146015625, 
       0.946875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 5], 0}, {
       Rational[87, 400], Rational[1, 40]}}, {{0.2, 0}, {0.2175, 0.025}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 5], Rational[1, 20]}, {
       Rational[1731, 8000], Rational[4617, 64000]}}, {{0.2, 0.05}, {0.216375,
       0.072140625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 5], Rational[1, 10]}, {
       Rational[861, 4000], Rational[1907, 16000]}}, {{0.2, 0.1}, {0.21525, 
      0.1191875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 5], Rational[3, 20]}, {
       Rational[1713, 8000], Rational[10633, 64000]}}, {{0.2, 0.15}, {
      0.214125, 0.166140625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 5], Rational[1, 5]}, {
       Rational[213, 1000], Rational[213, 1000]}}, {{0.2, 0.2}, {0.213, 
      0.213}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 5], Rational[1, 4]}, {
       Rational[339, 1600], Rational[133, 512]}}, {{0.2, 0.25}, {0.211875, 
      0.259765625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 5], Rational[3, 10]}, {
       Rational[843, 4000], Rational[4903, 16000]}}, {{0.2, 0.3}, {0.21075, 
      0.3064375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 5], Rational[7, 20]}, {
       Rational[1677, 8000], Rational[22593, 64000]}}, {{0.2, 0.35}, {
      0.209625, 0.353015625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 5], Rational[2, 5]}, {
       Rational[417, 2000], Rational[799, 2000]}}, {{0.2, 0.4}, {0.2085, 
      0.3995}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 5], Rational[9, 20]}, {
       Rational[1659, 8000], Rational[28537, 64000]}}, {{0.2, 0.45}, {
      0.207375, 0.445890625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 5], Rational[1, 2]}, {
       Rational[33, 160], Rational[63, 128]}}, {{0.2, 0.5}, {0.20625, 
      0.4921875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 5], Rational[11, 20]}, {
       Rational[1641, 8000], Rational[34457, 64000]}}, {{0.2, 0.55}, {
      0.205125, 0.538390625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 5], Rational[3, 5]}, {
       Rational[51, 250], Rational[1169, 2000]}}, {{0.2, 0.6}, {0.204, 
      0.5845}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 5], Rational[13, 20]}, {
       Rational[1623, 8000], Rational[40353, 64000]}}, {{0.2, 0.65}, {
      0.202875, 0.630515625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 5], Rational[7, 10]}, {
       Rational[807, 4000], Rational[10823, 16000]}}, {{0.2, 0.7}, {0.20175, 
      0.6764375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 5], Rational[3, 4]}, {
       Rational[321, 1600], Rational[1849, 2560]}}, {{0.2, 0.75}, {0.200625, 
      0.722265625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 5], Rational[4, 5]}, {
       Rational[399, 2000], Rational[96, 125]}}, {{0.2, 0.8}, {0.1995, 
      0.768}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 5], Rational[17, 20]}, {
       Rational[1587, 8000], Rational[52073, 64000]}}, {{0.2, 0.85}, {
      0.198375, 0.813640625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 5], Rational[9, 10]}, {
       Rational[789, 4000], Rational[13747, 16000]}}, {{0.2, 0.9}, {0.19725, 
      0.8591875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 5], Rational[19, 20]}, {
       Rational[1569, 8000], Rational[57897, 64000]}}, {{0.2, 0.95}, {
      0.196125, 0.904640625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 5], 1}, {
       Rational[39, 200], Rational[19, 20]}}, {{0.2, 1}, {0.195, 0.95}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 4], 0}, {
       Rational[135, 512], Rational[3, 128]}}, {{0.25, 0}, {0.263671875, 
       0.0234375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 4], Rational[1, 20]}, {
       Rational[269, 1024], Rational[1809, 25600]}}, {{0.25, 0.05}, {
      0.2626953125, 0.0706640625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 4], Rational[1, 10]}, {
       Rational[67, 256], Rational[377, 3200]}}, {{0.25, 0.1}, {0.26171875, 
      0.1178125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 4], Rational[3, 20]}, {
       Rational[267, 1024], Rational[4221, 25600]}}, {{0.25, 0.15}, {
      0.2607421875, 0.1648828125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 4], Rational[1, 5]}, {
       Rational[133, 512], Rational[339, 1600]}}, {{0.25, 0.2}, {0.259765625, 
      0.211875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 4], Rational[1, 4]}, {
       Rational[265, 1024], Rational[265, 1024]}}, {{0.25, 0.25}, {
      0.2587890625, 0.2587890625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 4], Rational[3, 10]}, {
       Rational[33, 128], Rational[489, 1600]}}, {{0.25, 0.3}, {0.2578125, 
      0.305625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 4], Rational[7, 20]}, {
       Rational[263, 1024], Rational[9021, 25600]}}, {{0.25, 0.35}, {
      0.2568359375, 0.3523828125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 4], Rational[2, 5]}, {
       Rational[131, 512], Rational[1277, 3200]}}, {{0.25, 0.4}, {0.255859375,
       0.3990625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 4], Rational[9, 20]}, {
       Rational[261, 1024], Rational[11409, 25600]}}, {{0.25, 0.45}, {
      0.2548828125, 0.4456640625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 4], Rational[1, 2]}, {
       Rational[65, 256], Rational[63, 128]}}, {{0.25, 0.5}, {0.25390625, 
      0.4921875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 4], Rational[11, 20]}, {
       Rational[259, 1024], Rational[13789, 25600]}}, {{0.25, 0.55}, {
      0.2529296875, 0.5386328125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 4], Rational[3, 5]}, {
       Rational[129, 512], Rational[117, 200]}}, {{0.25, 0.6}, {0.251953125, 
      0.585}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 4], Rational[13, 20]}, {
       Rational[257, 1024], Rational[16161, 25600]}}, {{0.25, 0.65}, {
      0.2509765625, 0.6312890625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 4], Rational[7, 10]}, {
       Rational[1, 4], Rational[271, 400]}}, {{0.25, 0.7}, {0.25, 
      0.6775}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 4], Rational[3, 4]}, {
       Rational[255, 1024], Rational[741, 1024]}}, {{0.25, 0.75}, {
      0.2490234375, 0.7236328125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 4], Rational[4, 5]}, {
       Rational[127, 512], Rational[2463, 3200]}}, {{0.25, 0.8}, {0.248046875,
       0.7696875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 4], Rational[17, 20]}, {
       Rational[253, 1024], Rational[20881, 25600]}}, {{0.25, 0.85}, {
      0.2470703125, 0.8156640625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 4], Rational[9, 10]}, {
       Rational[63, 256], Rational[2757, 3200]}}, {{0.25, 0.9}, {0.24609375, 
      0.8615625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 4], Rational[19, 20]}, {
       Rational[251, 1024], Rational[23229, 25600]}}, {{0.25, 0.95}, {
      0.2451171875, 0.9073828125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 4], 1}, {
       Rational[125, 512], Rational[61, 64]}}, {{0.25, 1}, {0.244140625, 
       0.953125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 10], 0}, {
       Rational[991, 3200], Rational[7, 320]}}, {{0.3, 0}, {0.3096875, 
       0.021875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 10], Rational[1, 20]}, {
       Rational[2471, 8000], Rational[1107, 16000]}}, {{0.3, 0.05}, {0.308875,
       0.0691875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 10], Rational[1, 10]}, {
       Rational[4929, 16000], Rational[1863, 16000]}}, {{0.3, 0.1}, {
      0.3080625, 0.1164375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 10], Rational[3, 20]}, {
       Rational[1229, 4000], Rational[1309, 8000]}}, {{0.3, 0.15}, {0.30725, 
      0.163625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 10], Rational[1, 5]}, {
       Rational[4903, 16000], Rational[843, 4000]}}, {{0.3, 0.2}, {0.3064375, 
      0.21075}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 10], Rational[1, 4]}, {
       Rational[489, 1600], Rational[33, 128]}}, {{0.3, 0.25}, {0.305625, 
      0.2578125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 10], Rational[3, 10]}, {
       Rational[4877, 16000], Rational[4877, 16000]}}, {{0.3, 0.3}, {
      0.3048125, 0.3048125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 10], Rational[7, 20]}, {
       Rational[38, 125], Rational[1407, 4000]}}, {{0.3, 0.35}, {0.304, 
      0.35175}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 10], Rational[2, 5]}, {
       Rational[4851, 16000], Rational[3189, 8000]}}, {{0.3, 0.4}, {0.3031875,
       0.398625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 10], Rational[9, 20]}, {
       Rational[2419, 8000], Rational[7127, 16000]}}, {{0.3, 0.45}, {0.302375,
       0.4454375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 10], Rational[1, 2]}, {
       Rational[193, 640], Rational[63, 128]}}, {{0.3, 0.5}, {0.3015625, 
      0.4921875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 10], Rational[11, 20]}, {
       Rational[1203, 4000], Rational[4311, 8000]}}, {{0.3, 0.55}, {0.30075, 
      0.538875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 10], Rational[3, 5]}, {
       Rational[4799, 16000], Rational[1171, 2000]}}, {{0.3, 0.6}, {0.2999375,
       0.5855}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 10], Rational[13, 20]}, {
       Rational[2393, 8000], Rational[10113, 16000]}}, {{0.3, 0.65}, {
      0.299125, 0.6320625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 10], Rational[7, 10]}, {
       Rational[4773, 16000], Rational[10857, 16000]}}, {{0.3, 0.7}, {
      0.2983125, 0.6785625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 10], Rational[3, 4]}, {
       Rational[119, 400], Rational[29, 40]}}, {{0.3, 0.75}, {0.2975, 
      0.725}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 10], Rational[4, 5]}, {
       Rational[4747, 16000], Rational[6171, 8000]}}, {{0.3, 0.8}, {0.2966875,
       0.771375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 10], Rational[17, 20]}, {
       Rational[2367, 8000], Rational[13083, 16000]}}, {{0.3, 0.85}, {
      0.295875, 0.8176875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 10], Rational[9, 10]}, {
       Rational[4721, 16000], Rational[13823, 16000]}}, {{0.3, 0.9}, {
      0.2950625, 0.8639375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 10], Rational[19, 20]}, {
       Rational[1177, 4000], Rational[7281, 8000]}}, {{0.3, 0.95}, {0.29425, 
      0.910125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 10], 1}, {
       Rational[939, 3200], Rational[153, 160]}}, {{0.3, 1}, {0.2934375, 
       0.95625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 20], 0}, {
       Rational[4551, 12800], Rational[13, 640]}}, {{0.35, 0}, {0.355546875, 
       0.0203125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 20], Rational[1, 20]}, {
       Rational[45429, 128000], Rational[8667, 128000]}}, {{0.35, 0.05}, {
      0.3549140625, 0.0677109375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 20], Rational[1, 10]}, {
       Rational[11337, 32000], Rational[1841, 16000]}}, {{0.35, 0.1}, {
      0.35428125, 0.1150625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 20], Rational[3, 20]}, {
       Rational[45267, 128000], Rational[20783, 128000]}}, {{0.35, 0.15}, {
      0.3536484375, 0.1623671875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 20], Rational[1, 5]}, {
       Rational[22593, 64000], Rational[1677, 8000]}}, {{0.35, 0.2}, {
      0.353015625, 0.209625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 20], Rational[1, 4]}, {
       Rational[9021, 25600], Rational[263, 1024]}}, {{0.35, 0.25}, {
      0.3523828125, 0.2568359375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 20], Rational[3, 10]}, {
       Rational[1407, 4000], Rational[38, 125]}}, {{0.35, 0.3}, {0.35175, 
      0.304}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 20], Rational[7, 20]}, {
       Rational[44943, 128000], Rational[44943, 128000]}}, {{0.35, 0.35}, {
      0.3511171875, 0.3511171875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 20], Rational[2, 5]}, {
       Rational[22431, 64000], Rational[6371, 16000]}}, {{0.35, 0.4}, {
      0.350484375, 0.3981875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 20], Rational[9, 20]}, {
       Rational[44781, 128000], Rational[56987, 128000]}}, {{0.35, 0.45}, {
      0.3498515625, 0.4452109375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 20], Rational[1, 2]}, {
       Rational[447, 1280], Rational[63, 128]}}, {{0.35, 0.5}, {0.34921875, 
      0.4921875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 20], Rational[11, 20]}, {
       Rational[44619, 128000], Rational[69007, 128000]}}, {{0.35, 0.55}, {
      0.3485859375, 0.5391171875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 20], Rational[3, 5]}, {
       Rational[22269, 64000], Rational[293, 500]}}, {{0.35, 0.6}, {
      0.347953125, 0.586}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 20], Rational[13, 20]}, {
       Rational[44457, 128000], Rational[81003, 128000]}}, {{0.35, 0.65}, {
      0.3473203125, 0.6328359375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 20], Rational[7, 10]}, {
       Rational[5547, 16000], Rational[5437, 8000]}}, {{0.35, 0.7}, {
      0.3466875, 0.679625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 20], Rational[3, 4]}, {
       Rational[8859, 25600], Rational[3719, 5120]}}, {{0.35, 0.75}, {
      0.3460546875, 0.7263671875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 20], Rational[4, 5]}, {
       Rational[22107, 64000], Rational[12369, 16000]}}, {{0.35, 0.8}, {
      0.345421875, 0.7730625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 20], Rational[17, 20]}, {
       Rational[44133, 128000], Rational[104923, 128000]}}, {{0.35, 0.85}, {
      0.3447890625, 0.8197109375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 20], Rational[9, 10]}, {
       Rational[11013, 32000], Rational[13861, 16000]}}, {{0.35, 0.9}, {
      0.34415625, 0.8663125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 20], Rational[19, 20]}, {
       Rational[43971, 128000], Rational[116847, 128000]}}, {{0.35, 0.95}, {
      0.3435234375, 0.9128671875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 20], 1}, {
       Rational[4389, 12800], Rational[307, 320]}}, {{0.35, 1}, {0.342890625, 
       0.959375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[2, 5], 0}, {
       Rational[321, 800], Rational[3, 160]}}, {{0.4, 0}, {0.40125, 
       0.01875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[2, 5], Rational[1, 20]}, {
       Rational[6413, 16000], Rational[4239, 64000]}}, {{0.4, 0.05}, {
      0.4008125, 0.066234375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[2, 5], Rational[1, 10]}, {
       Rational[3203, 8000], Rational[1819, 16000]}}, {{0.4, 0.1}, {0.400375, 
      0.1136875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[2, 5], Rational[3, 20]}, {
       Rational[6399, 16000], Rational[10311, 64000]}}, {{0.4, 0.15}, {
      0.3999375, 0.161109375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[2, 5], Rational[1, 5]}, {
       Rational[799, 2000], Rational[417, 2000]}}, {{0.4, 0.2}, {0.3995, 
      0.2085}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[2, 5], Rational[1, 4]}, {
       Rational[1277, 3200], Rational[131, 512]}}, {{0.4, 0.25}, {0.3990625, 
      0.255859375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[2, 5], Rational[3, 10]}, {
       Rational[3189, 8000], Rational[4851, 16000]}}, {{0.4, 0.3}, {0.398625, 
      0.3031875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[2, 5], Rational[7, 20]}, {
       Rational[6371, 16000], Rational[22431, 64000]}}, {{0.4, 0.35}, {
      0.3981875, 0.350484375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[2, 5], Rational[2, 5]}, {
       Rational[1591, 4000], Rational[1591, 4000]}}, {{0.4, 0.4}, {0.39775, 
      0.39775}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[2, 5], Rational[9, 20]}, {
       Rational[6357, 16000], Rational[28479, 64000]}}, {{0.4, 0.45}, {
      0.3973125, 0.444984375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[2, 5], Rational[1, 2]}, {
       Rational[127, 320], Rational[63, 128]}}, {{0.4, 0.5}, {0.396875, 
      0.4921875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[2, 5], Rational[11, 20]}, {
       Rational[6343, 16000], Rational[34519, 64000]}}, {{0.4, 0.55}, {
      0.3964375, 0.539359375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[2, 5], Rational[3, 5]}, {
       Rational[99, 250], Rational[1173, 2000]}}, {{0.4, 0.6}, {0.396, 
      0.5865}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[2, 5], Rational[13, 20]}, {
       Rational[6329, 16000], Rational[40551, 64000]}}, {{0.4, 0.65}, {
      0.3955625, 0.633609375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[2, 5], Rational[7, 10]}, {
       Rational[3161, 8000], Rational[10891, 16000]}}, {{0.4, 0.7}, {0.395125,
       0.6806875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[2, 5], Rational[3, 4]}, {
       Rational[1263, 3200], Rational[1863, 2560]}}, {{0.4, 0.75}, {0.3946875,
       0.727734375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[
     NCache[{{Rational[2, 5], Rational[4, 5]}, {
       Rational[1577, 4000], Rational[3099, 4000]}}, {{0.4, 0.8}, {0.39425, 
      0.77475}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[2, 5], Rational[17, 20]}, {
       Rational[6301, 16000], Rational[52591, 64000]}}, {{0.4, 0.85}, {
      0.3938125, 0.821734375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[2, 5], Rational[9, 10]}, {
       Rational[3147, 8000], Rational[13899, 16000]}}, {{0.4, 0.9}, {0.393375,
       0.8686875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[2, 5], Rational[19, 20]}, {
       Rational[6287, 16000], Rational[58599, 64000]}}, {{0.4, 0.95}, {
      0.3929375, 0.915609375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[2, 5], 1}, {
       Rational[157, 400], Rational[77, 80]}}, {{0.4, 1}, {0.3925, 
       0.9625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 20], 0}, {
       Rational[5719, 12800], Rational[11, 640]}}, {{0.45, 0}, {0.446796875, 
       0.0171875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 20], Rational[1, 20]}, {
       Rational[57161, 128000], Rational[8289, 128000]}}, {{0.45, 0.05}, {
      0.4465703125, 0.0647578125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 20], Rational[1, 10]}, {
       Rational[14283, 32000], Rational[1797, 16000]}}, {{0.45, 0.1}, {
      0.44634375, 0.1123125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 20], Rational[3, 20]}, {
       Rational[57103, 128000], Rational[20461, 128000]}}, {{0.45, 0.15}, {
      0.4461171875, 0.1598515625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 20], Rational[1, 5]}, {
       Rational[28537, 64000], Rational[1659, 8000]}}, {{0.45, 0.2}, {
      0.445890625, 0.207375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 20], Rational[1, 4]}, {
       Rational[11409, 25600], Rational[261, 1024]}}, {{0.45, 0.25}, {
      0.4456640625, 0.2548828125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 20], Rational[3, 10]}, {
       Rational[7127, 16000], Rational[2419, 8000]}}, {{0.45, 0.3}, {
      0.4454375, 0.302375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 20], Rational[7, 20]}, {
       Rational[56987, 128000], Rational[44781, 128000]}}, {{0.45, 0.35}, {
      0.4452109375, 0.3498515625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 20], Rational[2, 5]}, {
       Rational[28479, 64000], Rational[6357, 16000]}}, {{0.45, 0.4}, {
      0.444984375, 0.3973125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 20], Rational[9, 20]}, {
       Rational[56929, 128000], Rational[56929, 128000]}}, {{0.45, 0.45}, {
      0.4447578125, 0.4447578125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 20], Rational[1, 2]}, {
       Rational[569, 1280], Rational[63, 128]}}, {{0.45, 0.5}, {0.44453125, 
      0.4921875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 20], Rational[11, 20]}, {
       Rational[56871, 128000], Rational[69069, 128000]}}, {{0.45, 0.55}, {
      0.4443046875, 0.5396015625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 20], Rational[3, 5]}, {
       Rational[28421, 64000], Rational[587, 1000]}}, {{0.45, 0.6}, {
      0.444078125, 0.587}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 20], Rational[13, 20]}, {
       Rational[56813, 128000], Rational[81201, 128000]}}, {{0.45, 0.65}, {
      0.4438515625, 0.6343828125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 20], Rational[7, 10]}, {
       Rational[3549, 8000], Rational[2727, 4000]}}, {{0.45, 0.7}, {0.443625, 
      0.68175}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 20], Rational[3, 4]}, {
       Rational[11351, 25600], Rational[3733, 5120]}}, {{0.45, 0.75}, {
      0.4433984375, 0.7291015625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 20], Rational[4, 5]}, {
       Rational[28363, 64000], Rational[12423, 16000]}}, {{0.45, 0.8}, {
      0.443171875, 0.7764375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 20], Rational[17, 20]}, {
       Rational[56697, 128000], Rational[105441, 128000]}}, {{0.45, 0.85}, {
      0.4429453125, 0.8237578125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 20], Rational[9, 10]}, {
       Rational[14167, 32000], Rational[13937, 16000]}}, {{0.45, 0.9}, {
      0.44271875, 0.8710625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 20], Rational[19, 20]}, {
       Rational[56639, 128000], Rational[117549, 128000]}}, {{0.45, 0.95}, {
      0.4424921875, 0.9183515625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 20], 1}, {
       Rational[5661, 12800], Rational[309, 320]}}, {{0.45, 1}, {0.442265625, 
       0.965625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 2], 0}, {
       Rational[63, 128], Rational[1, 64]}}, {{0.5, 0}, {0.4921875, 
       0.015625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 2], Rational[1, 20]}, {
       Rational[63, 128], Rational[81, 1280]}}, {{0.5, 0.05}, {0.4921875, 
      0.06328125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 2], Rational[1, 10]}, {
       Rational[63, 128], Rational[71, 640]}}, {{0.5, 0.1}, {0.4921875, 
      0.1109375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 2], Rational[3, 20]}, {
       Rational[63, 128], Rational[203, 1280]}}, {{0.5, 0.15}, {0.4921875, 
      0.15859375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 2], Rational[1, 5]}, {
       Rational[63, 128], Rational[33, 160]}}, {{0.5, 0.2}, {0.4921875, 
      0.20625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 2], Rational[1, 4]}, {
       Rational[63, 128], Rational[65, 256]}}, {{0.5, 0.25}, {0.4921875, 
      0.25390625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 2], Rational[3, 10]}, {
       Rational[63, 128], Rational[193, 640]}}, {{0.5, 0.3}, {0.4921875, 
      0.3015625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 2], Rational[7, 20]}, {
       Rational[63, 128], Rational[447, 1280]}}, {{0.5, 0.35}, {0.4921875, 
      0.34921875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 2], Rational[2, 5]}, {
       Rational[63, 128], Rational[127, 320]}}, {{0.5, 0.4}, {0.4921875, 
      0.396875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 2], Rational[9, 20]}, {
       Rational[63, 128], Rational[569, 1280]}}, {{0.5, 0.45}, {0.4921875, 
      0.44453125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 2], Rational[1, 2]}, {
       Rational[63, 128], Rational[63, 128]}}, {{0.5, 0.5}, {0.4921875, 
      0.4921875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 2], Rational[11, 20]}, {
       Rational[63, 128], Rational[691, 1280]}}, {{0.5, 0.55}, {0.4921875, 
      0.53984375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 2], Rational[3, 5]}, {
       Rational[63, 128], Rational[47, 80]}}, {{0.5, 0.6}, {0.4921875, 
      0.5875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 2], Rational[13, 20]}, {
       Rational[63, 128], Rational[813, 1280]}}, {{0.5, 0.65}, {0.4921875, 
      0.63515625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 2], Rational[7, 10]}, {
       Rational[63, 128], Rational[437, 640]}}, {{0.5, 0.7}, {0.4921875, 
      0.6828125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 2], Rational[3, 4]}, {
       Rational[63, 128], Rational[187, 256]}}, {{0.5, 0.75}, {0.4921875, 
      0.73046875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 2], Rational[4, 5]}, {
       Rational[63, 128], Rational[249, 320]}}, {{0.5, 0.8}, {0.4921875, 
      0.778125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 2], Rational[17, 20]}, {
       Rational[63, 128], Rational[1057, 1280]}}, {{0.5, 0.85}, {0.4921875, 
      0.82578125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 2], Rational[9, 10]}, {
       Rational[63, 128], Rational[559, 640]}}, {{0.5, 0.9}, {0.4921875, 
      0.8734375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 2], Rational[19, 20]}, {
       Rational[63, 128], Rational[1179, 1280]}}, {{0.5, 0.95}, {0.4921875, 
      0.92109375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[1, 2], 1}, {
       Rational[63, 128], Rational[31, 32]}}, {{0.5, 1}, {0.4921875, 
       0.96875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[11, 20], 0}, {
       Rational[6879, 12800], Rational[9, 640]}}, {{0.55, 0}, {0.537421875, 
       0.0140625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[11, 20], Rational[1, 20]}, {
       Rational[68821, 128000], Rational[7911, 128000]}}, {{0.55, 0.05}, {
      0.5376640625, 0.0618046875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[11, 20], Rational[1, 10]}, {
       Rational[17213, 32000], Rational[1753, 16000]}}, {{0.55, 0.1}, {
      0.53790625, 0.1095625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[11, 20], Rational[3, 20]}, {
       Rational[68883, 128000], Rational[20139, 128000]}}, {{0.55, 0.15}, {
      0.5381484375, 0.1573359375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[11, 20], Rational[1, 5]}, {
       Rational[34457, 64000], Rational[1641, 8000]}}, {{0.55, 0.2}, {
      0.538390625, 0.205125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[11, 20], Rational[1, 4]}, {
       Rational[13789, 25600], Rational[259, 1024]}}, {{0.55, 0.25}, {
      0.5386328125, 0.2529296875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[11, 20], Rational[3, 10]}, {
       Rational[4311, 8000], Rational[1203, 4000]}}, {{0.55, 0.3}, {0.538875, 
      0.30075}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[11, 20], Rational[7, 20]}, {
       Rational[69007, 128000], Rational[44619, 128000]}}, {{0.55, 0.35}, {
      0.5391171875, 0.3485859375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[11, 20], Rational[2, 5]}, {
       Rational[34519, 64000], Rational[6343, 16000]}}, {{0.55, 0.4}, {
      0.539359375, 0.3964375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[11, 20], Rational[9, 20]}, {
       Rational[69069, 128000], Rational[56871, 128000]}}, {{0.55, 0.45}, {
      0.5396015625, 0.4443046875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[11, 20], Rational[1, 2]}, {
       Rational[691, 1280], Rational[63, 128]}}, {{0.55, 0.5}, {0.53984375, 
      0.4921875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[11, 20], Rational[11, 20]}, {
       Rational[69131, 128000], Rational[69131, 128000]}}, {{0.55, 0.55}, {
      0.5400859375, 0.5400859375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[11, 20], Rational[3, 5]}, {
       Rational[34581, 64000], Rational[147, 250]}}, {{0.55, 0.6}, {
      0.540328125, 0.588}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[11, 20], Rational[13, 20]}, {
       Rational[69193, 128000], Rational[81399, 128000]}}, {{0.55, 0.65}, {
      0.5405703125, 0.6359296875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[11, 20], Rational[7, 10]}, {
       Rational[8653, 16000], Rational[5471, 8000]}}, {{0.55, 0.7}, {
      0.5408125, 0.683875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[11, 20], Rational[3, 4]}, {
       Rational[13851, 25600], Rational[3747, 5120]}}, {{0.55, 0.75}, {
      0.5410546875, 0.7318359375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[11, 20], Rational[4, 5]}, {
       Rational[34643, 64000], Rational[12477, 16000]}}, {{0.55, 0.8}, {
      0.541296875, 0.7798125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[11, 20], Rational[17, 20]}, {
       Rational[69317, 128000], Rational[105959, 128000]}}, {{0.55, 0.85}, {
      0.5415390625, 0.8278046875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[11, 20], Rational[9, 10]}, {
       Rational[17337, 32000], Rational[14013, 16000]}}, {{0.55, 0.9}, {
      0.54178125, 0.8758125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[11, 20], Rational[19, 20]}, {
       Rational[69379, 128000], Rational[118251, 128000]}}, {{0.55, 0.95}, {
      0.5420234375, 0.9238359375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[11, 20], 1}, {
       Rational[6941, 12800], Rational[311, 320]}}, {{0.55, 1}, {0.542265625, 
       0.971875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 5], 0}, {
       Rational[233, 400], Rational[1, 80]}}, {{0.6, 0}, {0.5825, 
       0.0125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 5], Rational[1, 20]}, {
       Rational[583, 1000], Rational[3861, 64000]}}, {{0.6, 0.05}, {0.583, 
      0.060328125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 5], Rational[1, 10]}, {
       Rational[1167, 2000], Rational[1731, 16000]}}, {{0.6, 0.1}, {0.5835, 
      0.1081875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 5], Rational[3, 20]}, {
       Rational[73, 125], Rational[9989, 64000]}}, {{0.6, 0.15}, {0.584, 
      0.156078125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 5], Rational[1, 5]}, {
       Rational[1169, 2000], Rational[51, 250]}}, {{0.6, 0.2}, {0.5845, 
      0.204}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 5], Rational[1, 4]}, {
       Rational[117, 200], Rational[129, 512]}}, {{0.6, 0.25}, {0.585, 
      0.251953125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 5], Rational[3, 10]}, {
       Rational[1171, 2000], Rational[4799, 16000]}}, {{0.6, 0.3}, {0.5855, 
      0.2999375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 5], Rational[7, 20]}, {
       Rational[293, 500], Rational[22269, 64000]}}, {{0.6, 0.35}, {0.586, 
      0.347953125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 5], Rational[2, 5]}, {
       Rational[1173, 2000], Rational[99, 250]}}, {{0.6, 0.4}, {0.5865, 
      0.396}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 5], Rational[9, 20]}, {
       Rational[587, 1000], Rational[28421, 64000]}}, {{0.6, 0.45}, {0.587, 
      0.444078125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 5], Rational[1, 2]}, {
       Rational[47, 80], Rational[63, 128]}}, {{0.6, 0.5}, {0.5875, 
      0.4921875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 5], Rational[11, 20]}, {
       Rational[147, 250], Rational[34581, 64000]}}, {{0.6, 0.55}, {0.588, 
      0.540328125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 5], Rational[3, 5]}, {
       Rational[1177, 2000], Rational[1177, 2000]}}, {{0.6, 0.6}, {0.5885, 
      0.5885}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 5], Rational[13, 20]}, {
       Rational[589, 1000], Rational[40749, 64000]}}, {{0.6, 0.65}, {0.589, 
      0.636703125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 5], Rational[7, 10]}, {
       Rational[1179, 2000], Rational[10959, 16000]}}, {{0.6, 0.7}, {0.5895, 
      0.6849375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 5], Rational[3, 4]}, {
       Rational[59, 100], Rational[1877, 2560]}}, {{0.6, 0.75}, {0.59, 
      0.733203125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 5], Rational[4, 5]}, {
       Rational[1181, 2000], Rational[1563, 2000]}}, {{0.6, 0.8}, {0.5905, 
      0.7815}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 5], Rational[17, 20]}, {
       Rational[591, 1000], Rational[53109, 64000]}}, {{0.6, 0.85}, {0.591, 
      0.829828125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 5], Rational[9, 10]}, {
       Rational[1183, 2000], Rational[14051, 16000]}}, {{0.6, 0.9}, {0.5915, 
      0.8781875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 5], Rational[19, 20]}, {
       Rational[74, 125], Rational[59301, 64000]}}, {{0.6, 0.95}, {0.592, 
      0.926578125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 5], 1}, {
       Rational[237, 400], Rational[39, 40]}}, {{0.6, 1}, {0.5925, 
       0.975}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[13, 20], 0}, {
       Rational[8031, 12800], Rational[7, 640]}}, {{0.65, 0}, {0.627421875, 
       0.0109375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[13, 20], Rational[1, 20]}, {
       Rational[80409, 128000], Rational[7533, 128000]}}, {{0.65, 0.05}, {
      0.6281953125, 0.0588515625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[13, 20], Rational[1, 10]}, {
       Rational[20127, 32000], Rational[1709, 16000]}}, {{0.65, 0.1}, {
      0.62896875, 0.1068125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[13, 20], Rational[3, 20]}, {
       Rational[80607, 128000], Rational[19817, 128000]}}, {{0.65, 0.15}, {
      0.6297421875, 0.1548203125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[13, 20], Rational[1, 5]}, {
       Rational[40353, 64000], Rational[1623, 8000]}}, {{0.65, 0.2}, {
      0.630515625, 0.202875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[13, 20], Rational[1, 4]}, {
       Rational[16161, 25600], Rational[257, 1024]}}, {{0.65, 0.25}, {
      0.6312890625, 0.2509765625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[13, 20], Rational[3, 10]}, {
       Rational[10113, 16000], Rational[2393, 8000]}}, {{0.65, 0.3}, {
      0.6320625, 0.299125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[13, 20], Rational[7, 20]}, {
       Rational[81003, 128000], Rational[44457, 128000]}}, {{0.65, 0.35}, {
      0.6328359375, 0.3473203125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[13, 20], Rational[2, 5]}, {
       Rational[40551, 64000], Rational[6329, 16000]}}, {{0.65, 0.4}, {
      0.633609375, 0.3955625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[13, 20], Rational[9, 20]}, {
       Rational[81201, 128000], Rational[56813, 128000]}}, {{0.65, 0.45}, {
      0.6343828125, 0.4438515625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[13, 20], Rational[1, 2]}, {
       Rational[813, 1280], Rational[63, 128]}}, {{0.65, 0.5}, {0.63515625, 
      0.4921875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[13, 20], Rational[11, 20]}, {
       Rational[81399, 128000], Rational[69193, 128000]}}, {{0.65, 0.55}, {
      0.6359296875, 0.5405703125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[13, 20], Rational[3, 5]}, {
       Rational[40749, 64000], Rational[589, 1000]}}, {{0.65, 0.6}, {
      0.636703125, 0.589}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[
     NCache[{{Rational[13, 20], Rational[13, 20]}, {
       Rational[81597, 128000], Rational[81597, 128000]}}, {{0.65, 0.65}, {
      0.6374765625, 0.6374765625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[13, 20], Rational[7, 10]}, {
       Rational[2553, 4000], Rational[343, 500]}}, {{0.65, 0.7}, {0.63825, 
      0.686}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[13, 20], Rational[3, 4]}, {
       Rational[16359, 25600], Rational[3761, 5120]}}, {{0.65, 0.75}, {
      0.6390234375, 0.7345703125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[13, 20], Rational[4, 5]}, {
       Rational[40947, 64000], Rational[12531, 16000]}}, {{0.65, 0.8}, {
      0.639796875, 0.7831875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[13, 20], Rational[17, 20]}, {
       Rational[81993, 128000], Rational[106477, 128000]}}, {{0.65, 0.85}, {
      0.6405703125, 0.8318515625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[13, 20], Rational[9, 10]}, {
       Rational[20523, 32000], Rational[14089, 16000]}}, {{0.65, 0.9}, {
      0.64134375, 0.8805625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[13, 20], Rational[19, 20]}, {
       Rational[82191, 128000], Rational[118953, 128000]}}, {{0.65, 0.95}, {
      0.6421171875, 0.9293203125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[13, 20], 1}, {
       Rational[8229, 12800], Rational[313, 320]}}, {{0.65, 1}, {0.642890625, 
       0.978125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 10], 0}, {
       Rational[2151, 3200], Rational[3, 320]}}, {{0.7, 0}, {0.6721875, 
       0.009375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 10], Rational[1, 20]}, {
       Rational[2693, 4000], Rational[459, 8000]}}, {{0.7, 0.05}, {0.67325, 
      0.057375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 10], Rational[1, 10]}, {
       Rational[10789, 16000], Rational[1687, 16000]}}, {{0.7, 0.1}, {
      0.6743125, 0.1054375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[
     NCache[{{Rational[7, 10], Rational[3, 20]}, {
       Rational[5403, 8000], Rational[2457, 16000]}}, {{0.7, 0.15}, {0.675375,
       0.1535625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 10], Rational[1, 5]}, {
       Rational[10823, 16000], Rational[807, 4000]}}, {{0.7, 0.2}, {0.6764375,
       0.20175}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 10], Rational[1, 4]}, {
       Rational[271, 400], Rational[1, 4]}}, {{0.7, 0.25}, {0.6775, 
      0.25}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 10], Rational[3, 10]}, {
       Rational[10857, 16000], Rational[4773, 16000]}}, {{0.7, 0.3}, {
      0.6785625, 0.2983125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 10], Rational[7, 20]}, {
       Rational[5437, 8000], Rational[5547, 16000]}}, {{0.7, 0.35}, {0.679625,
       0.3466875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 10], Rational[2, 5]}, {
       Rational[10891, 16000], Rational[3161, 8000]}}, {{0.7, 0.4}, {
      0.6806875, 0.395125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 10], Rational[9, 20]}, {
       Rational[2727, 4000], Rational[3549, 8000]}}, {{0.7, 0.45}, {0.68175, 
      0.443625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 10], Rational[1, 2]}, {
       Rational[437, 640], Rational[63, 128]}}, {{0.7, 0.5}, {0.6828125, 
      0.4921875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 10], Rational[11, 20]}, {
       Rational[5471, 8000], Rational[8653, 16000]}}, {{0.7, 0.55}, {0.683875,
       0.5408125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 10], Rational[3, 5]}, {
       Rational[10959, 16000], Rational[1179, 2000]}}, {{0.7, 0.6}, {
      0.6849375, 0.5895}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 10], Rational[13, 20]}, {
       Rational[343, 500], Rational[2553, 4000]}}, {{0.7, 0.65}, {0.686, 
      0.63825}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 10], Rational[7, 10]}, {
       Rational[10993, 16000], Rational[10993, 16000]}}, {{0.7, 0.7}, {
      0.6870625, 0.6870625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 10], Rational[3, 4]}, {
       Rational[1101, 1600], Rational[471, 640]}}, {{0.7, 0.75}, {0.688125, 
      0.7359375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 10], Rational[4, 5]}, {
       Rational[11027, 16000], Rational[6279, 8000]}}, {{0.7, 0.8}, {
      0.6891875, 0.784875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 10], Rational[17, 20]}, {
       Rational[2761, 4000], Rational[6671, 8000]}}, {{0.7, 0.85}, {0.69025, 
      0.833875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 10], Rational[9, 10]}, {
       Rational[11061, 16000], Rational[14127, 16000]}}, {{0.7, 0.9}, {
      0.6913125, 0.8829375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 10], Rational[19, 20]}, {
       Rational[5539, 8000], Rational[14913, 16000]}}, {{0.7, 0.95}, {
      0.692375, 0.9320625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[7, 10], 1}, {
       Rational[2219, 3200], Rational[157, 160]}}, {{0.7, 1}, {0.6934375, 
       0.98125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 4], 0}, {
       Rational[367, 512], Rational[1, 128]}}, {{0.75, 0}, {0.716796875, 
       0.0078125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 4], Rational[1, 20]}, {
       Rational[3677, 5120], Rational[1431, 25600]}}, {{0.75, 0.05}, {
      0.7181640625, 0.0558984375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 4], Rational[1, 10]}, {
       Rational[921, 1280], Rational[333, 3200]}}, {{0.75, 0.1}, {0.71953125, 
      0.1040625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 4], Rational[3, 20]}, {
       Rational[3691, 5120], Rational[3899, 25600]}}, {{0.75, 0.15}, {
      0.7208984375, 0.1523046875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 4], Rational[1, 5]}, {
       Rational[1849, 2560], Rational[321, 1600]}}, {{0.75, 0.2}, {
      0.722265625, 0.200625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 4], Rational[1, 4]}, {
       Rational[741, 1024], Rational[255, 1024]}}, {{0.75, 0.25}, {
      0.7236328125, 0.2490234375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 4], Rational[3, 10]}, {
       Rational[29, 40], Rational[119, 400]}}, {{0.75, 0.3}, {0.725, 
      0.2975}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 4], Rational[7, 20]}, {
       Rational[3719, 5120], Rational[8859, 25600]}}, {{0.75, 0.35}, {
      0.7263671875, 0.3460546875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 4], Rational[2, 5]}, {
       Rational[1863, 2560], Rational[1263, 3200]}}, {{0.75, 0.4}, {
      0.727734375, 0.3946875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 4], Rational[9, 20]}, {
       Rational[3733, 5120], Rational[11351, 25600]}}, {{0.75, 0.45}, {
      0.7291015625, 0.4433984375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 4], Rational[1, 2]}, {
       Rational[187, 256], Rational[63, 128]}}, {{0.75, 0.5}, {0.73046875, 
      0.4921875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 4], Rational[11, 20]}, {
       Rational[3747, 5120], Rational[13851, 25600]}}, {{0.75, 0.55}, {
      0.7318359375, 0.5410546875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 4], Rational[3, 5]}, {
       Rational[1877, 2560], Rational[59, 100]}}, {{0.75, 0.6}, {0.733203125, 
      0.59}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 4], Rational[13, 20]}, {
       Rational[3761, 5120], Rational[16359, 25600]}}, {{0.75, 0.65}, {
      0.7345703125, 0.6390234375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 4], Rational[7, 10]}, {
       Rational[471, 640], Rational[1101, 1600]}}, {{0.75, 0.7}, {0.7359375, 
      0.688125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 4], Rational[3, 4]}, {
       Rational[755, 1024], Rational[755, 1024]}}, {{0.75, 0.75}, {
      0.7373046875, 0.7373046875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 4], Rational[4, 5]}, {
       Rational[1891, 2560], Rational[2517, 3200]}}, {{0.75, 0.8}, {
      0.738671875, 0.7865625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 4], Rational[17, 20]}, {
       Rational[3789, 5120], Rational[21399, 25600]}}, {{0.75, 0.85}, {
      0.7400390625, 0.8358984375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 4], Rational[9, 10]}, {
       Rational[949, 1280], Rational[2833, 3200]}}, {{0.75, 0.9}, {0.74140625,
       0.8853125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 4], Rational[19, 20]}, {
       Rational[3803, 5120], Rational[23931, 25600]}}, {{0.75, 0.95}, {
      0.7427734375, 0.9348046875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[3, 4], 1}, {
       Rational[381, 512], Rational[63, 64]}}, {{0.75, 1}, {0.744140625, 
       0.984375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[4, 5], 0}, {
       Rational[609, 800], Rational[1, 160]}}, {{0.8, 0}, {0.76125, 
       0.00625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[4, 5], Rational[1, 20]}, {
       Rational[12207, 16000], Rational[3483, 64000]}}, {{0.8, 0.05}, {
      0.7629375, 0.054421875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[4, 5], Rational[1, 10]}, {
       Rational[6117, 8000], Rational[1643, 16000]}}, {{0.8, 0.1}, {0.764625, 
      0.1026875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[4, 5], Rational[3, 20]}, {
       Rational[12261, 16000], Rational[9667, 64000]}}, {{0.8, 0.15}, {
      0.7663125, 0.151046875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[4, 5], Rational[1, 5]}, {
       Rational[96, 125], Rational[399, 2000]}}, {{0.8, 0.2}, {0.768, 
      0.1995}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[4, 5], Rational[1, 4]}, {
       Rational[2463, 3200], Rational[127, 512]}}, {{0.8, 0.25}, {0.7696875, 
      0.248046875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[4, 5], Rational[3, 10]}, {
       Rational[6171, 8000], Rational[4747, 16000]}}, {{0.8, 0.3}, {0.771375, 
      0.2966875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[4, 5], Rational[7, 20]}, {
       Rational[12369, 16000], Rational[22107, 64000]}}, {{0.8, 0.35}, {
      0.7730625, 0.345421875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[4, 5], Rational[2, 5]}, {
       Rational[3099, 4000], Rational[1577, 4000]}}, {{0.8, 0.4}, {0.77475, 
      0.39425}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[4, 5], Rational[9, 20]}, {
       Rational[12423, 16000], Rational[28363, 64000]}}, {{0.8, 0.45}, {
      0.7764375, 0.443171875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[4, 5], Rational[1, 2]}, {
       Rational[249, 320], Rational[63, 128]}}, {{0.8, 0.5}, {0.778125, 
      0.4921875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[4, 5], Rational[11, 20]}, {
       Rational[12477, 16000], Rational[34643, 64000]}}, {{0.8, 0.55}, {
      0.7798125, 0.541296875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[4, 5], Rational[3, 5]}, {
       Rational[1563, 2000], Rational[1181, 2000]}}, {{0.8, 0.6}, {0.7815, 
      0.5905}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[4, 5], Rational[13, 20]}, {
       Rational[12531, 16000], Rational[40947, 64000]}}, {{0.8, 0.65}, {
      0.7831875, 0.639796875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[4, 5], Rational[7, 10]}, {
       Rational[6279, 8000], Rational[11027, 16000]}}, {{0.8, 0.7}, {0.784875,
       0.6891875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[4, 5], Rational[3, 4]}, {
       Rational[2517, 3200], Rational[1891, 2560]}}, {{0.8, 0.75}, {0.7865625,
       0.738671875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[4, 5], Rational[4, 5]}, {
       Rational[3153, 4000], Rational[3153, 4000]}}, {{0.8, 0.8}, {0.78825, 
      0.78825}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[4, 5], Rational[17, 20]}, {
       Rational[12639, 16000], Rational[53627, 64000]}}, {{0.8, 0.85}, {
      0.7899375, 0.837921875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[4, 5], Rational[9, 10]}, {
       Rational[6333, 8000], Rational[14203, 16000]}}, {{0.8, 0.9}, {0.791625,
       0.8876875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[4, 5], Rational[19, 20]}, {
       Rational[12693, 16000], Rational[60003, 64000]}}, {{0.8, 0.95}, {
      0.7933125, 0.937546875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[4, 5], 1}, {
       Rational[159, 200], Rational[79, 80]}}, {{0.8, 1}, {0.795, 
       0.9875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[17, 20], 0}, {
       Rational[10311, 12800], Rational[3, 640]}}, {{0.85, 0}, {0.805546875, 
       0.0046875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[17, 20], Rational[1, 20]}, {
       Rational[103369, 128000], Rational[6777, 128000]}}, {{0.85, 0.05}, {
      0.8075703125, 0.0529453125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[17, 20], Rational[1, 10]}, {
       Rational[25907, 32000], Rational[1621, 16000]}}, {{0.85, 0.1}, {
      0.80959375, 0.1013125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[17, 20], Rational[3, 20]}, {
       Rational[103887, 128000], Rational[19173, 128000]}}, {{0.85, 0.15}, {
      0.8116171875, 0.1497890625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[17, 20], Rational[1, 5]}, {
       Rational[52073, 64000], Rational[1587, 8000]}}, {{0.85, 0.2}, {
      0.813640625, 0.198375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[17, 20], Rational[1, 4]}, {
       Rational[20881, 25600], Rational[253, 1024]}}, {{0.85, 0.25}, {
      0.8156640625, 0.2470703125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[17, 20], Rational[3, 10]}, {
       Rational[13083, 16000], Rational[2367, 8000]}}, {{0.85, 0.3}, {
      0.8176875, 0.295875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[17, 20], Rational[7, 20]}, {
       Rational[104923, 128000], Rational[44133, 128000]}}, {{0.85, 0.35}, {
      0.8197109375, 0.3447890625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[17, 20], Rational[2, 5]}, {
       Rational[52591, 64000], Rational[6301, 16000]}}, {{0.85, 0.4}, {
      0.821734375, 0.3938125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[17, 20], Rational[9, 20]}, {
       Rational[105441, 128000], Rational[56697, 128000]}}, {{0.85, 0.45}, {
      0.8237578125, 0.4429453125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[17, 20], Rational[1, 2]}, {
       Rational[1057, 1280], Rational[63, 128]}}, {{0.85, 0.5}, {0.82578125, 
      0.4921875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[17, 20], Rational[11, 20]}, {
       Rational[105959, 128000], Rational[69317, 128000]}}, {{0.85, 0.55}, {
      0.8278046875, 0.5415390625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[17, 20], Rational[3, 5]}, {
       Rational[53109, 64000], Rational[591, 1000]}}, {{0.85, 0.6}, {
      0.829828125, 0.591}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[17, 20], Rational[13, 20]}, {
       Rational[106477, 128000], Rational[81993, 128000]}}, {{0.85, 0.65}, {
      0.8318515625, 0.6405703125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[17, 20], Rational[7, 10]}, {
       Rational[6671, 8000], Rational[2761, 4000]}}, {{0.85, 0.7}, {0.833875, 
      0.69025}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[17, 20], Rational[3, 4]}, {
       Rational[21399, 25600], Rational[3789, 5120]}}, {{0.85, 0.75}, {
      0.8358984375, 0.7400390625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[17, 20], Rational[4, 5]}, {
       Rational[53627, 64000], Rational[12639, 16000]}}, {{0.85, 0.8}, {
      0.837921875, 0.7899375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[17, 20], Rational[17, 20]}, {
       Rational[107513, 128000], Rational[107513, 128000]}}, {{0.85, 0.85}, {
      0.8399453125, 0.8399453125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[17, 20], Rational[9, 10]}, {
       Rational[26943, 32000], Rational[14241, 16000]}}, {{0.85, 0.9}, {
      0.84196875, 0.8900625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[17, 20], Rational[19, 20]}, {
       Rational[108031, 128000], Rational[120357, 128000]}}, {{0.85, 0.95}, {
      0.8439921875, 0.9402890625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[17, 20], 1}, {
       Rational[10829, 12800], Rational[317, 320]}}, {{0.85, 1}, {0.846015625,
        0.990625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 10], 0}, {
       Rational[2719, 3200], Rational[1, 320]}}, {{0.9, 0}, {0.8496875, 
       0.003125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 10], Rational[1, 20]}, {
       Rational[13633, 16000], Rational[1647, 32000]}}, {{0.9, 0.05}, {
      0.8520625, 0.05146875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 10], Rational[1, 10]}, {
       Rational[13671, 16000], Rational[1599, 16000]}}, {{0.9, 0.1}, {
      0.8544375, 0.0999375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 10], Rational[3, 20]}, {
       Rational[13709, 16000], Rational[4753, 32000]}}, {{0.9, 0.15}, {
      0.8568125, 0.14853125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 10], Rational[1, 5]}, {
       Rational[13747, 16000], Rational[789, 4000]}}, {{0.9, 0.2}, {0.8591875,
       0.19725}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 10], Rational[1, 4]}, {
       Rational[2757, 3200], Rational[63, 256]}}, {{0.9, 0.25}, {0.8615625, 
      0.24609375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 10], Rational[3, 10]}, {
       Rational[13823, 16000], Rational[4721, 16000]}}, {{0.9, 0.3}, {
      0.8639375, 0.2950625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 10], Rational[7, 20]}, {
       Rational[13861, 16000], Rational[11013, 32000]}}, {{0.9, 0.35}, {
      0.8663125, 0.34415625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 10], Rational[2, 5]}, {
       Rational[13899, 16000], Rational[3147, 8000]}}, {{0.9, 0.4}, {
      0.8686875, 0.393375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 10], Rational[9, 20]}, {
       Rational[13937, 16000], Rational[14167, 32000]}}, {{0.9, 0.45}, {
      0.8710625, 0.44271875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[
     NCache[{{Rational[9, 10], Rational[1, 2]}, {
       Rational[559, 640], Rational[63, 128]}}, {{0.9, 0.5}, {0.8734375, 
      0.4921875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 10], Rational[11, 20]}, {
       Rational[14013, 16000], Rational[17337, 32000]}}, {{0.9, 0.55}, {
      0.8758125, 0.54178125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 10], Rational[3, 5]}, {
       Rational[14051, 16000], Rational[1183, 2000]}}, {{0.9, 0.6}, {
      0.8781875, 0.5915}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 10], Rational[13, 20]}, {
       Rational[14089, 16000], Rational[20523, 32000]}}, {{0.9, 0.65}, {
      0.8805625, 0.64134375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 10], Rational[7, 10]}, {
       Rational[14127, 16000], Rational[11061, 16000]}}, {{0.9, 0.7}, {
      0.8829375, 0.6913125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 10], Rational[3, 4]}, {
       Rational[2833, 3200], Rational[949, 1280]}}, {{0.9, 0.75}, {0.8853125, 
      0.74140625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 10], Rational[4, 5]}, {
       Rational[14203, 16000], Rational[6333, 8000]}}, {{0.9, 0.8}, {
      0.8876875, 0.791625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 10], Rational[17, 20]}, {
       Rational[14241, 16000], Rational[26943, 32000]}}, {{0.9, 0.85}, {
      0.8900625, 0.84196875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 10], Rational[9, 10]}, {
       Rational[14279, 16000], Rational[14279, 16000]}}, {{0.9, 0.9}, {
      0.8924375, 0.8924375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 10], Rational[19, 20]}, {
       Rational[14317, 16000], Rational[30177, 32000]}}, {{0.9, 0.95}, {
      0.8948125, 0.94303125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[9, 10], 1}, {
       Rational[2871, 3200], Rational[159, 160]}}, {{0.9, 1}, {0.8971875, 
       0.99375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[19, 20], 0}, {
       Rational[11439, 12800], Rational[1, 640]}}, {{0.95, 0}, {0.893671875, 
       0.0015625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[19, 20], Rational[1, 20]}, {
       Rational[114741, 128000], Rational[6399, 128000]}}, {{0.95, 0.05}, {
      0.8964140625, 0.0499921875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[19, 20], Rational[1, 10]}, {
       Rational[28773, 32000], Rational[1577, 16000]}}, {{0.95, 0.1}, {
      0.89915625, 0.0985625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[19, 20], Rational[3, 20]}, {
       Rational[115443, 128000], Rational[18851, 128000]}}, {{0.95, 0.15}, {
      0.9018984375, 0.1472734375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[19, 20], Rational[1, 5]}, {
       Rational[57897, 64000], Rational[1569, 8000]}}, {{0.95, 0.2}, {
      0.904640625, 0.196125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[19, 20], Rational[1, 4]}, {
       Rational[23229, 25600], Rational[251, 1024]}}, {{0.95, 0.25}, {
      0.9073828125, 0.2451171875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[19, 20], Rational[3, 10]}, {
       Rational[7281, 8000], Rational[1177, 4000]}}, {{0.95, 0.3}, {0.910125, 
      0.29425}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[19, 20], Rational[7, 20]}, {
       Rational[116847, 128000], Rational[43971, 128000]}}, {{0.95, 0.35}, {
      0.9128671875, 0.3435234375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[19, 20], Rational[2, 5]}, {
       Rational[58599, 64000], Rational[6287, 16000]}}, {{0.95, 0.4}, {
      0.915609375, 0.3929375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[19, 20], Rational[9, 20]}, {
       Rational[117549, 128000], Rational[56639, 128000]}}, {{0.95, 0.45}, {
      0.9183515625, 0.4424921875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[19, 20], Rational[1, 2]}, {
       Rational[1179, 1280], Rational[63, 128]}}, {{0.95, 0.5}, {0.92109375, 
      0.4921875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[
     NCache[{{Rational[19, 20], Rational[11, 20]}, {
       Rational[118251, 128000], Rational[69379, 128000]}}, {{0.95, 0.55}, {
      0.9238359375, 0.5420234375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[19, 20], Rational[3, 5]}, {
       Rational[59301, 64000], Rational[74, 125]}}, {{0.95, 0.6}, {
      0.926578125, 0.592}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[19, 20], Rational[13, 20]}, {
       Rational[118953, 128000], Rational[82191, 128000]}}, {{0.95, 0.65}, {
      0.9293203125, 0.6421171875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[19, 20], Rational[7, 10]}, {
       Rational[14913, 16000], Rational[5539, 8000]}}, {{0.95, 0.7}, {
      0.9320625, 0.692375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[19, 20], Rational[3, 4]}, {
       Rational[23931, 25600], Rational[3803, 5120]}}, {{0.95, 0.75}, {
      0.9348046875, 0.7427734375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[19, 20], Rational[4, 5]}, {
       Rational[60003, 64000], Rational[12693, 16000]}}, {{0.95, 0.8}, {
      0.937546875, 0.7933125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[19, 20], Rational[17, 20]}, {
       Rational[120357, 128000], Rational[108031, 128000]}}, {{0.95, 0.85}, {
      0.9402890625, 0.8439921875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[19, 20], Rational[9, 10]}, {
       Rational[30177, 32000], Rational[14317, 16000]}}, {{0.95, 0.9}, {
      0.94303125, 0.8948125}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[19, 20], Rational[19, 20]}, {
       Rational[121059, 128000], Rational[121059, 128000]}}, {{0.95, 0.95}, {
      0.9457734375, 0.9457734375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{Rational[19, 20], 1}, {
       Rational[12141, 12800], Rational[319, 320]}}, {{0.95, 1}, {0.948515625,
        0.996875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{1, 0}, {Rational[15, 16], 0}}, {{1, 0}, {
       0.9375, 0}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{1, Rational[1, 20]}, {
       Rational[301, 320], Rational[621, 12800]}}, {{1, 0.05}, {0.940625, 
       0.048515625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{1, Rational[1, 10]}, {
       Rational[151, 160], Rational[311, 3200]}}, {{1, 0.1}, {0.94375, 
       0.0971875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{1, Rational[3, 20]}, {
       Rational[303, 320], Rational[1869, 12800]}}, {{1, 0.15}, {0.946875, 
       0.146015625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{1, Rational[1, 5]}, {
       Rational[19, 20], Rational[39, 200]}}, {{1, 0.2}, {0.95, 0.195}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{1, Rational[1, 4]}, {
       Rational[61, 64], Rational[125, 512]}}, {{1, 0.25}, {0.953125, 
       0.244140625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{1, Rational[3, 10]}, {
       Rational[153, 160], Rational[939, 3200]}}, {{1, 0.3}, {0.95625, 
       0.2934375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{1, Rational[7, 20]}, {
       Rational[307, 320], Rational[4389, 12800]}}, {{1, 0.35}, {0.959375, 
       0.342890625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{1, Rational[2, 5]}, {
       Rational[77, 80], Rational[157, 400]}}, {{1, 0.4}, {0.9625, 
       0.3925}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{1, Rational[9, 20]}, {
       Rational[309, 320], Rational[5661, 12800]}}, {{1, 0.45}, {0.965625, 
       0.442265625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{1, Rational[1, 2]}, {
       Rational[31, 32], Rational[63, 128]}}, {{1, 0.5}, {0.96875, 
       0.4921875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{1, Rational[11, 20]}, {
       Rational[311, 320], Rational[6941, 12800]}}, {{1, 0.55}, {0.971875, 
       0.542265625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{1, Rational[3, 5]}, {
       Rational[39, 40], Rational[237, 400]}}, {{1, 0.6}, {0.975, 
       0.5925}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{1, Rational[13, 20]}, {
       Rational[313, 320], Rational[8229, 12800]}}, {{1, 0.65}, {0.978125, 
       0.642890625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{1, Rational[7, 10]}, {
       Rational[157, 160], Rational[2219, 3200]}}, {{1, 0.7}, {0.98125, 
       0.6934375}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{1, Rational[3, 4]}, {
       Rational[63, 64], Rational[381, 512]}}, {{1, 0.75}, {0.984375, 
       0.744140625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{1, Rational[4, 5]}, {
       Rational[79, 80], Rational[159, 200]}}, {{1, 0.8}, {0.9875, 
       0.795}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{1, Rational[17, 20]}, {
       Rational[317, 320], Rational[10829, 12800]}}, {{1, 0.85}, {0.990625, 
       0.846015625}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{1, Rational[9, 10]}, {
       Rational[159, 160], Rational[2871, 3200]}}, {{1, 0.9}, {0.99375, 
       0.8971875}}]]}, 
   {Arrowheads[0.02], 
    ArrowBox[NCache[{{1, Rational[19, 20]}, {
       Rational[319, 320], Rational[12141, 12800]}}, {{1, 0.95}, {0.996875, 
       0.948515625}}]]}, 
   {PointSize[0.008], PointBox[{1, 1}]}},
  AspectRatio->Automatic,
  Axes->True,
  AxesLabel->{
    FormBox["\"Prob C Player1\"", TraditionalForm], 
    FormBox["\"Prob C Player2\"", TraditionalForm]},
  AxesOrigin->{-0.025, -0.025},
  PlotLabel->FormBox["\"Expected Change\"", TraditionalForm]]], "Output",
 CellChangeTimes->{
  3.39268776928125*^9, {3.3926879939375*^9, 3.392688048109375*^9}, 
   3.39268833396875*^9, {3.392688413046875*^9, 3.39268842940625*^9}, {
   3.392688469859375*^9, 3.39268847896875*^9}, 3.392688563609375*^9, {
   3.392689618640625*^9, 3.39268969428125*^9}, 3.3926897840625*^9, {
   3.392689827609375*^9, 3.392689847015625*^9}, {3.392695391046875*^9, 
   3.392695398859375*^9}, 3.392699693421875*^9, 3.39270144609375*^9, 
   3.392705525578125*^9, 3.392705665890625*^9, 3.39270663440625*^9, 
   3.39270714203125*^9, 3.392707211328125*^9, 3.392707260703125*^9, {
   3.392752799875*^9, 3.39275280615625*^9}, 3.39275907028125*^9, 
   3.392759141453125*^9, 3.3927591866875*^9, 3.3927592425625*^9, 
   3.392759854046875*^9, 3.39276067034375*^9, 3.392760941109375*^9, {
   3.39276137440625*^9, 3.392761390859375*^9}, 3.39276311371875*^9, 
   3.3927636099375*^9, 3.392763753703125*^9, 3.3927639528125*^9, 
   3.39276420696875*^9, 3.392764340921875*^9, 3.392764902078125*^9, 
   3.392776917953125*^9, 3.392777823953125*^9, 3.392855041671875*^9, 
   3.392855280109375*^9, 3.392855403125*^9, 3.3928554410625*^9, 
   3.39285549803125*^9, 3.3928569774375*^9, {3.39285706821875*^9, 
   3.39285709196875*^9}, 3.392859516203125*^9, 3.392859776359375*^9, 
   3.3928601668125*^9, 3.392860290421875*^9, 3.392860632015625*^9, 
   3.39286362865625*^9, 3.392863719375*^9, 3.392863766390625*^9, 
   3.392868788671875*^9, {3.39286885553125*^9, 3.392868897546875*^9}, 
   3.392869203609375*^9, 3.3928696805*^9, 3.393307712625*^9, 
   3.393307758546875*^9, 3.393307858375*^9, 3.393309669296875*^9, 
   3.39330973278125*^9, 3.393367275265625*^9, 3.3933674225625*^9, 
   3.39336834815625*^9, 3.393368397421875*^9, {3.393368471265625*^9, 
   3.393368497578125*^9}, 3.393369083859375*^9, 3.393369135078125*^9, {
   3.393369275703125*^9, 3.393369293953125*^9}, 3.393369565390625*^9, 
   3.393385191015625*^9, 3.393385254203125*^9, 3.39340792115625*^9, 
   3.39344854028125*^9, 3.393448609921875*^9, 3.39347140646875*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Simulation - Initialisation", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "Vector", " ", "with", " ", "the", " ", "decisions", " ", "made", " ", 
    "by", " ", "each", " ", "of", " ", "the", " ", "agents"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"decisions", "=", 
     RowBox[{"{", ",", "}"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"prob1", "=", "initialProb1"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"prob2", "=", "initialProb2"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"listOfProb", "=", 
     RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"numberOfDigitsOfnOfIterations", "=", 
     RowBox[{"Length", "[", 
      RowBox[{"IntegerDigits", "[", "nOfIterations", "]"}], "]"}]}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.3933673810625*^9, 3.393367382296875*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Simulation - Execution", "Section"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Draw", " ", "a", " ", "black", " ", "ball", " ", "with", " ", "number", 
    " ", "0", " ", "for", " ", "the", " ", "initial", " ", "conditions"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"AppendTo", "[", 
     RowBox[{"listOfProb", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", 
        RowBox[{"Disk", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"initialProb1", ",", "initialProb2"}], "}"}], ",", 
          "0.03`"}], "]"}]}], "}"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"AppendTo", "[", 
     RowBox[{"listOfProb", ",", 
      RowBox[{"Text", "[", 
       RowBox[{
        RowBox[{"Style", "[", 
         RowBox[{"\"\<0\>\"", ",", 
          RowBox[{"FontSize", "\[Rule]", 
           RowBox[{"16", "*", "textScaleFactor"}]}], ",", "Bold", ",", 
          RowBox[{"GrayLevel", "[", "1", "]"}], ",", 
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"initialProb1", ",", "initialProb2"}], "}"}]}], "]"}]}], 
     "]"}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"and", " ", "the", " ", "rest", " ", "of", " ", "them"}], 
     "..."}], " ", "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", " ", 
   
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "\[LessEqual]", "nOfIterations"}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"RandomReal", "[", "]"}], "\[LessEqual]", "prob1"}], ",", 
         RowBox[{
          RowBox[{
          "decisions", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
           "=", "Cooperate"}], ",", 
         RowBox[{
          RowBox[{
          "decisions", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}],
           "=", "Defect"}]}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"noise", "\[NotEqual]", "0"}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"RandomReal", "[", "]"}], "\[LessEqual]", "noise"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
              "decisions", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "\[Equal]", "Cooperate"}], ",", 
             RowBox[{
              RowBox[{
              "decisions", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "=", "Defect"}], ",", 
             RowBox[{
              RowBox[{
              "decisions", "\[LeftDoubleBracket]", "1", 
               "\[RightDoubleBracket]"}], "=", "Cooperate"}]}], "]"}]}], 
          "]"}]}], "]"}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"RandomReal", "[", "]"}], "\[LessEqual]", "prob2"}], ",", 
         RowBox[{
          RowBox[{
          "decisions", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}],
           "=", "Cooperate"}], ",", 
         RowBox[{
          RowBox[{
          "decisions", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}],
           "=", "Defect"}]}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"noise", "\[NotEqual]", "0"}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"RandomReal", "[", "]"}], "\[LessEqual]", "noise"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{
              "decisions", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "\[Equal]", "Cooperate"}], ",", 
             RowBox[{
              RowBox[{
              "decisions", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "=", "Defect"}], ",", 
             RowBox[{
              RowBox[{
              "decisions", "\[LeftDoubleBracket]", "2", 
               "\[RightDoubleBracket]"}], "=", "Cooperate"}]}], "]"}]}], 
          "]"}]}], "]"}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"outcome", "=", 
        RowBox[{"Switch", "[", 
         RowBox[{"decisions", ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"Cooperate", ",", "Cooperate"}], "}"}], ",", "CC", ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"Cooperate", ",", "Defect"}], "}"}], ",", "CD", ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"Defect", ",", "Cooperate"}], "}"}], ",", "DC", ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"Defect", ",", "Defect"}], "}"}], ",", "DD"}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"prob1", "=", 
        RowBox[{"prob1", "+", 
         RowBox[{"changeAfterOn", "[", 
          RowBox[{"outcome", ",", "prob1"}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"outcome", "=", 
        RowBox[{"Switch", "[", 
         RowBox[{"decisions", ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"Cooperate", ",", "Cooperate"}], "}"}], ",", "CC", ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"Cooperate", ",", "Defect"}], "}"}], ",", "DC", ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"Defect", ",", "Cooperate"}], "}"}], ",", "CD", ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"Defect", ",", "Defect"}], "}"}], ",", "DD"}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"prob2", "=", 
        RowBox[{"prob2", "+", 
         RowBox[{"changeAfterOn", "[", 
          RowBox[{"outcome", ",", "prob2"}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"numberOfDigits", "=", 
        RowBox[{"Length", "[", 
         RowBox[{"IntegerDigits", "[", "i", "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Mod", "[", 
           RowBox[{"i", ",", 
            RowBox[{"10", "^", 
             RowBox[{"(", 
              RowBox[{"numberOfDigits", "-", "1"}], ")"}]}]}], "]"}], 
          "\[Equal]", "0"}], ",", "\[IndentingNewLine]", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{
           "This", " ", "condition", " ", "selects", " ", "the", " ", 
            RowBox[{"numbers", ":", " ", "1"}]}], ",", "2", ",", "3", ",", "...",
            ",", "9", ",", "10", ",", "20", ",", "30", ",", "...", ",", "90", 
           ",", "100", ",", "200", ",", "300", ",", "...", ",", "900", ",", 
           "1000"}], "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{"(*", 
          RowBox[{"Draw", " ", "a", " ", "disk"}], "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"AppendTo", "[", 
           RowBox[{"listOfProb", ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"GrayLevel", "[", 
               RowBox[{"0.3", "+", 
                RowBox[{"0.7", 
                 
                 FractionBox["numberOfDigits", 
                  "numberOfDigitsOfnOfIterations"]}]}], "]"}], ",", 
              RowBox[{"EdgeForm", "[", "Thick", "]"}], ",", 
              RowBox[{"Disk", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"prob1", ",", "prob2"}], "}"}], ",", "0.03`"}], 
               "]"}]}], "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
          "\[IndentingNewLine]", 
          RowBox[{"(*", 
           RowBox[{
            RowBox[{
             RowBox[{"Don", "'"}], "t", " ", "write", " ", "1000", " ", 
             RowBox[{"(", 
              RowBox[{"4", " ", "digits"}], ")"}]}], ",", " ", 
            RowBox[{"write", " ", 
             SuperscriptBox["10", "3"], " ", 
             RowBox[{"instead", "."}]}]}], "*)"}], "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"numberOfDigits", "\[NotEqual]", "4"}], ",", 
            "\[IndentingNewLine]", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"AppendTo", "[", 
              RowBox[{"listOfProb", ",", 
               RowBox[{"Text", "[", 
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{"i", ",", 
                   RowBox[{"FontSize", "\[Rule]", 
                    RowBox[{"16", "*", "textScaleFactor"}]}], ",", "Bold", 
                   ",", 
                   RowBox[{"GrayLevel", "[", "0", "]"}], ",", 
                   RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}]}], 
                  "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"prob1", ",", "prob2"}], "}"}]}], "]"}]}], "]"}], 
             ";"}], "\[IndentingNewLine]", ",", "\[IndentingNewLine]", 
            "\[IndentingNewLine]", 
            RowBox[{"(*", 
             RowBox[{"Write", " ", 
              SuperscriptBox["10", "3"], " ", "instead", " ", "of", " ", 
              "1000"}], "*)"}], "\[IndentingNewLine]", 
            RowBox[{"AppendTo", "[", 
             RowBox[{"listOfProb", ",", 
              RowBox[{"Text", "[", 
               RowBox[{
                RowBox[{"Style", "[", 
                 RowBox[{
                  RowBox[{"Superscript", "[", 
                   RowBox[{"10", ",", "3"}], "]"}], ",", 
                  RowBox[{"FontSize", "\[Rule]", 
                   RowBox[{"16", "*", "textScaleFactor"}]}], ",", "Bold", ",",
                   
                  RowBox[{"GrayLevel", "[", "0", "]"}], ",", 
                  RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}]}], "]"}],
                 ",", 
                RowBox[{"{", 
                 RowBox[{"prob1", ",", "prob2"}], "}"}]}], "]"}]}], "]"}]}], 
           "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}], ";"}]}], 
        "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}], ";"}]}], 
     "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", " ", 
   RowBox[{"Show", "[", 
    RowBox[{
     RowBox[{"Graphics", "[", "listOfProb", "]"}], ",", 
     RowBox[{"AxesOrigin", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.025`"}], ",", 
        RowBox[{"-", "0.025`"}]}], "}"}]}], ",", 
     RowBox[{"Axes", "\[Rule]", "True"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<Prob C Player1\>\"", ",", "\"\<Prob C Player2\>\""}], 
       "}"}]}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<Simulation\>\""}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.14`"}], ",", "1.03`"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.14`"}], ",", "1.03`"}], "}"}]}], "}"}]}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.392695450328125*^9, 3.39269549834375*^9}, {
   3.392699619484375*^9, 3.3926996861875*^9}, {3.392699869109375*^9, 
   3.39269990209375*^9}, {3.39270000284375*^9, 3.392700071828125*^9}, {
   3.3927007693125*^9, 3.39270080375*^9}, {3.392760662953125*^9, 
   3.39276066584375*^9}, {3.392761387453125*^9, 3.39276138765625*^9}, {
   3.39276356509375*^9, 3.39276357759375*^9}, {3.392763923390625*^9, 
   3.392763938046875*^9}, {3.3927640758125*^9, 3.392764079265625*^9}, {
   3.392854925171875*^9, 3.39285493121875*^9}, {3.392855176609375*^9, 
   3.392855266078125*^9}, {3.392855380140625*^9, 3.392855400234375*^9}, {
   3.392855432609375*^9, 3.392855435015625*^9}, 3.39285548728125*^9, 
   3.39285938725*^9, 3.392859434765625*^9, {3.39285948865625*^9, 
   3.392859511078125*^9}, {3.392859544734375*^9, 3.392859545640625*^9}, {
   3.3928597296875*^9, 3.392859736765625*^9}, {3.392859832265625*^9, 
   3.39285983296875*^9}, {3.392863590875*^9, 3.392863611140625*^9}, {
   3.392863707546875*^9, 3.39286371375*^9}, {3.392863900625*^9, 
   3.39286390715625*^9}, {3.39287005259375*^9, 3.392870054109375*^9}, 
   3.393367418765625*^9, {3.39344844984375*^9, 3.393448459890625*^9}}],

Cell[BoxData[
 GraphicsBox[{
   {EdgeForm[Thickness[Large]], DiskBox[{1, 0}, 0.03]}, InsetBox[
    StyleBox["\<\"0\"\>",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[1],
     BackFaceColor->GrayLevel[1],
     GraphicsColor->GrayLevel[1],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[1]], {1, 0}], 
   {GrayLevel[0.475], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{Rational[15, 16], 0}, {0.9375, 0}], 0.03]}, InsetBox[
    StyleBox["1",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], NCache[{Rational[15, 16], 0}, {0.9375, 0}]], 
   {GrayLevel[0.475], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{Rational[225, 256], 0}, {0.87890625, 0}], 0.03]}, 
   InsetBox[
    StyleBox["2",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[225, 256], 0}, {0.87890625, 0}]], 
   {GrayLevel[0.475], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{Rational[3375, 4096], 0}, {0.823974609375, 0}], 0.03]}, 
   InsetBox[
    StyleBox["3",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[3375, 4096], 0}, {0.823974609375, 0}]], 
   {GrayLevel[0.475], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{Rational[50625, 65536], 0}, {0.7724761962890625, 0}], 
     0.03]}, InsetBox[
    StyleBox["4",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[50625, 65536], 0}, {0.7724761962890625, 0}]], 
   {GrayLevel[0.475], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{Rational[759375, 1048576], 0}, {0.7241964340209961, 0}], 
     0.03]}, InsetBox[
    StyleBox["5",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[759375, 1048576], 0}, {0.7241964340209961, 0}]], 
   {GrayLevel[0.475], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{Rational[24589201, 33554432], Rational[1, 32]}, {
      0.73281529545784, 0.03125}], 0.03]}, InsetBox[
    StyleBox["6",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[24589201, 33554432], Rational[1, 32]}, {0.73281529545784,
      0.03125}]], 
   {GrayLevel[0.475], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{Rational[368838015, 536870912], Rational[15, 512]}, {
      0.687014339491725, 0.029296875}], 0.03]}, InsetBox[
    StyleBox["7",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[368838015, 536870912], Rational[15, 512]}, {
     0.687014339491725, 0.029296875}]], 
   {GrayLevel[0.475], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[11970849377, 17179869184], Rational[977, 16384]}, {
      0.6967951413826086, 0.05963134765625}], 0.03]}, InsetBox[
    StyleBox["8",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[11970849377, 17179869184], Rational[977, 16384]}, {
     0.6967951413826086, 0.05963134765625}]], 
   {GrayLevel[0.475], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[179562740655, 274877906944], Rational[14655, 262144]}, {
      0.6532454450461955, 0.055904388427734375`}], 0.03]}, InsetBox[
    StyleBox["9",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[179562740655, 274877906944], Rational[14655, 262144]}, {
     0.6532454450461955, 0.055904388427734375`}]], 
   {GrayLevel[0.6499999999999999], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[2693441109825, 4398046511104], Rational[219825, 4194304]}, {
      0.6124176047308083, 0.05241036415100098}], 0.03]}, InsetBox[
    StyleBox["10",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[2693441109825, 4398046511104], Rational[
      219825, 4194304]}, {0.6124176047308083, 0.05241036415100098}]], 
   {GrayLevel[0.6499999999999999], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[36296860316093948863233377, 77371252455336267181195264], 
       Rational[9906798371695584977, 73786976294838206464]}, {
      0.46912592421903554`, 0.13426215396210264`}], 0.03]}, InsetBox[
    StyleBox["20",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[36296860316093948863233377, 77371252455336267181195264], 
      Rational[9906798371695584977, 73786976294838206464]}, {
     0.46912592421903554`, 0.13426215396210264`}]], 
   {GrayLevel[0.6499999999999999], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[502406936434574644152549838973385981825, 
        1361129467683753853853498429727072845824], Rational[
       219211090745847933011085842691825, 
        1298074214633706907132624082305024]}, {0.3691103222454841, 
      0.1688740815236865}], 0.03]}, InsetBox[
    StyleBox["30",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[
      502406936434574644152549838973385981825, 
       1361129467683753853853498429727072845824], Rational[
      219211090745847933011085842691825, 
       1298074214633706907132624082305024]}, {0.3691103222454841, 
     0.1688740815236865}]], 
   {GrayLevel[0.6499999999999999], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[80655497056306102443101282267760360493137353696139121, 
        191561942608236107294793378393788647952342390272950272], Rational[
       52784046175308079793450928125525952329509885921, 
        182687704666362864775460604089535377456991567872]}, {
      0.42104134024812484`, 0.28893047986839626`}], 0.03]}, InsetBox[
    StyleBox["40",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{
     Rational[80655497056306102443101282267760360493137353696139121, 
       191561942608236107294793378393788647952342390272950272], Rational[
      52784046175308079793450928125525952329509885921, 
       182687704666362864775460604089535377456991567872]}, {
     0.42104134024812484`, 0.28893047986839626`}]], 
   {GrayLevel[0.6499999999999999], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[562573024131032168085716116159465739844023314395578297958218759\
9985, 13479973333575319897333507543509815336818572211270286240551805124608], 
       Rational[
       4280730595883425488117421146186118485598534572425266190837985, 
        12855504354071922204335696738729300820177623950262342682411008]}, {
      0.41733986426352954`, 0.3329881487323773}], 0.03]}, InsetBox[
    StyleBox["50",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[
      5625730241310321680857161161594657398440233143955782979582187599985, 
       13479973333575319897333507543509815336818572211270286240551805124608], 
      Rational[4280730595883425488117421146186118485598534572425266190837985, 
       12855504354071922204335696738729300820177623950262342682411008]}, {
     0.41733986426352954`, 0.3329881487323773}]], 
   {GrayLevel[0.6499999999999999], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[867911362330302908597815990250414920845527629288179713180989517\
907622457424413025, 
        1897137590064188545819787018382342682267975428761855001222473056385648\
716020711424], Rational[
       72701423437188259887519663885137796370333853338760061955392857332026608\
3025, 180925139433306555349329664076074856020734351040063381311652475012364265\
0624]}, {0.457484668943246, 0.401831518079265}], 0.03]}, InsetBox[
    StyleBox["60",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[
      867911362330302908597815990250414920845527629288179713180989517907622457\
424413025, 
       18971375900641885458197870183823426822679754287618550012224730563856487\
16020711424], Rational[
      727014234371882598875196638851377963703338533387600619553928573320266083\
025, 1809251394333065553493296640760748560207343510400633813116524750123642650\
624]}, {0.457484668943246, 0.401831518079265}]], 
   {GrayLevel[0.6499999999999999], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[128840691589483651214886560548700077994709504779193950896454705\
469680190382519004402824339225425, 
        2669983794901137602993777132711940143253380652945815962433802009777774\
65722580068752870260867072], Rational[
       11352243099834167753748775857112173641048882517419085036773953038621134\
6429264435810815425, 
        2546294970418107607835557110511722701314335492082420313295175561692976\
62470417088272924672]}, {0.48255233546934045`, 0.44583377934293694`}], 0.03]},
    InsetBox[
    StyleBox["70",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[
      128840691589483651214886560548700077994709504779193950896454705469680190\
382519004402824339225425, 
       26699837949011376029937771327119401432533806529458159624338020097777746\
5722580068752870260867072], Rational[
      113522430998341677537487758571121736410488825174190850367739530386211346\
429264435810815425, 
       25462949704181076078355571105117227013143354920824203132951755616929766\
2470417088272924672]}, {0.48255233546934045`, 0.44583377934293694`}]], 
   {GrayLevel[0.6499999999999999], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[851529730530512119965283447796572962458547195087621363548551336\
0879059370262140000734445130071977399787551825, 
        1878834066219066582311584477431469621900546039126655896565832777225767\
2200916867547709591987078149624255479808], Rational[
       77007427534704635718157620093330419034628968285625024507108670309729400\
59329617889197851580000000261825, 
        1791795793742243368445953824454755422497316397787719627919991280771033\
4969441287563047019946172856926208]}, {0.4532224243964854, 
      0.42977792337524845`}], 0.03]}, InsetBox[
    StyleBox["80",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[
      851529730530512119965283447796572962458547195087621363548551336087905937\
0262140000734445130071977399787551825, 
       18788340662190665823115844774314696219005460391266558965658327772257672\
200916867547709591987078149624255479808], Rational[
      770074275347046357181576200933304190346289682856250245071086703097294005\
9329617889197851580000000261825, 
       17917957937422433684459538244547554224973163977877196279199912807710334\
969441287563047019946172856926208]}, {0.4532224243964854, 
     0.42977792337524845`}]], 
   {GrayLevel[0.6499999999999999], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[594325092130243530706700805441881633030302533803214097542082632\
855440146062108772634730078606490607683680095275618780347729, 
        1322111937580497197903830616065542079656809365928562438569297590548811\
582472622691650378420879430569695182424050046716608512], Rational[
       54791854314143035828135238165817929388399605667155288206330556900434342\
5535166829893344328428866319054562588538580929, 
        1260864198284623334792929283204595641762551656654894293374345388935863\
096687910739565256520156317300505812095689818112]}, {0.4495270598780581, 
      0.43455793564989864`}], 0.03]}, InsetBox[
    StyleBox["90",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[
      594325092130243530706700805441881633030302533803214097542082632855440146\
062108772634730078606490607683680095275618780347729, 
       13221119375804971979038306160655420796568093659285624385692975905488115\
82472622691650378420879430569695182424050046716608512], Rational[
      547918543141430358281352381658179293883996056671552882063305569004343425\
535166829893344328428866319054562588538580929, 
       12608641982846233347929292832045956417625516566548942933743453889358630\
96687910739565256520156317300505812095689818112]}, {0.4495270598780581, 
     0.43455793564989864`}]], 
   {GrayLevel[0.825], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[410067895128300013762780101569994698635708900371953936588957943\
67578647322382411287510247050074968864676980359967070453285577562224361041, 
        9303535670983768199031344740966458039726609416797671171603074549512182\
8878514934185752454491361736391777602765602070775492429008462675968], 
       Rational[
       38259114043054650490751362177056245614512948291841968549686204362050670\
906556933216202271211948923218488290051382344544037439643841, 
        8872543021186607550650925389257867850996598641202613040545534657966788\
1849780019937279180995332466499116518750764914298527173050368]}, {
      0.4407656504260373, 0.43120798571160834`}], 0.03]}, InsetBox[
    StyleBox["100",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[
      410067895128300013762780101569994698635708900371953936588957943675786473\
22382411287510247050074968864676980359967070453285577562224361041, 
       93035356709837681990313447409664580397266094167976711716030745495121828\
878514934185752454491361736391777602765602070775492429008462675968], Rational[
      382591140430546504907513621770562456145129482918419685496862043620506709\
06556933216202271211948923218488290051382344544037439643841, 
       88725430211866075506509253892578678509965986412026130405455346579667881\
849780019937279180995332466499116518750764914298527173050368]}, {
     0.4407656504260373, 0.43120798571160834`}]], 
   {GrayLevel[0.825], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[174790737151928742398272338065800367128005150341086415171037119\
565323067917919626941521945453200377261441834547152815268229522779435826742160\
077926330841034966560242307627766409474574110263160700805822934148185355424681\
462663865960875291295718048352404447442646712083270625, 
        5409735998829212122647959397545130050752996618609884386590317660433140\
762180862561018032700289609604041465804730952997671755239009307499901445519139\
460501267541879644149812061887810741006606756382968144980082569258475809717775\
99220570518424337445351925287506839283710296064], Rational[
       16665210176347240922748057232064718975852012629169897321755524408630543\
592043702217756831228382651772025886624244668269178382668751213882421562682166\
486168772328317970587638405929965562570648253196619186577003100430084681201462\
4834797521206279356730922410696731020625, 
        5159126280621730921409568212075357485535618418321499239530866299088612\
329655516205804856014527902225533929638606026647254710425385768413449712294711\
552144305745963710927784025085268727308851963408439774494249886759258088796401\
97010584371971452184059071815020407947264]}, {0.3231040057957678, 
      0.3230238856324118}], 0.03]}, InsetBox[
    StyleBox["200",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[
      174790737151928742398272338065800367128005150341086415171037119565323067\
917919626941521945453200377261441834547152815268229522779435826742160077926330\
841034966560242307627766409474574110263160700805822934148185355424681462663865\
960875291295718048352404447442646712083270625, 
       54097359988292121226479593975451300507529966186098843865903176604331407\
621808625610180327002896096040414658047309529976717552390093074999014455191394\
605012675418796441498120618878107410066067563829681449800825692584758097177759\
9220570518424337445351925287506839283710296064], Rational[
      166652101763472409227480572320647189758520126291698973217555244086305435\
920437022177568312283826517720258866242446682691783826687512138824215626821664\
861687723283179705876384059299655625706482531966191865770031004300846812014624\
834797521206279356730922410696731020625, 
       51591262806217309214095682120753574855356184183214992395308662990886123\
296555162058048560145279022255339296386060266472547104253857684134497122947115\
521443057459637109277840250852687273088519634084397744942498867592580887964019\
7010584371971452184059071815020407947264]}, {0.3231040057957678, 
     0.3230238856324118}]], 
   {GrayLevel[0.825], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[189169042699210207557840153816370105007529065554506643168878485\
037926410088550965284110606136690029495155264855140892358077909828192583832835\
376367187957999198223732423321062594807213824205876950867603687488944107995548\
765655826823426017867181876803333283232443035973256418826507008481736706935481\
122802851798525179896737916866444694914156789019225578097491254167135944207562\
67364600475738385343795945010380849, 
        5032967183571257946185495199983940279677371217383114330539893367794250\
486815366256900771645615961698282153071371067070480036917683351677115784083104\
054421152599584064088130643355576278110320562816890442851672846761035987624266\
501081958490349110188162145985823892023079485810624991073586876087382335060830\
075858372576616132120723237806531763394174416791350780793872214409619018287658\
1485726422392912374977789952], Rational[
       18040528993022974090700382147050336941046058621293547983451360620168858\
010685508152049421265467366615203564219755801250928821514435448670251488007400\
748922445847869485945353841121294656514787007227350372386711314642595080448085\
207216508579906946142049584494762220653916966948748891147128806072063369170179\
551115363707392235168556991756977471508950959488935272130428523735212615786111\
431704343056259110049, 
        4799811538287408777413840484603824882199641435034860926189320915025949\
942412725693608066220870935152322915145274226255874668996508933713069709857086\
233540680503448547447329181056572225675888598267450754977867933999095904945627\
690393408289288625896608491884063617728309140978455535005175472342855773030119\
014604923798195011254046666914493335146116654197073727411148275766009348189981\
6022612020867264151552]}, {0.3758598770854312, 0.37585911132377303`}], 0.03]},
    InsetBox[
    StyleBox["300",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[
      189169042699210207557840153816370105007529065554506643168878485037926410\
088550965284110606136690029495155264855140892358077909828192583832835376367187\
957999198223732423321062594807213824205876950867603687488944107995548765655826\
823426017867181876803333283232443035973256418826507008481736706935481122802851\
798525179896737916866444694914156789019225578097491254167135944207562673646004\
75738385343795945010380849, 
       50329671835712579461854951999839402796773712173831143305398933677942504\
868153662569007716456159616982821530713710670704800369176833516771157840831040\
544211525995840640881306433555762781103205628168904428516728467610359876242665\
010819584903491101881621459858238920230794858106249910735868760873823350608300\
758583725766161321207232378065317633941744167913507807938722144096190182876581\
485726422392912374977789952], Rational[
      180405289930229740907003821470503369410460586212935479834513606201688580\
106855081520494212654673666152035642197558012509288215144354486702514880074007\
489224458478694859453538411212946565147870072273503723867113146425950804480852\
072165085799069461420495844947622206539169669487488911471288060720633691701795\
511153637073922351685569917569774715089509594889352721304285237352126157861114\
31704343056259110049, 
       47998115382874087774138404846038248821996414350348609261893209150259499\
424127256936080662208709351523229151452742262558746689965089337130697098570862\
335406805034485474473291810565722256758885982674507549778679339990959049456276\
903934082892886258966084918840636177283091409784555350051754723428557730301190\
146049237981950112540466669144933351461166541970737274111482757660093481899816\
022612020867264151552]}, {0.3758598770854312, 0.37585911132377303`}]], 
   {GrayLevel[0.825], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[191433342880268681173943694090044601138213931556845956363443914\
673241599663110403546935805856193778110631763235156595735808568582612573722300\
010339168808831769889885564127687382567681354063615238212931388242315550215285\
493122631821726357350741978516420644154636605540276662057833156791918159608000\
379534359130468547832778920004801503316178309843252079564719550232693419808740\
398510352925315556555278923189885453782603613613807913378359122471852029672355\
373125525560003548675729285979193122566657744951763525689163626252472639852269\
3270709112171905, 
        4682438972324590935107345090020944030197829563088176720753021222186883\
041677992176265689953086748756383726196955934714933182594540792695278540450833\
233741497140746528382826576356174156430340660567296239493708358823195021005153\
699562983484301302302899544182408118870863374895494291352001975238934046534747\
906783748237500099344703400190932753905717897582455420523838748548516587115334\
510526629495265241567464182546137698000753654052600996454825767040240348964459\
608153237868495593548091756095996712563406031489568076156061892907537527755560\
542273536], Rational[
       18256505914043580525613905395282966472342304106231507046934267337919942\
483608722677839198222677258657137590461848487702464208461502485621663858618309\
543495492996933533663584277361293966553070863016112643068375926070145794379422\
302208906604999671272547086409256099018650746681672993681838987274001145252201\
263574164884898577813194662719854462971937382296227720414641066743008398366476\
024178476277911910074612310687148351442085248326713067292567618290287381864901\
963395014772091751655778507953748284316375321303356120777166688491372670969459\
05, 44655217860456380225251627826890411664942069655305640418558323118084745804\
576799166352176218860137523495923966941210889179063744934012367997555263836228\
766414077248843982949985086194576552778821633303065239986026985120973636185641\
889414637578032521243516754227818211206196742003358383197548283901658389548366\
391641974450105139764787587478198105982757401041226614367948041120406297059159\
532828285839477228776765309693317420517483259210552738435430910495271343799668\
81978863235086010066753479000771106153518189971996456205265910661247020302336]\
}, {0.40883254221086374`, 0.4088325348919706}], 0.03]}, InsetBox[
    StyleBox["400",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[
      191433342880268681173943694090044601138213931556845956363443914673241599\
663110403546935805856193778110631763235156595735808568582612573722300010339168\
808831769889885564127687382567681354063615238212931388242315550215285493122631\
821726357350741978516420644154636605540276662057833156791918159608000379534359\
130468547832778920004801503316178309843252079564719550232693419808740398510352\
925315556555278923189885453782603613613807913378359122471852029672355373125525\
560003548675729285979193122566657744951763525689163626252472639852269327070911\
2171905, 468243897232459093510734509002094403019782956308817672075302122218688\
304167799217626568995308674875638372619695593471493318259454079269527854045083\
323374149714074652838282657635617415643034066056729623949370835882319502100515\
369956298348430130230289954418240811887086337489549429135200197523893404653474\
790678374823750009934470340019093275390571789758245542052383874854851658711533\
451052662949526524156746418254613769800075365405260099645482576704024034896445\
960815323786849559354809175609599671256340603148956807615606189290753752775556\
0542273536], Rational[
      182565059140435805256139053952829664723423041062315070469342673379199424\
836087226778391982226772586571375904618484877024642084615024856216638586183095\
434954929969335336635842773612939665530708630161126430683759260701457943794223\
022089066049996712725470864092560990186507466816729936818389872740011452522012\
635741648848985778131946627198544629719373822962277204146410667430083983664760\
241784762779119100746123106871483514420852483267130672925676182902873818649019\
633950147720917516557785079537482843163753213033561207771666884913726709694590\
5, 446552178604563802252516278268904116649420696553056404185583231180847458045\
767991663521762188601375234959239669412108891790637449340123679975552638362287\
664140772488439829499850861945765527788216333030652399860269851209736361856418\
894146375780325212435167542278182112061967420033583831975482839016583895483663\
916419744501051397647875874781981059827574010412266143679480411204062970591595\
328282858394772287767653096933174205174832592105527384354309104952713437996688\
1978863235086010066753479000771106153518189971996456205265910661247020302336]}\
, {0.40883254221086374`, 0.4088325348919706}]], 
   {GrayLevel[0.825], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[649665555274451997007375578109339147513341413745452921200541121\
372455866681240004574087201691107532369337816074611390960490518715974730435054\
494837868850991898094162338117844437296457165841339058331495487092667389041232\
423609681351327569271721055815179363160818870699885112252046103517898828340810\
846612449569894859854157838926425926555505974550236206565033671586080024505087\
210754724814933661931692865290019904843683114984885929756752687873045219832842\
619296069048434696645821072563192869348442153835685616504338275411661358347605\
894571447304202775678972550750070257571706955517104114808017978282369804310893\
047240929955431848784484551038512293326781602272625414242466436761683810481, 
        1742529520249056365512311353133210194868002470362733988718715702982049\
553878204974098095879957046832133411116918454362118733432444115935018714466786\
957605746348649192788820800696196515419189104683104957187774528626675040280292\
359797245618173808073285037449211441338460459359488199888816259777611053192701\
961659180955402379577469159828320928237838306141193366024320020020406550115646\
199896773300050762697536767502815384675215990944010597050121839365705495260405\
711680625463166940749616744059475821932476870841353759757688198160654803105173\
484222505416851352655856542995917645077182797114155482006005394666665993761527\
547105656127708028861905978284863688229753943906920953645204758331392], 
       Rational[
       61956935419492510455096484950485703429585086223277437285302475670870229\
444442491280742552969153810755109602567999945811443484615517984091125933260950\
670158655154077787199159274599751706815913660533546021295277535998146838910418\
574758240095829402541758670052617500203846892574079561839503655347656562174518\
579337419194356986783881555218216887630412069623988584610829024836764622991423\
275065857764330918194329717609599148310504928544101767416067582261991832587410\
916242910092907612052824660528439380631648281926432086417375812765846735630217\
236609517714333104120591562842868327765158617437900095509977540757028346804461\
9556552271563826002666710486922459051213639231787643426645281, 
        1661805649041229596626578667767725176685335607874616612166133597356843\
522909359907243820075947806198247347943228201257818921501583209929484095064913\
709264513348244850910969544120975985926808457072358090579771546007800140648166\
999623532884763534615788495492183152521572551116455268753830203797923138802244\
149836712794687633111447486713715484845960909024422994636840839405447530856748\
771569035816241038033997313978972801852432242340097996759530867925363059292226\
516419053519408169507614845332599470074154730645517120130241583023695757966207\
012388711373187401443344634052198071553404614557414514547353167215982431184318\
110566764953334835874467829022277534703973716647072747845844992]}, {
      0.37282900962366283`, 0.37282900954897014`}], 0.03]}, InsetBox[
    StyleBox["500",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[
      649665555274451997007375578109339147513341413745452921200541121372455866\
681240004574087201691107532369337816074611390960490518715974730435054494837868\
850991898094162338117844437296457165841339058331495487092667389041232423609681\
351327569271721055815179363160818870699885112252046103517898828340810846612449\
569894859854157838926425926555505974550236206565033671586080024505087210754724\
814933661931692865290019904843683114984885929756752687873045219832842619296069\
048434696645821072563192869348442153835685616504338275411661358347605894571447\
304202775678972550750070257571706955517104114808017978282369804310893047240929\
955431848784484551038512293326781602272625414242466436761683810481, 
       17425295202490563655123113531332101948680024703627339887187157029820495\
538782049740980958799570468321334111169184543621187334324441159350187144667869\
576057463486491927888208006961965154191891046831049571877745286266750402802923\
597972456181738080732850374492114413384604593594881998888162597776110531927019\
616591809554023795774691598283209282378383061411933660243200200204065501156461\
998967733000507626975367675028153846752159909440105970501218393657054952604057\
116806254631669407496167440594758219324768708413537597576881981606548031051734\
842225054168513526558565429959176450771827971141554820060053946666659937615275\
47105656127708028861905978284863688229753943906920953645204758331392], 
      Rational[619569354194925104550964849504857034295850862232774372853024756\
708702294444424912807425529691538107551096025679999458114434846155179840911259\
332609506701586551540777871991592745997517068159136605335460212952775359981468\
389104185747582400958294025417586700526175002038468925740795618395036553476565\
621745185793374191943569867838815552182168876304120696239885846108290248367646\
229914232750658577643309181943297176095991483105049285441017674160675822619918\
325874109162429100929076120528246605284393806316482819264320864173758127658467\
356302172366095177143331041205915628428683277651586174379000955099775407570283\
468044619556552271563826002666710486922459051213639231787643426645281, 
       16618056490412295966265786677677251766853356078746166121661335973568435\
229093599072438200759478061982473479432282012578189215015832099294840950649137\
092645133482448509109695441209759859268084570723580905797715460078001406481669\
996235328847635346157884954921831525215725511164552687538302037979231388022441\
498367127946876331114474867137154848459609090244229946368408394054475308567487\
715690358162410380339973139789728018524322423400979967595308679253630592922265\
164190535194081695076148453325994700741547306455171201302415830236957579662070\
123887113731874014433446340521980715534046145574145145473531672159824311843181\
10566764953334835874467829022277534703973716647072747845844992]}, {
     0.37282900962366283`, 0.37282900954897014`}]], 
   {GrayLevel[0.825], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[698685614672448643398620413744071355927655261000844457838000505\
185940842326428282995033157451115895174050977966159420866546365857041748031946\
701536250018652935557447958967537808479847367386363020352892979981445182849635\
633187746706488172164503531113036506350150816141300264696322718533289044616990\
614610829825155439548565602108709087668315105462279938979983753373103061891313\
996529610772712253322247746306962005027960495032214815176780975364704451262303\
080970150849197160125029395562521674368809601787686623607351634955223551633311\
919116767918593800370774577592849334814481817933903253963767779767709153460812\
170507299306241650981257447176782648610276570197039446968712123549113134082859\
764730404706035246251454760662401204362975574149106215366275357772449900608710\
72084116189143266857670178949937964519995586341152992769, 
        1621168554937932830827871384660893263308920365639894423965828383580971\
667187181437422388984302541823478894658202168379861638091987662734359271069432\
530912953033466082209950697033892871709249785322397649342650666144739689077987\
504360673497597118698918178712505065580178804789043757004449719710034375864128\
340101432074072588948559838418002182124720649164133747665721099188993611694170\
409060032926739236796623512402787008949738039331593119408777983890925324290327\
128602138840121600771846097891188274889253992121069947920600432340576079408232\
590896975241180347171921768363693081616946062716191370862574317982712610366060\
030439594020767379989070463991357714728533425311370609632035766905767136174274\
092129723473051248691882854377614580191259028433114485582819188383134951024659\
12726696962751051318023405498085337938318858387456], Rational[
       66631852595452433699339558999469847519191922207380058460051951418418486\
514033671949455683683435880900908948135883636532592073246470073288263659072253\
760729064044508577740320435773687878878513751770469849937479249188780728327867\
762474061950665895032856221844107890607984046617540319311406391483291220247293\
777735206633240145584892144197477842525578742473659293818497238439127055210147\
838893240006898246468226746123970997536104282361773912744026346616786556412741\
887514029727543062682380390787152781138880071512103456779752645538020881348902\
963255383923656772099140622372649151483078904779562042091082965525675095928014\
077521289651691496128517250309563146366299225317240286259893041102026981746102\
868664812733883189767337399150784378676688166880277965469426675685371301936716\
414335647710656487031719281431338815257969, 
        1546066813409741240337249169026273024853630414619345115629032500821086\
566149884641096486076643506835440535219385307674276006786334669813498755521233\
111298516305414278230620095285313483914613519022367143004084268707980813100802\
902565644738766783427160433495049539165667347706836468700837821683916450370910\
968877250742027844379958952348711187481613778270848987260552500905030833906336\
220798523833026158138869774248873719167459525424569243820932372942853283205344\
322778834190484619876714799777210497750524513360090206070518905964447097213966\
933152175179653498813554542888348657242723524776641245710920637114250765195903\
807105630894439105977125610343320574501546311675425157196079031854407440351747\
600679133866358994190104345681776600066432026322473989088839710600981665634783\
86618325197936106985114484308324182451552256]}, {0.4309765400669261, 
      0.43097654006621217`}], 0.03]}, InsetBox[
    StyleBox["600",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[
      698685614672448643398620413744071355927655261000844457838000505185940842\
326428282995033157451115895174050977966159420866546365857041748031946701536250\
018652935557447958967537808479847367386363020352892979981445182849635633187746\
706488172164503531113036506350150816141300264696322718533289044616990614610829\
825155439548565602108709087668315105462279938979983753373103061891313996529610\
772712253322247746306962005027960495032214815176780975364704451262303080970150\
849197160125029395562521674368809601787686623607351634955223551633311919116767\
918593800370774577592849334814481817933903253963767779767709153460812170507299\
306241650981257447176782648610276570197039446968712123549113134082859764730404\
706035246251454760662401204362975574149106215366275357772449900608710720841161\
89143266857670178949937964519995586341152992769, 
       16211685549379328308278713846608932633089203656398944239658283835809716\
671871814374223889843025418234788946582021683798616380919876627343592710694325\
309129530334660822099506970338928717092497853223976493426506661447396890779875\
043606734975971186989181787125050655801788047890437570044497197100343758641283\
401014320740725889485598384180021821247206491641337476657210991889936116941704\
090600329267392367966235124027870089497380393315931194087779838909253242903271\
286021388401216007718460978911882748892539921210699479206004323405760794082325\
908969752411803471719217683636930816169460627161913708625743179827126103660600\
304395940207673799890704639913577147285334253113706096320357669057671361742740\
921297234730512486918828543776145801912590284331144855828191883831349510246591\
2726696962751051318023405498085337938318858387456], Rational[
      666318525954524336993395589994698475191919222073800584600519514184184865\
140336719494556836834358809009089481358836365325920732464700732882636590722537\
607290640445085777403204357736878788785137517704698499374792491887807283278677\
624740619506658950328562218441078906079840466175403193114063914832912202472937\
777352066332401455848921441974778425255787424736592938184972384391270552101478\
388932400068982464682267461239709975361042823617739127440263466167865564127418\
875140297275430626823803907871527811388800715121034567797526455380208813489029\
632553839236567720991406223726491514830789047795620420910829655256750959280140\
775212896516914961285172503095631463662992253172402862598930411020269817461028\
686648127338831897673373991507843786766881668802779654694266756853713019367164\
14335647710656487031719281431338815257969, 
       15460668134097412403372491690262730248536304146193451156290325008210865\
661498846410964860766435068354405352193853076742760067863346698134987555212331\
112985163054142782306200952853134839146135190223671430040842687079808131008029\
025656447387667834271604334950495391656673477068364687008378216839164503709109\
688772507420278443799589523487111874816137782708489872605525009050308339063362\
207985238330261581388697742488737191674595254245692438209323729428532832053443\
227788341904846198767147997772104977505245133600902060705189059644470972139669\
331521751796534988135545428883486572427235247766412457109206371142507651959038\
071056308944391059771256103433205745015463116754251571960790318544074403517476\
006791338663589941901043456817766000664320263224739890888397106009816656347838\
6618325197936106985114484308324182451552256]}, {0.4309765400669261, 
     0.43097654006621217`}]], 
   {GrayLevel[0.825], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[593743912555263732657395445538417823984553943023419563311241602\
851358786222832328082406239170174420767978328699373742006195097079042846874194\
810214686455369515007584743968576981490437394158835361127695206714395108017721\
435448171583357265470201882626756624510303731961135937286410633910965952966526\
384752908971433043866023852768205186667233778009340779537606156010911020961178\
638025316518205616038279678444290631462455892531684873130024434872919696724527\
257164160419207890558023711925140301935372821345699763245321304108904712184963\
335338457067790005966970398403710009642637424776352385733454742050701959287866\
813821691277236009370717126237493781359293133427289643892775241432172594518058\
026692751474054906621981800780714049231853279893196376445975726319372318219667\
274977297972267267177544904024912904302805658889381894501554596379807611981121\
595407917352770394659814421244891935090747823485588422757831614359883868345349\
201434691469333656551942557965239425, 
        1885324934942783349661089362943614330592528040529035405081048689039555\
169195128561741157387709248602961820835784115436963050811822459269150643214449\
501189245442704298205472539979035436307857615361023255472010320582016797334348\
165830435110611333600200662009813831428415989101249301333384001906526313454920\
787465438050547441786480382814996617044984209413936031707860294351705958294546\
208275281311243524221224062918714419509298768890840533542714763746427028653148\
168716268629333446031594251892045416551626270494623507463134005393222466584077\
132503746718113827624501506285858788947684241878755444045352141448756510633877\
711094550275707653002570438760414130830190412623057912662912132959657073242875\
423244354142474442609985552913037301192861029443242464045791270459354982483737\
878389157765045610176690983834316769564497020469963549751188938173060929252668\
535623847384931201523603961732169181117294286013475974194387069614746934228503\
510645087380779977589890482176], Rational[
       56623831992650229840593017968408834270267818583034289178537913977336674\
534580146175400103260304429518756482436730774706521467090304788442952300932271\
758745997350547388388450636697830799621965076253783244523343594368389136147030\
431998865231913727753716933501167590515297612315404901256639295672598952977387\
042293486622435377374641499255721670562846509577987493882466191045666319741757\
101551958706118187019177546117651601824758675648813599668883245193020011868818\
399875553739362532679605931416190880643538821982684827220625559434667860710621\
815279495839190297058325006707956279543343910703493371937682006971489542963415\
442705928417718322022003478727758996339333186122837717533801643899062389696579\
686873109234148814409244585966975071027931494510632286860900661064902701664139\
064027351289480156670737260536124275408514539109995578039749221405819521725457\
600772763091691401580051559013312852389183782115228380765228241613774261127077\
2714191111108548029425, 
        1797985968535216664944733965819944696991470375565562634545372666396670\
502848747789136083018979309657060452304634204327548075496504267949247973646592\
618169064943985269742462673167262493427140822754882102462778397161499783834789\
434271273718463262176705038080037909916320790387391377766975404650236428694649\
493661344576404039179306395354267708821281632818161040981159490920740087790056\
427264481841319584103797972601618213185595291987267049353327525850703266766689\
461437481526692815810770275013013283301950712675689227545866017716619936546399\
242881533353914096474172121320589817950901262167697376294471875618702421792867\
385000753665645268442697943458952074842634594557817375815307743987710068934321\
807140688078379099473939469254529286568509129946939910932341833552699072345483\
663930089726491556336108192285839814724442501516307401419819772885380677464169\
059394690880709840320209466678780728452009473813510870165240354170557913044456\
015248381977825143422976]}, {0.31492922071456236`, 0.31492922071455615`}], 
     0.03]}, InsetBox[
    StyleBox["700",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[
      593743912555263732657395445538417823984553943023419563311241602851358786\
222832328082406239170174420767978328699373742006195097079042846874194810214686\
455369515007584743968576981490437394158835361127695206714395108017721435448171\
583357265470201882626756624510303731961135937286410633910965952966526384752908\
971433043866023852768205186667233778009340779537606156010911020961178638025316\
518205616038279678444290631462455892531684873130024434872919696724527257164160\
419207890558023711925140301935372821345699763245321304108904712184963335338457\
067790005966970398403710009642637424776352385733454742050701959287866813821691\
277236009370717126237493781359293133427289643892775241432172594518058026692751\
474054906621981800780714049231853279893196376445975726319372318219667274977297\
972267267177544904024912904302805658889381894501554596379807611981121595407917\
352770394659814421244891935090747823485588422757831614359883868345349201434691\
469333656551942557965239425, 
       18853249349427833496610893629436143305925280405290354050810486890395551\
691951285617411573877092486029618208357841154369630508118224592691506432144495\
011892454427042982054725399790354363078576153610232554720103205820167973343481\
658304351106113336002006620098138314284159891012493013333840019065263134549207\
874654380505474417864803828149966170449842094139360317078602943517059582945462\
082752813112435242212240629187144195092987688908405335427147637464270286531481\
687162686293334460315942518920454165516262704946235074631340053932224665840771\
325037467181138276245015062858587889476842418787554440453521414487565106338777\
110945502757076530025704387604141308301904126230579126629121329596570732428754\
232443541424744426099855529130373011928610294432424640457912704593549824837378\
783891577650456101766909838343167695644970204699635497511889381730609292526685\
356238473849312015236039617321691811172942860134759741943870696147469342285035\
10645087380779977589890482176], Rational[
      566238319926502298405930179684088342702678185830342891785379139773366745\
345801461754001032603044295187564824367307747065214670903047884429523009322717\
587459973505473883884506366978307996219650762537832445233435943683891361470304\
319988652319137277537169335011675905152976123154049012566392956725989529773870\
422934866224353773746414992557216705628465095779874938824661910456663197417571\
015519587061181870191775461176516018247586756488135996688832451930200118688183\
998755537393625326796059314161908806435388219826848272206255594346678607106218\
152794958391902970583250067079562795433439107034933719376820069714895429634154\
427059284177183220220034787277589963393331861228377175338016438990623896965796\
868731092341488144092445859669750710279314945106322868609006610649027016641390\
640273512894801566707372605361242754085145391099955780397492214058195217254576\
007727630916914015800515590133128523891837821152283807652282416137742611270772\
714191111108548029425, 
       17979859685352166649447339658199446969914703755655626345453726663966705\
028487477891360830189793096570604523046342043275480754965042679492479736465926\
181690649439852697424626731672624934271408227548821024627783971614997838347894\
342712737184632621767050380800379099163207903873913777669754046502364286946494\
936613445764040391793063953542677088212816328181610409811594909207400877900564\
272644818413195841037979726016182131855952919872670493533275258507032667666894\
614374815266928158107702750130132833019507126756892275458660177166199365463992\
428815333539140964741721213205898179509012621676973762944718756187024217928673\
850007536656452684426979434589520748426345945578173758153077439877100689343218\
071406880783790994739394692545292865685091299469399109323418335526990723454836\
639300897264915563361081922858398147244425015163074014198197728853806774641690\
593946908807098403202094666787807284520094738135108701652403541705579130444560\
15248381977825143422976]}, {0.31492922071456236`, 0.31492922071455615`}]], 
   {GrayLevel[0.825], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[284059274291958784502787875674066206703882972908997878554156475\
202325279540319407645292504826308102762745083583323543913875481759232333008035\
289855062191502437561991381187786943925207689065868310387622626991825061321849\
260659592551423948877874155412837444812712311821469033004552025901457414121178\
557995590274086245754231335178168161964218930978202799866632191062136046679484\
475716660702663913190025780411971624058249198459223332506187179964418006328721\
620216895152797001406294744208261937429596956492496602240730001952374126111096\
251363320441468513486724977371463112373042428653271263657792004002554187218625\
338141391748594650345901947482524181170536193039117352108172708797029637087760\
240099277077183575981381284061111113586824682210545914725667580510031817355748\
041266202304805353509028874743788667336847973223533272873067084327707815606502\
182557398590598636547897122875850235183059386895306123856389792251023986767566\
257287375249626268865368370483520924771275902767660200386289535502825620022411\
755701979671286523956019340706731083431197066497856254200488151981162342383301\
43515300249319905, 
        8770093891817668509245788232435077583097904714030556297069846868160171\
272393860653487685451882205228419595067814226508378459825061657586320084443212\
124487964503490977607541583088638175728130778068525568608694456192474324014516\
770368064623655112663615779702576374752983846127837994087518040014784548614470\
809097577880048265922731957497361736723523858036873777181066283098178435958713\
404491372628337935213472556559237750579481777434131940028760373692673259695940\
852190238253512391544673579453667313856783538340566935256207660449719782343309\
596112902645648491053271115178111774118247837554599355344980784310248070558005\
617314113756372148220187643876068341152958710052149342369923250682470476979612\
277528771392117016604927869237542506485954429435377987296604062236018120195508\
712387248196568844006803166094676051522027167611703414107127637736378972062181\
989558928253959912412456023750831714240590674258707030458505770268710601858434\
552163819316436533950375187888057909827563263582000657277866842110739821461524\
469734066299084769366000451211588960690505868127301461936407401348404649512363\
1383773184], Rational[
       27090003422923921045366425099250762020020520224077701569531478224867185\
910132224525114883475716889655796372384588020952248398349118012963268033972734\
517939690144440038897563283914207551947124155862847910382165288993316533877092\
742446072257996622539410501043862497641224145314338800553844122398741383832093\
349610474888424552702652982690538581329209423079599378553001497495148777810074\
231576762053744770407338059883845591344797273370912974479516614911707913048008\
615342385637001989467168268385663717478846474767288651437996678193358268410605\
386445311070240281986125032610824407174861972703639384340508906775508918187206\
063390277990995334957343092912955188286536048932422336507456993467978623925446\
796759973475053389088045160709337208552693850392069619162073028498238885865503\
159766119590140896697688311888115229699387125504427370778780945957115367120462\
603613402688443130720005926282707161096405063944990063832123742369091303932894\
844565989024026632352237392884481112652372042691469789570759555738332509654775\
519438019658660465697554224500115712833459509726500992162638398044261708552493\
905, 8363813297097843655820644600329473097894577707319790169782492511902018806\
833134320724187328226285198611826961340166576746425461827905260391315882885097\
969021323672273261586745346677947738772180622602051361746269409632038130299349\
182190536170113242736606314255118134483190658414835059659996046814488043280419\
442727928207651064617116448747383807681901966928269558969767664125858267510799\
876568439805922711823040541875601367456223901874485043297170345948466964665271\
940458539497748894380168393771470886977709141318259483535442781181127875623317\
826178212784281781455149820434354894874417833899836869221481619117804105764024\
080384975788257808864253879612294342955312778615324373172045404882885913479115\
990420715443626980712765920202738271669797358873355194667875515001411624439918\
887375065392345434954801649738360902812163936332143885734212623957607328588475\
760391477546608364540122748214449158278154619891195734506387966833688600954582\
370585743366750669837177169855031802714599210739762571207849608173200093769521\
459642695507783285141421519841156664377086760808431564719582889942788612712038\
4]}, {0.32389536280447434`, 0.32389536280447423`}], 0.03]}, InsetBox[
    StyleBox["800",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[
      284059274291958784502787875674066206703882972908997878554156475202325279\
540319407645292504826308102762745083583323543913875481759232333008035289855062\
191502437561991381187786943925207689065868310387622626991825061321849260659592\
551423948877874155412837444812712311821469033004552025901457414121178557995590\
274086245754231335178168161964218930978202799866632191062136046679484475716660\
702663913190025780411971624058249198459223332506187179964418006328721620216895\
152797001406294744208261937429596956492496602240730001952374126111096251363320\
441468513486724977371463112373042428653271263657792004002554187218625338141391\
748594650345901947482524181170536193039117352108172708797029637087760240099277\
077183575981381284061111113586824682210545914725667580510031817355748041266202\
304805353509028874743788667336847973223533272873067084327707815606502182557398\
590598636547897122875850235183059386895306123856389792251023986767566257287375\
249626268865368370483520924771275902767660200386289535502825620022411755701979\
671286523956019340706731083431197066497856254200488151981162342383301435153002\
49319905, 
       87700938918176685092457882324350775830979047140305562970698468681601712\
723938606534876854518822052284195950678142265083784598250616575863200844432121\
244879645034909776075415830886381757281307780685255686086944561924743240145167\
703680646236551126636157797025763747529838461278379940875180400147845486144708\
090975778800482659227319574973617367235238580368737771810662830981784359587134\
044913726283379352134725565592377505794817774341319400287603736926732596959408\
521902382535123915446735794536673138567835383405669352562076604497197823433095\
961129026456484910532711151781117741182478375545993553449807843102480705580056\
173141137563721482201876438760683411529587100521493423699232506824704769796122\
775287713921170166049278692375425064859544294353779872966040622360181201955087\
123872481965688440068031660946760515220271676117034141071276377363789720621819\
895589282539599124124560237508317142405906742587070304585057702687106018584345\
521638193164365339503751878880579098275632635820006572778668421107398214615244\
697340662990847693660004512115889606905058681273014619364074013484046495123631\
383773184], Rational[
      270900034229239210453664250992507620200205202240777015695314782248671859\
101322245251148834757168896557963723845880209522483983491180129632680339727345\
179396901444400388975632839142075519471241558628479103821652889933165338770927\
424460722579966225394105010438624976412241453143388005538441223987413838320933\
496104748884245527026529826905385813292094230795993785530014974951487778100742\
315767620537447704073380598838455913447972733709129744795166149117079130480086\
153423856370019894671682683856637174788464747672886514379966781933582684106053\
864453110702402819861250326108244071748619727036393843405089067755089181872060\
633902779909953349573430929129551882865360489324223365074569934679786239254467\
967599734750533890880451607093372085526938503920696191620730284982388858655031\
597661195901408966976883118881152296993871255044273707787809459571153671204626\
036134026884431307200059262827071610964050639449900638321237423690913039328948\
445659890240266323522373928844811126523720426914697895707595557383325096547755\
194380196586604656975542245001157128334595097265009921626383980442617085524939\
05, 83638132970978436558206446003294730978945777073197901697824925119020188068\
331343207241873282262851986118269613401665767464254618279052603913158828850979\
690213236722732615867453466779477387721806226020513617462694096320381302993491\
821905361701132427366063142551181344831906584148350596599960468144880432804194\
427279282076510646171164487473838076819019669282695589697676641258582675107998\
765684398059227118230405418756013674562239018744850432971703459484669646652719\
404585394977488943801683937714708869777091413182594835354427811811278756233178\
261782127842817814551498204343548948744178338998368692214816191178041057640240\
803849757882578088642538796122943429553127786153243731720454048828859134791159\
904207154436269807127659202027382716697973588733551946678755150014116244399188\
873750653923454349548016497383609028121639363321438857342126239576073285884757\
603914775466083645401227482144491582781546198911957345063879668336886009545823\
705857433667506698371771698550318027145992107397625712078496081732000937695214\
596426955077832851414215198411566643770867608084315647195828899427886127120384\
]}, {0.32389536280447434`, 0.32389536280447423`}]], 
   {GrayLevel[0.825], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[961726484138534336945970163430610776006143085868934292218736300\
607930691982646997248527664987386128008441803389677412607241872048737468425177\
567823648709460091756203344058550962236498751279021517040679429361448390714286\
231925363651756976982867979047818854306624924226282685684216017869450059916162\
144700657464266295486493785590920977557603352660643369874321210099779875882353\
710589288733875535062366430791997762861371632401304382729646574694946703410714\
307447076424811551262245375135720391257387968048198451511818300568309942231343\
340338051622147683431328908337190214803866199109003276344725022739455638564242\
884662672297188448830623328903581869926018895915932732467297678288558561865426\
042999126823544241452348380648577534287266759642136442618864321244706705772084\
974831675964848020748466319651463090096719718026107583230733837722333973093936\
418334446776623421381797575736209038293266163090732898606105357421409554068544\
330431238331890196102136707794830163219388674666033960897766184968986116650387\
528477989743777342258735335073113933757301133602052128439303081350577097055933\
987635710191612393235287359959644443306942492375568196235795045596493968337114\
31061266414999625222106895248604136204540359524855230192315493293440337339361,
         261097220353288126672938177679156095644991062261845945096058370820988\
476992889364212206702983749389585222526678609815709496893359546448401815809021\
962841319486489244135927499585090397533595929578607017502963986556594079709849\
428186418083671086146654374201977176450926017821012185029652278616994445899507\
251671734744220446946486726407547565235149894863358205867325756674110764756253\
993099966928553885423458889971322871579559478608624183521952968159874118775047\
260337252104265418773417083462637758243022067387692495904092352983253803449206\
459297022958414187805329623211592031387556499575103086196215648918623048654255\
951626478311402706432958845021902155525708567549424550578292254419501668798871\
269980409104842571343781196003726789783864995697628349902887948567776707783522\
646068221069947888712445738580883629266305817265348726496923250530740848921945\
719737110154001853236418729955762642910594288704080345157761475729034231677085\
714110182611974992975445366440868305962566813264974948999022699867300443656204\
429612466863914812544582267618279858291387701892055461642936593324221228204880\
079364250610231654227718537096269602982451130745464334744412025781521475750325\
603366797431668304122877782900730195434508359022560951177085100788547584], 
       Rational[
       91717384733060296560702314820971142025704683212461960843514450761242541\
104925914362539272632823175850663018733852957295591640218860644247842876588949\
378331273769420008373258875269857281127258131023237934894793962784521107627483\
831034690128542011393560993804811926476540281568900050409677034241659936340181\
764991469101278887767919232236736264906930440433243068343990912934215715850169\
623374623703813164466778758278306599589234854388445158791814140555418930137168\
827594996281530275217507013372950385828351182324862375132110725400700257106965\
878431428969968244967571955538474120453521918157188064251563369110112589944017\
557866247343681062106430771393946574808668609705991742269227874994160488101480\
870747369946737243419017772982725633586821421130061455566138478016276938365709\
968300104342859624315683881703679802552349352865053084953645071290685615454408\
775528516979999965302168620131810918619169688100735771948652224538158642920242\
833405395047944511274449033963901524300631588026653617475179964050886267501349\
699088117738748730346525306716134246160581300287812407688175697401223962835661\
755549105228751661023577088958132671464273369735569263078088252304021164521590\
184144086515991247366711285983524555122391730479624446339278161, 
        2490017131359940783242589737693367916536245939844569636307319362840542\
573861020700571124105298513313152528063570116192908257421107735141771467294902\
447140879502193871840739246226219153724631591592855620412483087125721737955564\
767707997166357861963790647525569691190014055452463007256052766961998423571655\
766217563097195119347445739818072941161631535180646952317483488789661071360149\
317741078649081091150845432008007732196421419225923381061105424498311221838448\
146221657793668925985499224306466658048840211750912627259181527931726488582672\
684641103347913625767990333667679132342877383948355543100506295381765829603728\
786721022714640678720081758708020739800534892553563600333139938540474594105446\
529201594398904527128040275609271905745172459579738139180068479230658605418421\
230966768931845557331521402176700871146257565167891755074722771937759865970093\
915339566745775730480372714574457577806418311157992793634047276773779217501504\
078962160224676065210775055321391162515323765420674791326739309952740131914181\
038021725310466885991881061728285391725422877235941521100393231622898370789337\
915079599478069822575745936358161954712401683287280414051170594992842442992454\
56091687614124588129880698109369464334972723982392264535031414784]}, {
      0.3683403763690902, 0.3683403763690902}], 0.03]}, InsetBox[
    StyleBox["900",
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[
      961726484138534336945970163430610776006143085868934292218736300607930691\
982646997248527664987386128008441803389677412607241872048737468425177567823648\
709460091756203344058550962236498751279021517040679429361448390714286231925363\
651756976982867979047818854306624924226282685684216017869450059916162144700657\
464266295486493785590920977557603352660643369874321210099779875882353710589288\
733875535062366430791997762861371632401304382729646574694946703410714307447076\
424811551262245375135720391257387968048198451511818300568309942231343340338051\
622147683431328908337190214803866199109003276344725022739455638564242884662672\
297188448830623328903581869926018895915932732467297678288558561865426042999126\
823544241452348380648577534287266759642136442618864321244706705772084974831675\
964848020748466319651463090096719718026107583230733837722333973093936418334446\
776623421381797575736209038293266163090732898606105357421409554068544330431238\
331890196102136707794830163219388674666033960897766184968986116650387528477989\
743777342258735335073113933757301133602052128439303081350577097055933987635710\
191612393235287359959644443306942492375568196235795045596493968337114310612664\
14999625222106895248604136204540359524855230192315493293440337339361, 
       26109722035328812667293817767915609564499106226184594509605837082098847\
699288936421220670298374938958522252667860981570949689335954644840181580902196\
284131948648924413592749958509039753359592957860701750296398655659407970984942\
818641808367108614665437420197717645092601782101218502965227861699444589950725\
167173474422044694648672640754756523514989486335820586732575667411076475625399\
309996692855388542345888997132287157955947860862418352195296815987411877504726\
033725210426541877341708346263775824302206738769249590409235298325380344920645\
929702295841418780532962321159203138755649957510308619621564891862304865425595\
162647831140270643295884502190215552570856754942455057829225441950166879887126\
998040910484257134378119600372678978386499569762834990288794856777670778352264\
606822106994788871244573858088362926630581726534872649692325053074084892194571\
973711015400185323641872995576264291059428870408034515776147572903423167708571\
411018261197499297544536644086830596256681326497494899902269986730044365620442\
961246686391481254458226761827985829138770189205546164293659332422122820488007\
936425061023165422771853709626960298245113074546433474441202578152147575032560\
3366797431668304122877782900730195434508359022560951177085100788547584], 
      Rational[917173847330602965607023148209711420257046832124619608435144507\
612425411049259143625392726328231758506630187338529572955916402188606442478428\
765889493783312737694200083732588752698572811272581310232379348947939627845211\
076274838310346901285420113935609938048119264765402815689000504096770342416599\
363401817649914691012788877679192322367362649069304404332430683439909129342157\
158501696233746237038131644667787582783065995892348543884451587918141405554189\
301371688275949962815302752175070133729503858283511823248623751321107254007002\
571069658784314289699682449675719555384741204535219181571880642515633691101125\
899440175578662473436810621064307713939465748086686097059917422692278749941604\
881014808707473699467372434190177729827256335868214211300614555661384780162769\
383657099683001043428596243156838817036798025523493528650530849536450712906856\
154544087755285169799999653021686201318109186191696881007357719486522245381586\
429202428334053950479445112744490339639015243006315880266536174751799640508862\
675013496990881177387487303465253067161342461605813002878124076881756974012239\
628356617555491052287516610235770889581326714642733697355692630780882523040211\
64521590184144086515991247366711285983524555122391730479624446339278161, 
       24900171313599407832425897376933679165362459398445696363073193628405425\
738610207005711241052985133131525280635701161929082574211077351417714672949024\
471408795021938718407392462262191537246315915928556204124830871257217379555647\
677079971663578619637906475255696911900140554524630072560527669619984235716557\
662175630971951193474457398180729411616315351806469523174834887896610713601493\
177410786490810911508454320080077321964214192259233810611054244983112218384481\
462216577936689259854992243064666580488402117509126272591815279317264885826726\
846411033479136257679903336676791323428773839483555431005062953817658296037287\
867210227146406787200817587080207398005348925535636003331399385404745941054465\
292015943989045271280402756092719057451724595797381391800684792306586054184212\
309667689318455573315214021767008711462575651678917550747227719377598659700939\
153395667457757304803727145744575778064183111579927936340472767737792175015040\
789621602246760652107750553213911625153237654206747913267393099527401319141810\
380217253104668859918810617282853917254228772359415211003932316228983707893379\
150795994780698225757459363581619547124016832872804140511705949928424429924545\
6091687614124588129880698109369464334972723982392264535031414784]}, {
     0.3683403763690902, 0.3683403763690902}]], 
   {GrayLevel[1.], EdgeForm[Thickness[Large]], 
    DiskBox[NCache[{
      Rational[472506323851370505105375763270134888243204152058203443213621846\
528546749059566804219342217828382995948401407712827835779429237693387592022576\
884383828048207594311658436083918420948932918161211717023072408605470331639808\
601018425548264039060730604677812610242305513334252473373660454021360168365029\
860117508685592049939502726330598916288445040963729658748299213563038210544827\
719186182994374068503828924144729989071765359878080930885899561380471815941229\
988340833745242437683864896799381596867890109092263953009745297714584840561401\
159961889385898080761550253524923878504298930760977960287139059565542174944062\
453244709803179824666090595140350771653751600620213379255738489603682331339512\
810408681072259801048008090825025651083762077650119859052439060860542578409603\
035874130710549638067102494757519946644343746648876144223867285666012143796934\
947899901944394730431160216704498247839933073451319634026898265282748135337358\
070419573519068411611810753740422946371402285911365380899952963473622966740044\
400016321782022111006198114486654544362822977197531607886651613380670419764213\
490146124126592742695682544644724213616959272968318812969855693843254164326739\
890155239865703699901809575897363436133712650051563751952649408602217741976960\
393761158992404305753548354964158561837557490493638366265799245373144581653510\
7894597560364720645352311596628817482440834077882013482305, 
        1214563651575762615264101594293491418330613568983476666403491462106614\
371659613393294514520241105180865509236396993402304847905211156501911152911937\
838784573992353559365518409248213467209083027901949084929130684772007083758983\
008322943841716406691224656623343817453783575282100192513962736359519322150483\
923830379920847481025273270426966151277321157875632860287842592008953200957108\
434491810605120606706093517656837156766265300932561380259713531937396719557069\
293099425539113676974425283813487484465428921262564704324382664605644024169305\
849997800065447383420156896339110227314968353094663156351173285930287463011179\
083544456527748107576674559866145520226562644235703704060183016412983853241166\
148824457413544804865882320867129898152158288877324032713696360203147660422434\
372689161197434140436954887323649502302792889434099627744413003579364315048204\
357299576763926960511180252524167961253706275962082429627645210004493331957343\
269527610605063914178648539818106935091716048728041050664240932415086191455676\
845668251471329211038194005116734715432901611180569476841050590432623807758412\
820490420628473068261707879750189340471331336515644604621633940050125204737302\
879789896230718339459679563935642713432996085048660480395553871789388929157953\
076660079468221113236894923638545699006801742833166191373673016189118067204072\
3446682911005144473853542730500346487817744370630656], Rational[
       45061714539658594617666287462421057761917011371357045765375420481990227\
992695797773958641344103254315913463022127510649988836627615563777040592614697\
974132162982201727416329858587653467650199880089490288798580107335870041947211\
123030955323754064813009873225834837800959352927972671034577405812610374370293\
374513673237574560325896474779028808956623361382738568715423794844289284378634\
261329774096962429473219316000619519633278361724573397478438644223854112130267\
251520619791277354104187841550157349584588230973184761427099479422255156886384\
142104773359738540202268707247284184534811943652167364131529700844074693677954\
968390956187038660655074664343407187060810023993724891884699983149719318953087\
868913122913828478881409056005957309081468155878617789721250274422542077022068\
987580744129888112031056467939381556099557563104626805214624878565314898106923\
178290191551359245522019769733986013764858912217629411603387718747892736989094\
111345402431120639500570772711343382046486778352772051033668260734328633825262\
132306565945727742068770967271752375261363533267029081841049400006091263817306\
652583404955893716632944685804919275624803620193053903001337013004417052746157\
871283596412092037887925208561519441478620194542125588518567864791473377383498\
173500795523366603603218130045270477153936323241703391411439857576456559065467\
21865115166066215734271438994759425926576305, 
        1158298160148394217743016809743396204310048645957447687533847295862783\
786449063676161303062668900662293919788739198114685867219172626974021103774965\
132507871620515403142469796417439906319697406675290188721781430027014812239630\
707095092622486502352928787825912301496299338609790985597574936255950281286701\
129751567765090447449944754054037238385506780505783901489107696541741562802418\
169490633587952238756268994957768589750542927677689914951051265656849593693799\
298381257571328808760094913304793819871357842695774750065214790921825431985193\
109510231080481894893795868243322589220970490545905262328313146524703467379740\
794701057937381846977877197137971420504152912364677146969016090786918500176588\
200401742375893406740076371066217325355680741193126709665008888438365612432894\
108475838849481716572718512843751432707589044031238200897610667781223597572521\
550464226497580490599804165386360131505686069452364377620358667377942401845305\
699851618390144266298912563150507865039554642417946863807907993712507430511166\
425388576003388606107896809689268794472600566082543827858973112518905456312573\
261728687885735576879222755193890896293002449527401547071107807207226948487570\
647992988806455935916595043120997155602451405571613769908479568280590943487122\
608814315288754571186919139517350863463212721665540877698586479367368762210914\
9405177031521934961179297190189692008798355456]}, {0.3890338091695281, 
      0.3890338091695281}], 0.03]}, InsetBox[
    StyleBox[
     TagBox[
      SuperscriptBox[
       TagBox["10",
        Power,
        Editable->True,
        Selectable->True], 
       TagBox["3",
        Power,
        Editable->True,
        Selectable->True]],
      InterpretTemplate[Superscript[#, #2]& ],
      Editable->False,
      Selectable->False],
     StripOnInput->False,
     FrontFaceColor->GrayLevel[0],
     BackFaceColor->GrayLevel[0],
     GraphicsColor->GrayLevel[0],
     FontFamily->"Times",
     FontSize->16,
     FontWeight->Bold,
     FontColor->GrayLevel[0]], 
    NCache[{Rational[
      472506323851370505105375763270134888243204152058203443213621846528546749\
059566804219342217828382995948401407712827835779429237693387592022576884383828\
048207594311658436083918420948932918161211717023072408605470331639808601018425\
548264039060730604677812610242305513334252473373660454021360168365029860117508\
685592049939502726330598916288445040963729658748299213563038210544827719186182\
994374068503828924144729989071765359878080930885899561380471815941229988340833\
745242437683864896799381596867890109092263953009745297714584840561401159961889\
385898080761550253524923878504298930760977960287139059565542174944062453244709\
803179824666090595140350771653751600620213379255738489603682331339512810408681\
072259801048008090825025651083762077650119859052439060860542578409603035874130\
710549638067102494757519946644343746648876144223867285666012143796934947899901\
944394730431160216704498247839933073451319634026898265282748135337358070419573\
519068411611810753740422946371402285911365380899952963473622966740044400016321\
782022111006198114486654544362822977197531607886651613380670419764213490146124\
126592742695682544644724213616959272968318812969855693843254164326739890155239\
865703699901809575897363436133712650051563751952649408602217741976960393761158\
992404305753548354964158561837557490493638366265799245373144581653510789459756\
0364720645352311596628817482440834077882013482305, 
       12145636515757626152641015942934914183306135689834766664034914621066143\
716596133932945145202411051808655092363969934023048479052111565019111529119378\
387845739923535593655184092482134672090830279019490849291306847720070837589830\
083229438417164066912246566233438174537835752821001925139627363595193221504839\
238303799208474810252732704269661512773211578756328602878425920089532009571084\
344918106051206067060935176568371567662653009325613802597135319373967195570692\
930994255391136769744252838134874844654289212625647043243826646056440241693058\
499978000654473834201568963391102273149683530946631563511732859302874630111790\
835444565277481075766745598661455202265626442357037040601830164129838532411661\
488244574135448048658823208671298981521582888773240327136963602031476604224343\
726891611974341404369548873236495023027928894340996277444130035793643150482043\
572995767639269605111802525241679612537062759620824296276452100044933319573432\
695276106050639141786485398181069350917160487280410506642409324150861914556768\
456682514713292110381940051167347154329016111805694768410505904326238077584128\
204904206284730682617078797501893404713313365156446046216339400501252047373028\
797898962307183394596795639356427134329960850486604803955538717893889291579530\
766600794682211132368949236385456990068017428331661913736730161891180672040723\
446682911005144473853542730500346487817744370630656], Rational[
      450617145396585946176662874624210577619170113713570457653754204819902279\
926957977739586413441032543159134630221275106499888366276155637770405926146979\
741321629822017274163298585876534676501998800894902887985801073358700419472111\
230309553237540648130098732258348378009593529279726710345774058126103743702933\
745136732375745603258964747790288089566233613827385687154237948442892843786342\
613297740969624294732193160006195196332783617245733974784386442238541121302672\
515206197912773541041878415501573495845882309731847614270994794222551568863841\
421047733597385402022687072472841845348119436521673641315297008440746936779549\
683909561870386606550746643434071870608100239937248918846999831497193189530878\
689131229138284788814090560059573090814681558786177897212502744225420770220689\
875807441298881120310564679393815560995575631046268052146248785653148981069231\
782901915513592455220197697339860137648589122176294116033877187478927369890941\
113454024311206395005707727113433820464867783527720510336682607343286338252621\
323065659457277420687709672717523752613635332670290818410494000060912638173066\
525834049558937166329446858049192756248036201930539030013370130044170527461578\
712835964120920378879252085615194414786201945421255885185678647914733773834981\
735007955233666036032181300452704771539363232417033914114398575764565590654672\
1865115166066215734271438994759425926576305, 
       11582981601483942177430168097433962043100486459574476875338472958627837\
864490636761613030626689006622939197887391981146858672191726269740211037749651\
325078716205154031424697964174399063196974066752901887217814300270148122396307\
070950926224865023529287878259123014962993386097909855975749362559502812867011\
297515677650904474499447540540372383855067805057839014891076965417415628024181\
694906335879522387562689949577685897505429276776899149510512656568495936937992\
983812575713288087600949133047938198713578426957747500652147909218254319851931\
095102310804818948937958682433225892209704905459052623283131465247034673797407\
947010579373818469778771971379714205041529123646771469690160907869185001765882\
004017423758934067400763710662173253556807411931267096650088884383656124328941\
084758388494817165727185128437514327075890440312382008976106677812235975725215\
504642264975804905998041653863601315056860694523643776203586673779424018453056\
998516183901442662989125631505078650395546424179468638079079937125074305111664\
253885760033886061078968096892687944726005660825438278589731125189054563125732\
617286878857355768792227551938908962930024495274015470711078072072269484875706\
479929888064559359165950431209971556024514055716137699084795682805909434871226\
088143152887545711869191395173508634632127216655408776985864793673687622109149\
405177031521934961179297190189692008798355456]}, {0.3890338091695281, 
     0.3890338091695281}]]},
  AspectRatio->Automatic,
  Axes->True,
  AxesLabel->{
    FormBox["\"Prob C Player1\"", TraditionalForm], 
    FormBox["\"Prob C Player2\"", TraditionalForm]},
  AxesOrigin->{-0.025, -0.025},
  ImageSize->{629., Automatic},
  PlotLabel->FormBox["\"Simulation\"", TraditionalForm],
  PlotRange->{{-0.14, 1.03}, {-0.14, 1.03}}]], "Output",
 CellChangeTimes->{
  3.39268777084375*^9, 3.392688027265625*^9, 3.392689641390625*^9, 
   3.39269969359375*^9, 3.392700077578125*^9, {3.3927014299375*^9, 
   3.392701446328125*^9}, 3.3927055258125*^9, 3.392705666125*^9, 
   3.392706634609375*^9, 3.392707142203125*^9, 3.392707211546875*^9, 
   3.392707260859375*^9, 3.392752806390625*^9, 3.39275907046875*^9, 
   3.392759141671875*^9, 3.392759186890625*^9, 3.392759242734375*^9, 
   3.39275985421875*^9, 3.3927606705625*^9, 3.39276094128125*^9, {
   3.392761374578125*^9, 3.3927613910625*^9}, 3.392763113890625*^9, 
   3.39276361009375*^9, 3.392763753875*^9, 3.392763953015625*^9, 
   3.39276420715625*^9, 3.392764341140625*^9, 3.392764902265625*^9, 
   3.39277691815625*^9, 3.392777824125*^9, 3.39285504190625*^9, {
   3.3928552391875*^9, 3.39285528028125*^9}, {3.392855386578125*^9, 
   3.392855403296875*^9}, {3.392855437125*^9, 3.39285544125*^9}, 
   3.39285549821875*^9, 3.392856977609375*^9, {3.392857068375*^9, 
   3.392857092125*^9}, 3.39285951640625*^9, 3.392859737953125*^9, 
   3.3928597765625*^9, 3.392860167*^9, 3.392860290609375*^9, 
   3.3928606321875*^9, 3.39286362896875*^9, 3.39286371959375*^9, 
   3.392863766578125*^9, 3.3928687889375*^9, {3.39286885571875*^9, 
   3.39286889775*^9}, 3.392869203828125*^9, 3.392869680734375*^9, 
   3.39330771278125*^9, 3.393307758703125*^9, 3.393307858546875*^9, 
   3.3933096728125*^9, 3.3933097363125*^9, 3.39336728371875*^9, 
   3.393367422796875*^9, 3.393368348390625*^9, 3.393368397671875*^9, {
   3.3933684715*^9, 3.393368497828125*^9}, 3.393369084109375*^9, 
   3.3933691353125*^9, {3.393369275984375*^9, 3.3933692941875*^9}, 
   3.393369565671875*^9, 3.393385191265625*^9, 3.3933852544375*^9, 
   3.393407921453125*^9, 3.3934485405625*^9, 3.39344861015625*^9, 
   3.39347140778125*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Figure - Creation", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"maxNorm", "=", 
    RowBox[{
     RowBox[{"NMaximize", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"expChangeNorm", "[", 
          RowBox[{"x", ",", "y"}], "]"}], ",", 
         RowBox[{
          RowBox[{"0", "\[LessEqual]", "x", "\[LessEqual]", "1"}], "&&", 
          RowBox[{"0", "\[LessEqual]", "y", "\[LessEqual]", "1"}]}]}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "y"}], "}"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gFigure", "=", 
   RowBox[{"Show", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"DensityPlot", "[", 
      RowBox[{
       RowBox[{"Rescale", "[", 
        RowBox[{
         RowBox[{"expChangeNorm", "[", 
          RowBox[{"x", ",", "y"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "maxNorm"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"380", ",", "750"}], "}"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", "0", ",", "1"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.04"}], ",", "1.04"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "0.04"}], ",", "1.04"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"BaseStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
          RowBox[{"FontSize", "\[Rule]", 
           RowBox[{"20", "*", "textScaleFactor"}]}]}], "]"}]}], ",", 
       RowBox[{"ColorFunction", "\[Rule]", 
        RowBox[{"ColorData", "[", "\"\<VisibleSpectrum\>\"", "]"}]}], ",", 
       RowBox[{"ColorFunctionScaling", "\[Rule]", "False"}], ",", 
       RowBox[{"FrameStyle", "\[Rule]", "Thick"}], ",", 
       RowBox[{"FrameTicksStyle", "\[Rule]", "Thick"}], ",", 
       RowBox[{"FrameTicks", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"0", ",", "\"\< 0 \>\"", ",", ".02"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"0.2", ",", "\"\< 0.2 \>\"", ",", ".02"}], "}"}], ",", 
              
              RowBox[{"{", 
               RowBox[{"0.4", ",", "\"\< 0.4 \>\"", ",", ".02"}], "}"}], ",", 
              
              RowBox[{"{", 
               RowBox[{"0.6", ",", "\"\< 0.6 \>\"", ",", ".02"}], "}"}], ",", 
              
              RowBox[{"{", 
               RowBox[{"0.8", ",", "\"\< 0.8 \>\"", ",", ".02"}], "}"}], ",", 
              
              RowBox[{"{", 
               RowBox[{"1", ",", "\"\< 1 \>\"", ",", ".02"}], "}"}]}], "}"}], 
            ",", "None"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"0", ",", "0", ",", ".02"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"0.2", ",", "0.2", ",", ".02"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"0.4", ",", "0.4", ",", ".02"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"0.6", ",", "0.6", ",", ".02"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"0.8", ",", "0.8", ",", ".02"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"1", ",", "1", ",", ".02"}], "}"}]}], "}"}], ",", 
            "None"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Text", "[", 
             RowBox[{"Style", "[", 
              RowBox[{"\"\<Probability of Cooperating, Player1\>\"", ",", 
               RowBox[{"FontSize", "\[Rule]", 
                RowBox[{"26", "*", "textScaleFactor"}]}], ",", 
               RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}]}], "]"}], 
             "]"}], ",", "None"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Text", "[", 
             RowBox[{"Style", "[", 
              RowBox[{"\"\<Probability of Cooperating, Player2\>\"", ",", 
               RowBox[{"FontSize", "\[Rule]", 
                RowBox[{"26", "*", "textScaleFactor"}]}], ",", 
               RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}]}], "]"}], 
             "]"}], ",", "None"}], "}"}]}], "}"}]}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Graphics", "[", 
      RowBox[{"{", 
       RowBox[{"expectedMovementArrowsAndPoints", ",", "listOfProb"}], "}"}], 
      "]"}]}], "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"myLegend", "=", 
   RowBox[{"DensityPlot", "[", 
    RowBox[{
     RowBox[{"Rescale", "[", 
      RowBox[{"y", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"380", ",", "750"}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", ".07"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", "0", ",", "1"}], "}"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", 
      RowBox[{"ColorData", "[", "\"\<VisibleSpectrum\>\"", "]"}]}], ",", 
     RowBox[{"ColorFunctionScaling", "\[Rule]", "False"}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"FrameStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"White", ",", "White"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"White", ",", "White"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Axes", "\[Rule]", "False"}], ",", 
     RowBox[{"FrameTicksStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Directive", "[", 
         RowBox[{"Black", ",", 
          RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
          RowBox[{"FontSize", "\[Rule]", 
           RowBox[{"15", "*", "textScaleFactor"}]}]}], "]"}], ",", "Thick"}], 
       "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"FrameTicks", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"None", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "\"\< 0 \>\"", ",", 
              RowBox[{"textScaleFactor", "/", "10"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.2", ",", 
              RowBox[{"0.2", "*", "maxNorm"}], ",", 
              RowBox[{"textScaleFactor", "/", "10"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.4", ",", 
              RowBox[{"0.4", "*", "maxNorm"}], ",", 
              RowBox[{"textScaleFactor", "/", "10"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.6", ",", 
              RowBox[{"0.6", "*", "maxNorm"}], ",", 
              RowBox[{"textScaleFactor", "/", "10"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.8", ",", 
              RowBox[{"0.8", "*", "maxNorm"}], ",", 
              RowBox[{"textScaleFactor", "/", "10"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", "maxNorm", ",", 
              RowBox[{"textScaleFactor", "/", "10"}]}], "}"}]}], "}"}]}], 
         "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"None", ",", "None"}], "}"}]}], "}"}]}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.392701523421875*^9, 3.392701523703125*^9}, {
   3.392702573453125*^9, 3.39270257371875*^9}, {3.3927030148125*^9, 
   3.392703118265625*^9}, {3.392703163375*^9, 3.392703171984375*^9}, {
   3.3927032033125*^9, 3.39270320359375*^9}, {3.39270337990625*^9, 
   3.392703390703125*^9}, {3.39270342128125*^9, 3.392703426265625*^9}, {
   3.392703581421875*^9, 3.392703612015625*^9}, {3.39270364884375*^9, 
   3.392703842625*^9}, {3.392703921125*^9, 3.39270393590625*^9}, {
   3.392703998203125*^9, 3.3927040098125*^9}, {3.392704154296875*^9, 
   3.392704155015625*^9}, {3.392704189078125*^9, 3.39270424009375*^9}, {
   3.392704672640625*^9, 3.39270468134375*^9}, {3.392704722421875*^9, 
   3.392704743671875*^9}, {3.3927048086875*^9, 3.392704811703125*^9}, {
   3.39270485*^9, 3.392704850375*^9}, {3.392705252828125*^9, 
   3.39270528603125*^9}, {3.392705434328125*^9, 3.39270544184375*^9}, {
   3.39270547371875*^9, 3.392705512703125*^9}, {3.3927055619375*^9, 
   3.392705562265625*^9}, {3.39270562296875*^9, 3.3927057254375*^9}, {
   3.392705793875*^9, 3.392705796828125*^9}, {3.39270583353125*^9, 
   3.392705872515625*^9}, {3.392705925296875*^9, 3.392705972953125*^9}, {
   3.392706138984375*^9, 3.39270614090625*^9}, {3.392706187625*^9, 
   3.39270621371875*^9}, {3.392706303515625*^9, 3.392706628703125*^9}, {
   3.39270673159375*^9, 3.392706762296875*^9}, {3.392706805046875*^9, 
   3.392706809484375*^9}, {3.392707116796875*^9, 3.39270711703125*^9}, {
   3.3927074890625*^9, 3.392707496875*^9}, {3.3927076333125*^9, 
   3.392707637546875*^9}, {3.3927490305625*^9, 3.392749062703125*^9}, {
   3.392749311171875*^9, 3.39274933003125*^9}, {3.39274979828125*^9, 
   3.39274979975*^9}, {3.392750383375*^9, 3.392750409296875*^9}, {
   3.392750580109375*^9, 3.39275066596875*^9}, {3.392751254125*^9, 
   3.3927512629375*^9}, {3.392751294421875*^9, 3.392751303609375*^9}, {
   3.392752301328125*^9, 3.392752399*^9}, {3.39275245875*^9, 
   3.392752481859375*^9}, {3.392752579265625*^9, 3.392752639171875*^9}, {
   3.392752674203125*^9, 3.3927526744375*^9}, {3.392752888109375*^9, 
   3.39275291875*^9}, {3.392753007390625*^9, 3.392753055640625*^9}, 
   3.392753250359375*^9, {3.39275336478125*^9, 3.392753395546875*^9}, {
   3.392753434796875*^9, 3.39275345896875*^9}, {3.392753564015625*^9, 
   3.392753572390625*^9}, {3.392753606140625*^9, 3.3927536084375*^9}, {
   3.392753727328125*^9, 3.3927537615*^9}, {3.39275379271875*^9, 
   3.39275381609375*^9}, {3.392753915703125*^9, 3.392753933640625*^9}, {
   3.392753997796875*^9, 3.392754041734375*^9}, {3.39275416215625*^9, 
   3.392754254765625*^9}, {3.392754319125*^9, 3.39275437690625*^9}, {
   3.39275445153125*^9, 3.392754529921875*^9}, {3.392754564328125*^9, 
   3.39275457628125*^9}, {3.392754616125*^9, 3.392754645359375*^9}, {
   3.392754714921875*^9, 3.392754808703125*^9}, {3.39275492684375*^9, 
   3.3927550234375*^9}, 3.3927550745625*^9, {3.39275514353125*^9, 
   3.392755143875*^9}, {3.39275522740625*^9, 3.3927552941875*^9}, {
   3.392756114828125*^9, 3.39275614515625*^9}, 3.39275618190625*^9, {
   3.392756250875*^9, 3.392756251109375*^9}, {3.39275630290625*^9, 
   3.392756318046875*^9}, {3.392756389140625*^9, 3.392756396640625*^9}, {
   3.392756518984375*^9, 3.392756522703125*^9}, {3.3927566238125*^9, 
   3.39275662565625*^9}, {3.39275667115625*^9, 3.392756720953125*^9}, {
   3.3927568156875*^9, 3.3927569268125*^9}, {3.39275702784375*^9, 
   3.39275707378125*^9}, {3.39275710403125*^9, 3.392757112953125*^9}, {
   3.3927575485*^9, 3.392757579546875*^9}, {3.392757874140625*^9, 
   3.3927578796875*^9}, {3.392757925765625*^9, 3.392757934265625*^9}, {
   3.392757972296875*^9, 3.392757997625*^9}, {3.392758062015625*^9, 
   3.392758139*^9}, {3.39275832*^9, 3.3927583916875*^9}, {
   3.392758432015625*^9, 3.392758459*^9}, {3.392758529109375*^9, 
   3.392758544890625*^9}, {3.392758613625*^9, 3.392758647984375*^9}, {
   3.39275870496875*^9, 3.392758795671875*^9}, {3.392758840625*^9, 
   3.392758857484375*^9}, {3.39275894103125*^9, 3.392758941765625*^9}, {
   3.3927589883125*^9, 3.392759066234375*^9}, {3.39275912846875*^9, 
   3.392759132140625*^9}, {3.392759179*^9, 3.392759218890625*^9}, {
   3.392759458390625*^9, 3.3927595086875*^9}, {3.392760544828125*^9, 
   3.392760552703125*^9}, {3.392760591078125*^9, 3.392760620359375*^9}, {
   3.392760835984375*^9, 3.392760883125*^9}, {3.39276110240625*^9, 
   3.3927611365625*^9}, {3.392761298328125*^9, 3.39276135640625*^9}, {
   3.392762935796875*^9, 3.3927631011875*^9}, {3.39276329821875*^9, 
   3.392763300484375*^9}, 3.3927633378125*^9, {3.392763417*^9, 
   3.392763420609375*^9}, {3.39276347178125*^9, 3.39276348590625*^9}, {
   3.39276353584375*^9, 3.3927635545*^9}, {3.392763801171875*^9, 
   3.392763815453125*^9}, {3.392763857515625*^9, 3.392763897453125*^9}, {
   3.392763977015625*^9, 3.392763980671875*^9}, {3.39276406509375*^9, 
   3.392764069828125*^9}, {3.392764160640625*^9, 3.3927641978125*^9}, {
   3.3927643105*^9, 3.392764332796875*^9}, {3.392764396796875*^9, 
   3.392764397390625*^9}, {3.39276467409375*^9, 3.3927646895625*^9}, {
   3.3927647829375*^9, 3.39276479253125*^9}, {3.392764825546875*^9, 
   3.392764830078125*^9}, {3.392764898234375*^9, 3.39276489846875*^9}, {
   3.39277689565625*^9, 3.392776907734375*^9}, {3.392777192015625*^9, 
   3.392777200328125*^9}, {3.39277743171875*^9, 3.392777636625*^9}, {
   3.39277768496875*^9, 3.39277772025*^9}, {3.392777769078125*^9, 
   3.392777814171875*^9}, {3.39285500003125*^9, 3.392855035234375*^9}, 
   3.3928601516875*^9, {3.392860185109375*^9, 3.392860229109375*^9}, {
   3.3928602665625*^9, 3.39286027878125*^9}, {3.3928687720625*^9, 
   3.39286877534375*^9}, {3.39330772821875*^9, 3.393307728609375*^9}, {
   3.3933097260625*^9, 3.393309726828125*^9}, {3.39336746096875*^9, 
   3.3933674765*^9}, {3.3933676075625*^9, 3.393367683859375*^9}, {
   3.393367806234375*^9, 3.3933678806875*^9}, {3.393367958046875*^9, 
   3.39336799965625*^9}, {3.39336806765625*^9, 3.393368159421875*^9}, {
   3.39336820115625*^9, 3.393368207671875*^9}, {3.39336825196875*^9, 
   3.39336833121875*^9}, {3.39336838621875*^9, 3.39336839171875*^9}, {
   3.3933684341875*^9, 3.393368495*^9}, {3.393368602140625*^9, 
   3.393368607359375*^9}, {3.39336864815625*^9, 3.393368776890625*^9}, {
   3.39336883171875*^9, 3.393368971421875*^9}, {3.39336900253125*^9, 
   3.39336907415625*^9}, {3.393369128015625*^9, 3.39336916740625*^9}, 
   3.393369561171875*^9, {3.393385187875*^9, 3.393385188125*^9}, {
   3.393385250328125*^9, 3.39338525075*^9}, {3.393407890609375*^9, 
   3.393407897359375*^9}, {3.393448490078125*^9, 3.39344851784375*^9}, {
   3.403167912234375*^9, 3.4031679245625*^9}}],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJyNmUtuXEUUhiN2AngfPQSmLAGJEa+tQC/BU89a0BNPoiurJctCam6MQ9tA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    "], {{
      {GrayLevel[0.8], EdgeForm[None], 
       GraphicsGroupBox[PolygonBox[CompressedData["
1:eJxNmwnYV9MWh885iUw3U27GUMlQhkRKSKakjFHmSjKXImSsSMhUCKWUEFIo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         "]]]}, {}, {}, {}}, {}},
    VertexColors->CompressedData["
1:eJy1W3k4lN/ftoZIVCJaCSXabSmfItmyfOmbpRItlGizVGhBmyVpE2WPrKns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     "]], {{
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{0, 0}, {Rational[1, 32], Rational[1, 32]}}, {{0, 0}, {
         0.03125, 0.03125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{0, Rational[1, 20]}, {
         Rational[19, 640], Rational[999, 12800]}}, {{0, 0.05}, {0.0296875, 
         0.078046875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{0, Rational[1, 10]}, {
         Rational[9, 320], Rational[399, 3200]}}, {{0, 0.1}, {0.028125, 
         0.1246875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{0, Rational[3, 20]}, {
         Rational[17, 640], Rational[2191, 12800]}}, {{0, 0.15}, {0.0265625, 
         0.171171875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{0, Rational[1, 5]}, {
         Rational[1, 40], Rational[87, 400]}}, {{0, 0.2}, {0.025, 
         0.2175}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{0, Rational[1, 4]}, {
         Rational[3, 128], Rational[135, 512]}}, {{0, 0.25}, {0.0234375, 
         0.263671875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{0, Rational[3, 10]}, {
         Rational[7, 320], Rational[991, 3200]}}, {{0, 0.3}, {0.021875, 
         0.3096875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{0, Rational[7, 20]}, {
         Rational[13, 640], Rational[4551, 12800]}}, {{0, 0.35}, {0.0203125, 
         0.355546875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{0, Rational[2, 5]}, {
         Rational[3, 160], Rational[321, 800]}}, {{0, 0.4}, {0.01875, 
         0.40125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{0, Rational[9, 20]}, {
         Rational[11, 640], Rational[5719, 12800]}}, {{0, 0.45}, {0.0171875, 
         0.446796875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{0, Rational[1, 2]}, {
         Rational[1, 64], Rational[63, 128]}}, {{0, 0.5}, {0.015625, 
         0.4921875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{0, Rational[11, 20]}, {
         Rational[9, 640], Rational[6879, 12800]}}, {{0, 0.55}, {0.0140625, 
         0.537421875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{0, Rational[3, 5]}, {
         Rational[1, 80], Rational[233, 400]}}, {{0, 0.6}, {0.0125, 
         0.5825}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{0, Rational[13, 20]}, {
         Rational[7, 640], Rational[8031, 12800]}}, {{0, 0.65}, {0.0109375, 
         0.627421875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{0, Rational[7, 10]}, {
         Rational[3, 320], Rational[2151, 3200]}}, {{0, 0.7}, {0.009375, 
         0.6721875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{0, Rational[3, 4]}, {
         Rational[1, 128], Rational[367, 512]}}, {{0, 0.75}, {0.0078125, 
         0.716796875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{0, Rational[4, 5]}, {
         Rational[1, 160], Rational[609, 800]}}, {{0, 0.8}, {0.00625, 
         0.76125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{0, Rational[17, 20]}, {
         Rational[3, 640], Rational[10311, 12800]}}, {{0, 0.85}, {0.0046875, 
         0.805546875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{0, Rational[9, 10]}, {
         Rational[1, 320], Rational[2719, 3200]}}, {{0, 0.9}, {0.003125, 
         0.8496875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{0, Rational[19, 20]}, {
         Rational[1, 640], Rational[11439, 12800]}}, {{0, 0.95}, {0.0015625, 
         0.893671875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{0, 1}, {0, Rational[15, 16]}}, {{0, 1}, {
         0, 0.9375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 20], 0}, {
         Rational[999, 12800], Rational[19, 640]}}, {{0.05, 0}, {0.078046875, 
         0.0296875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 20], Rational[1, 20]}, {
         Rational[9801, 128000], Rational[9801, 128000]}}, {{0.05, 0.05}, {
        0.0765703125, 0.0765703125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 20], Rational[1, 10]}, {
         Rational[2403, 32000], Rational[1973, 16000]}}, {{0.05, 0.1}, {
        0.07509375, 0.1233125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 20], Rational[3, 20]}, {
         Rational[9423, 128000], Rational[21749, 128000]}}, {{0.05, 0.15}, {
        0.0736171875, 0.1699140625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 20], Rational[1, 5]}, {
         Rational[4617, 64000], Rational[1731, 8000]}}, {{0.05, 0.2}, {
        0.072140625, 0.216375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 20], Rational[1, 4]}, {
         Rational[1809, 25600], Rational[269, 1024]}}, {{0.05, 0.25}, {
        0.0706640625, 0.2626953125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 20], Rational[3, 10]}, {
         Rational[1107, 16000], Rational[2471, 8000]}}, {{0.05, 0.3}, {
        0.0691875, 0.308875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 20], Rational[7, 20]}, {
         Rational[8667, 128000], Rational[45429, 128000]}}, {{0.05, 0.35}, {
        0.0677109375, 0.3549140625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 20], Rational[2, 5]}, {
         Rational[4239, 64000], Rational[6413, 16000]}}, {{0.05, 0.4}, {
        0.066234375, 0.4008125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 20], Rational[9, 20]}, {
         Rational[8289, 128000], Rational[57161, 128000]}}, {{0.05, 0.45}, {
        0.0647578125, 0.4465703125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 20], Rational[1, 2]}, {
         Rational[81, 1280], Rational[63, 128]}}, {{0.05, 0.5}, {0.06328125, 
        0.4921875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 20], Rational[11, 20]}, {
         Rational[7911, 128000], Rational[68821, 128000]}}, {{0.05, 0.55}, {
        0.0618046875, 0.5376640625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 20], Rational[3, 5]}, {
         Rational[3861, 64000], Rational[583, 1000]}}, {{0.05, 0.6}, {
        0.060328125, 0.583}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 20], Rational[13, 20]}, {
         Rational[7533, 128000], Rational[80409, 128000]}}, {{0.05, 0.65}, {
        0.0588515625, 0.6281953125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 20], Rational[7, 10]}, {
         Rational[459, 8000], Rational[2693, 4000]}}, {{0.05, 0.7}, {0.057375,
         0.67325}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 20], Rational[3, 4]}, {
         Rational[1431, 25600], Rational[3677, 5120]}}, {{0.05, 0.75}, {
        0.0558984375, 0.7181640625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 20], Rational[4, 5]}, {
         Rational[3483, 64000], Rational[12207, 16000]}}, {{0.05, 0.8}, {
        0.054421875, 0.7629375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 20], Rational[17, 20]}, {
         Rational[6777, 128000], Rational[103369, 128000]}}, {{0.05, 0.85}, {
        0.0529453125, 0.8075703125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 20], Rational[9, 10]}, {
         Rational[1647, 32000], Rational[13633, 16000]}}, {{0.05, 0.9}, {
        0.05146875, 0.8520625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 20], Rational[19, 20]}, {
         Rational[6399, 128000], Rational[114741, 128000]}}, {{0.05, 0.95}, {
        0.0499921875, 0.8964140625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 20], 1}, {
         Rational[621, 12800], Rational[301, 320]}}, {{0.05, 1}, {0.048515625,
          0.940625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 10], 0}, {
         Rational[399, 3200], Rational[9, 320]}}, {{0.1, 0}, {0.1246875, 
         0.028125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 10], Rational[1, 20]}, {
         Rational[1973, 16000], Rational[2403, 32000]}}, {{0.1, 0.05}, {
        0.1233125, 0.07509375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 10], Rational[1, 10]}, {
         Rational[1951, 16000], Rational[1951, 16000]}}, {{0.1, 0.1}, {
        0.1219375, 0.1219375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 10], Rational[3, 20]}, {
         Rational[1929, 16000], Rational[5397, 32000]}}, {{0.1, 0.15}, {
        0.1205625, 0.16865625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 10], Rational[1, 5]}, {
         Rational[1907, 16000], Rational[861, 4000]}}, {{0.1, 0.2}, {
        0.1191875, 0.21525}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 10], Rational[1, 4]}, {
         Rational[377, 3200], Rational[67, 256]}}, {{0.1, 0.25}, {0.1178125, 
        0.26171875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 10], Rational[3, 10]}, {
         Rational[1863, 16000], Rational[4929, 16000]}}, {{0.1, 0.3}, {
        0.1164375, 0.3080625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 10], Rational[7, 20]}, {
         Rational[1841, 16000], Rational[11337, 32000]}}, {{0.1, 0.35}, {
        0.1150625, 0.35428125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 10], Rational[2, 5]}, {
         Rational[1819, 16000], Rational[3203, 8000]}}, {{0.1, 0.4}, {
        0.1136875, 0.400375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 10], Rational[9, 20]}, {
         Rational[1797, 16000], Rational[14283, 32000]}}, {{0.1, 0.45}, {
        0.1123125, 0.44634375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 10], Rational[1, 2]}, {
         Rational[71, 640], Rational[63, 128]}}, {{0.1, 0.5}, {0.1109375, 
        0.4921875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 10], Rational[11, 20]}, {
         Rational[1753, 16000], Rational[17213, 32000]}}, {{0.1, 0.55}, {
        0.1095625, 0.53790625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 10], Rational[3, 5]}, {
         Rational[1731, 16000], Rational[1167, 2000]}}, {{0.1, 0.6}, {
        0.1081875, 0.5835}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 10], Rational[13, 20]}, {
         Rational[1709, 16000], Rational[20127, 32000]}}, {{0.1, 0.65}, {
        0.1068125, 0.62896875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 10], Rational[7, 10]}, {
         Rational[1687, 16000], Rational[10789, 16000]}}, {{0.1, 0.7}, {
        0.1054375, 0.6743125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 10], Rational[3, 4]}, {
         Rational[333, 3200], Rational[921, 1280]}}, {{0.1, 0.75}, {0.1040625,
         0.71953125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 10], Rational[4, 5]}, {
         Rational[1643, 16000], Rational[6117, 8000]}}, {{0.1, 0.8}, {
        0.1026875, 0.764625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 10], Rational[17, 20]}, {
         Rational[1621, 16000], Rational[25907, 32000]}}, {{0.1, 0.85}, {
        0.1013125, 0.80959375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 10], Rational[9, 10]}, {
         Rational[1599, 16000], Rational[13671, 16000]}}, {{0.1, 0.9}, {
        0.0999375, 0.8544375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 10], Rational[19, 20]}, {
         Rational[1577, 16000], Rational[28773, 32000]}}, {{0.1, 0.95}, {
        0.0985625, 0.89915625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 10], 1}, {
         Rational[311, 3200], Rational[151, 160]}}, {{0.1, 1}, {0.0971875, 
         0.94375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 20], 0}, {
         Rational[2191, 12800], Rational[17, 640]}}, {{0.15, 0}, {0.171171875,
          0.0265625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 20], Rational[1, 20]}, {
         Rational[21749, 128000], Rational[9423, 128000]}}, {{0.15, 0.05}, {
        0.1699140625, 0.0736171875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 20], Rational[1, 10]}, {
         Rational[5397, 32000], Rational[1929, 16000]}}, {{0.15, 0.1}, {
        0.16865625, 0.1205625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 20], Rational[3, 20]}, {
         Rational[21427, 128000], Rational[21427, 128000]}}, {{0.15, 0.15}, {
        0.1673984375, 0.1673984375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 20], Rational[1, 5]}, {
         Rational[10633, 64000], Rational[1713, 8000]}}, {{0.15, 0.2}, {
        0.166140625, 0.214125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 20], Rational[1, 4]}, {
         Rational[4221, 25600], Rational[267, 1024]}}, {{0.15, 0.25}, {
        0.1648828125, 0.2607421875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 20], Rational[3, 10]}, {
         Rational[1309, 8000], Rational[1229, 4000]}}, {{0.15, 0.3}, {
        0.163625, 0.30725}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 20], Rational[7, 20]}, {
         Rational[20783, 128000], Rational[45267, 128000]}}, {{0.15, 0.35}, {
        0.1623671875, 0.3536484375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 20], Rational[2, 5]}, {
         Rational[10311, 64000], Rational[6399, 16000]}}, {{0.15, 0.4}, {
        0.161109375, 0.3999375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 20], Rational[9, 20]}, {
         Rational[20461, 128000], Rational[57103, 128000]}}, {{0.15, 0.45}, {
        0.1598515625, 0.4461171875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 20], Rational[1, 2]}, {
         Rational[203, 1280], Rational[63, 128]}}, {{0.15, 0.5}, {0.15859375, 
        0.4921875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 20], Rational[11, 20]}, {
         Rational[20139, 128000], Rational[68883, 128000]}}, {{0.15, 0.55}, {
        0.1573359375, 0.5381484375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 20], Rational[3, 5]}, {
         Rational[9989, 64000], Rational[73, 125]}}, {{0.15, 0.6}, {
        0.156078125, 0.584}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 20], Rational[13, 20]}, {
         Rational[19817, 128000], Rational[80607, 128000]}}, {{0.15, 0.65}, {
        0.1548203125, 0.6297421875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 20], Rational[7, 10]}, {
         Rational[2457, 16000], Rational[5403, 8000]}}, {{0.15, 0.7}, {
        0.1535625, 0.675375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 20], Rational[3, 4]}, {
         Rational[3899, 25600], Rational[3691, 5120]}}, {{0.15, 0.75}, {
        0.1523046875, 0.7208984375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 20], Rational[4, 5]}, {
         Rational[9667, 64000], Rational[12261, 16000]}}, {{0.15, 0.8}, {
        0.151046875, 0.7663125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 20], Rational[17, 20]}, {
         Rational[19173, 128000], Rational[103887, 128000]}}, {{0.15, 0.85}, {
        0.1497890625, 0.8116171875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 20], Rational[9, 10]}, {
         Rational[4753, 32000], Rational[13709, 16000]}}, {{0.15, 0.9}, {
        0.14853125, 0.8568125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 20], Rational[19, 20]}, {
         Rational[18851, 128000], Rational[115443, 128000]}}, {{0.15, 0.95}, {
        0.1472734375, 0.9018984375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 20], 1}, {
         Rational[1869, 12800], Rational[303, 320]}}, {{0.15, 1}, {
         0.146015625, 0.946875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 5], 0}, {
         Rational[87, 400], Rational[1, 40]}}, {{0.2, 0}, {0.2175, 
         0.025}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 5], Rational[1, 20]}, {
         Rational[1731, 8000], Rational[4617, 64000]}}, {{0.2, 0.05}, {
        0.216375, 0.072140625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 5], Rational[1, 10]}, {
         Rational[861, 4000], Rational[1907, 16000]}}, {{0.2, 0.1}, {0.21525, 
        0.1191875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 5], Rational[3, 20]}, {
         Rational[1713, 8000], Rational[10633, 64000]}}, {{0.2, 0.15}, {
        0.214125, 0.166140625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 5], Rational[1, 5]}, {
         Rational[213, 1000], Rational[213, 1000]}}, {{0.2, 0.2}, {0.213, 
        0.213}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 5], Rational[1, 4]}, {
         Rational[339, 1600], Rational[133, 512]}}, {{0.2, 0.25}, {0.211875, 
        0.259765625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 5], Rational[3, 10]}, {
         Rational[843, 4000], Rational[4903, 16000]}}, {{0.2, 0.3}, {0.21075, 
        0.3064375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 5], Rational[7, 20]}, {
         Rational[1677, 8000], Rational[22593, 64000]}}, {{0.2, 0.35}, {
        0.209625, 0.353015625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 5], Rational[2, 5]}, {
         Rational[417, 2000], Rational[799, 2000]}}, {{0.2, 0.4}, {0.2085, 
        0.3995}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 5], Rational[9, 20]}, {
         Rational[1659, 8000], Rational[28537, 64000]}}, {{0.2, 0.45}, {
        0.207375, 0.445890625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 5], Rational[1, 2]}, {
         Rational[33, 160], Rational[63, 128]}}, {{0.2, 0.5}, {0.20625, 
        0.4921875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 5], Rational[11, 20]}, {
         Rational[1641, 8000], Rational[34457, 64000]}}, {{0.2, 0.55}, {
        0.205125, 0.538390625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 5], Rational[3, 5]}, {
         Rational[51, 250], Rational[1169, 2000]}}, {{0.2, 0.6}, {0.204, 
        0.5845}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 5], Rational[13, 20]}, {
         Rational[1623, 8000], Rational[40353, 64000]}}, {{0.2, 0.65}, {
        0.202875, 0.630515625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 5], Rational[7, 10]}, {
         Rational[807, 4000], Rational[10823, 16000]}}, {{0.2, 0.7}, {0.20175,
         0.6764375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 5], Rational[3, 4]}, {
         Rational[321, 1600], Rational[1849, 2560]}}, {{0.2, 0.75}, {0.200625,
         0.722265625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 5], Rational[4, 5]}, {
         Rational[399, 2000], Rational[96, 125]}}, {{0.2, 0.8}, {0.1995, 
        0.768}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 5], Rational[17, 20]}, {
         Rational[1587, 8000], Rational[52073, 64000]}}, {{0.2, 0.85}, {
        0.198375, 0.813640625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 5], Rational[9, 10]}, {
         Rational[789, 4000], Rational[13747, 16000]}}, {{0.2, 0.9}, {0.19725,
         0.8591875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 5], Rational[19, 20]}, {
         Rational[1569, 8000], Rational[57897, 64000]}}, {{0.2, 0.95}, {
        0.196125, 0.904640625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 5], 1}, {
         Rational[39, 200], Rational[19, 20]}}, {{0.2, 1}, {0.195, 
         0.95}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 4], 0}, {
         Rational[135, 512], Rational[3, 128]}}, {{0.25, 0}, {0.263671875, 
         0.0234375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 4], Rational[1, 20]}, {
         Rational[269, 1024], Rational[1809, 25600]}}, {{0.25, 0.05}, {
        0.2626953125, 0.0706640625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 4], Rational[1, 10]}, {
         Rational[67, 256], Rational[377, 3200]}}, {{0.25, 0.1}, {0.26171875, 
        0.1178125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 4], Rational[3, 20]}, {
         Rational[267, 1024], Rational[4221, 25600]}}, {{0.25, 0.15}, {
        0.2607421875, 0.1648828125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 4], Rational[1, 5]}, {
         Rational[133, 512], Rational[339, 1600]}}, {{0.25, 0.2}, {
        0.259765625, 0.211875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 4], Rational[1, 4]}, {
         Rational[265, 1024], Rational[265, 1024]}}, {{0.25, 0.25}, {
        0.2587890625, 0.2587890625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 4], Rational[3, 10]}, {
         Rational[33, 128], Rational[489, 1600]}}, {{0.25, 0.3}, {0.2578125, 
        0.305625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 4], Rational[7, 20]}, {
         Rational[263, 1024], Rational[9021, 25600]}}, {{0.25, 0.35}, {
        0.2568359375, 0.3523828125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 4], Rational[2, 5]}, {
         Rational[131, 512], Rational[1277, 3200]}}, {{0.25, 0.4}, {
        0.255859375, 0.3990625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 4], Rational[9, 20]}, {
         Rational[261, 1024], Rational[11409, 25600]}}, {{0.25, 0.45}, {
        0.2548828125, 0.4456640625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 4], Rational[1, 2]}, {
         Rational[65, 256], Rational[63, 128]}}, {{0.25, 0.5}, {0.25390625, 
        0.4921875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 4], Rational[11, 20]}, {
         Rational[259, 1024], Rational[13789, 25600]}}, {{0.25, 0.55}, {
        0.2529296875, 0.5386328125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 4], Rational[3, 5]}, {
         Rational[129, 512], Rational[117, 200]}}, {{0.25, 0.6}, {0.251953125,
         0.585}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 4], Rational[13, 20]}, {
         Rational[257, 1024], Rational[16161, 25600]}}, {{0.25, 0.65}, {
        0.2509765625, 0.6312890625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 4], Rational[7, 10]}, {
         Rational[1, 4], Rational[271, 400]}}, {{0.25, 0.7}, {0.25, 
        0.6775}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 4], Rational[3, 4]}, {
         Rational[255, 1024], Rational[741, 1024]}}, {{0.25, 0.75}, {
        0.2490234375, 0.7236328125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 4], Rational[4, 5]}, {
         Rational[127, 512], Rational[2463, 3200]}}, {{0.25, 0.8}, {
        0.248046875, 0.7696875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 4], Rational[17, 20]}, {
         Rational[253, 1024], Rational[20881, 25600]}}, {{0.25, 0.85}, {
        0.2470703125, 0.8156640625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 4], Rational[9, 10]}, {
         Rational[63, 256], Rational[2757, 3200]}}, {{0.25, 0.9}, {0.24609375,
         0.8615625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 4], Rational[19, 20]}, {
         Rational[251, 1024], Rational[23229, 25600]}}, {{0.25, 0.95}, {
        0.2451171875, 0.9073828125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 4], 1}, {
         Rational[125, 512], Rational[61, 64]}}, {{0.25, 1}, {0.244140625, 
         0.953125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 10], 0}, {
         Rational[991, 3200], Rational[7, 320]}}, {{0.3, 0}, {0.3096875, 
         0.021875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 10], Rational[1, 20]}, {
         Rational[2471, 8000], Rational[1107, 16000]}}, {{0.3, 0.05}, {
        0.308875, 0.0691875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 10], Rational[1, 10]}, {
         Rational[4929, 16000], Rational[1863, 16000]}}, {{0.3, 0.1}, {
        0.3080625, 0.1164375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 10], Rational[3, 20]}, {
         Rational[1229, 4000], Rational[1309, 8000]}}, {{0.3, 0.15}, {0.30725,
         0.163625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 10], Rational[1, 5]}, {
         Rational[4903, 16000], Rational[843, 4000]}}, {{0.3, 0.2}, {
        0.3064375, 0.21075}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 10], Rational[1, 4]}, {
         Rational[489, 1600], Rational[33, 128]}}, {{0.3, 0.25}, {0.305625, 
        0.2578125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 10], Rational[3, 10]}, {
         Rational[4877, 16000], Rational[4877, 16000]}}, {{0.3, 0.3}, {
        0.3048125, 0.3048125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 10], Rational[7, 20]}, {
         Rational[38, 125], Rational[1407, 4000]}}, {{0.3, 0.35}, {0.304, 
        0.35175}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 10], Rational[2, 5]}, {
         Rational[4851, 16000], Rational[3189, 8000]}}, {{0.3, 0.4}, {
        0.3031875, 0.398625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 10], Rational[9, 20]}, {
         Rational[2419, 8000], Rational[7127, 16000]}}, {{0.3, 0.45}, {
        0.302375, 0.4454375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 10], Rational[1, 2]}, {
         Rational[193, 640], Rational[63, 128]}}, {{0.3, 0.5}, {0.3015625, 
        0.4921875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 10], Rational[11, 20]}, {
         Rational[1203, 4000], Rational[4311, 8000]}}, {{0.3, 0.55}, {0.30075,
         0.538875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 10], Rational[3, 5]}, {
         Rational[4799, 16000], Rational[1171, 2000]}}, {{0.3, 0.6}, {
        0.2999375, 0.5855}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 10], Rational[13, 20]}, {
         Rational[2393, 8000], Rational[10113, 16000]}}, {{0.3, 0.65}, {
        0.299125, 0.6320625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 10], Rational[7, 10]}, {
         Rational[4773, 16000], Rational[10857, 16000]}}, {{0.3, 0.7}, {
        0.2983125, 0.6785625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 10], Rational[3, 4]}, {
         Rational[119, 400], Rational[29, 40]}}, {{0.3, 0.75}, {0.2975, 
        0.725}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 10], Rational[4, 5]}, {
         Rational[4747, 16000], Rational[6171, 8000]}}, {{0.3, 0.8}, {
        0.2966875, 0.771375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 10], Rational[17, 20]}, {
         Rational[2367, 8000], Rational[13083, 16000]}}, {{0.3, 0.85}, {
        0.295875, 0.8176875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 10], Rational[9, 10]}, {
         Rational[4721, 16000], Rational[13823, 16000]}}, {{0.3, 0.9}, {
        0.2950625, 0.8639375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 10], Rational[19, 20]}, {
         Rational[1177, 4000], Rational[7281, 8000]}}, {{0.3, 0.95}, {0.29425,
         0.910125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 10], 1}, {
         Rational[939, 3200], Rational[153, 160]}}, {{0.3, 1}, {0.2934375, 
         0.95625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 20], 0}, {
         Rational[4551, 12800], Rational[13, 640]}}, {{0.35, 0}, {0.355546875,
          0.0203125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 20], Rational[1, 20]}, {
         Rational[45429, 128000], Rational[8667, 128000]}}, {{0.35, 0.05}, {
        0.3549140625, 0.0677109375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 20], Rational[1, 10]}, {
         Rational[11337, 32000], Rational[1841, 16000]}}, {{0.35, 0.1}, {
        0.35428125, 0.1150625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 20], Rational[3, 20]}, {
         Rational[45267, 128000], Rational[20783, 128000]}}, {{0.35, 0.15}, {
        0.3536484375, 0.1623671875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 20], Rational[1, 5]}, {
         Rational[22593, 64000], Rational[1677, 8000]}}, {{0.35, 0.2}, {
        0.353015625, 0.209625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 20], Rational[1, 4]}, {
         Rational[9021, 25600], Rational[263, 1024]}}, {{0.35, 0.25}, {
        0.3523828125, 0.2568359375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 20], Rational[3, 10]}, {
         Rational[1407, 4000], Rational[38, 125]}}, {{0.35, 0.3}, {0.35175, 
        0.304}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 20], Rational[7, 20]}, {
         Rational[44943, 128000], Rational[44943, 128000]}}, {{0.35, 0.35}, {
        0.3511171875, 0.3511171875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 20], Rational[2, 5]}, {
         Rational[22431, 64000], Rational[6371, 16000]}}, {{0.35, 0.4}, {
        0.350484375, 0.3981875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 20], Rational[9, 20]}, {
         Rational[44781, 128000], Rational[56987, 128000]}}, {{0.35, 0.45}, {
        0.3498515625, 0.4452109375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 20], Rational[1, 2]}, {
         Rational[447, 1280], Rational[63, 128]}}, {{0.35, 0.5}, {0.34921875, 
        0.4921875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 20], Rational[11, 20]}, {
         Rational[44619, 128000], Rational[69007, 128000]}}, {{0.35, 0.55}, {
        0.3485859375, 0.5391171875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 20], Rational[3, 5]}, {
         Rational[22269, 64000], Rational[293, 500]}}, {{0.35, 0.6}, {
        0.347953125, 0.586}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 20], Rational[13, 20]}, {
         Rational[44457, 128000], Rational[81003, 128000]}}, {{0.35, 0.65}, {
        0.3473203125, 0.6328359375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 20], Rational[7, 10]}, {
         Rational[5547, 16000], Rational[5437, 8000]}}, {{0.35, 0.7}, {
        0.3466875, 0.679625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 20], Rational[3, 4]}, {
         Rational[8859, 25600], Rational[3719, 5120]}}, {{0.35, 0.75}, {
        0.3460546875, 0.7263671875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 20], Rational[4, 5]}, {
         Rational[22107, 64000], Rational[12369, 16000]}}, {{0.35, 0.8}, {
        0.345421875, 0.7730625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 20], Rational[17, 20]}, {
         Rational[44133, 128000], Rational[104923, 128000]}}, {{0.35, 0.85}, {
        0.3447890625, 0.8197109375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 20], Rational[9, 10]}, {
         Rational[11013, 32000], Rational[13861, 16000]}}, {{0.35, 0.9}, {
        0.34415625, 0.8663125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 20], Rational[19, 20]}, {
         Rational[43971, 128000], Rational[116847, 128000]}}, {{0.35, 0.95}, {
        0.3435234375, 0.9128671875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 20], 1}, {
         Rational[4389, 12800], Rational[307, 320]}}, {{0.35, 1}, {
         0.342890625, 0.959375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[2, 5], 0}, {
         Rational[321, 800], Rational[3, 160]}}, {{0.4, 0}, {0.40125, 
         0.01875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[2, 5], Rational[1, 20]}, {
         Rational[6413, 16000], Rational[4239, 64000]}}, {{0.4, 0.05}, {
        0.4008125, 0.066234375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[2, 5], Rational[1, 10]}, {
         Rational[3203, 8000], Rational[1819, 16000]}}, {{0.4, 0.1}, {
        0.400375, 0.1136875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[2, 5], Rational[3, 20]}, {
         Rational[6399, 16000], Rational[10311, 64000]}}, {{0.4, 0.15}, {
        0.3999375, 0.161109375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[2, 5], Rational[1, 5]}, {
         Rational[799, 2000], Rational[417, 2000]}}, {{0.4, 0.2}, {0.3995, 
        0.2085}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[2, 5], Rational[1, 4]}, {
         Rational[1277, 3200], Rational[131, 512]}}, {{0.4, 0.25}, {0.3990625,
         0.255859375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[2, 5], Rational[3, 10]}, {
         Rational[3189, 8000], Rational[4851, 16000]}}, {{0.4, 0.3}, {
        0.398625, 0.3031875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[2, 5], Rational[7, 20]}, {
         Rational[6371, 16000], Rational[22431, 64000]}}, {{0.4, 0.35}, {
        0.3981875, 0.350484375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[2, 5], Rational[2, 5]}, {
         Rational[1591, 4000], Rational[1591, 4000]}}, {{0.4, 0.4}, {0.39775, 
        0.39775}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[2, 5], Rational[9, 20]}, {
         Rational[6357, 16000], Rational[28479, 64000]}}, {{0.4, 0.45}, {
        0.3973125, 0.444984375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[2, 5], Rational[1, 2]}, {
         Rational[127, 320], Rational[63, 128]}}, {{0.4, 0.5}, {0.396875, 
        0.4921875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[2, 5], Rational[11, 20]}, {
         Rational[6343, 16000], Rational[34519, 64000]}}, {{0.4, 0.55}, {
        0.3964375, 0.539359375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[2, 5], Rational[3, 5]}, {
         Rational[99, 250], Rational[1173, 2000]}}, {{0.4, 0.6}, {0.396, 
        0.5865}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[2, 5], Rational[13, 20]}, {
         Rational[6329, 16000], Rational[40551, 64000]}}, {{0.4, 0.65}, {
        0.3955625, 0.633609375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[2, 5], Rational[7, 10]}, {
         Rational[3161, 8000], Rational[10891, 16000]}}, {{0.4, 0.7}, {
        0.395125, 0.6806875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[2, 5], Rational[3, 4]}, {
         Rational[1263, 3200], Rational[1863, 2560]}}, {{0.4, 0.75}, {
        0.3946875, 0.727734375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[2, 5], Rational[4, 5]}, {
         Rational[1577, 4000], Rational[3099, 4000]}}, {{0.4, 0.8}, {0.39425, 
        0.77475}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[2, 5], Rational[17, 20]}, {
         Rational[6301, 16000], Rational[52591, 64000]}}, {{0.4, 0.85}, {
        0.3938125, 0.821734375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[2, 5], Rational[9, 10]}, {
         Rational[3147, 8000], Rational[13899, 16000]}}, {{0.4, 0.9}, {
        0.393375, 0.8686875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[2, 5], Rational[19, 20]}, {
         Rational[6287, 16000], Rational[58599, 64000]}}, {{0.4, 0.95}, {
        0.3929375, 0.915609375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[2, 5], 1}, {
         Rational[157, 400], Rational[77, 80]}}, {{0.4, 1}, {0.3925, 
         0.9625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 20], 0}, {
         Rational[5719, 12800], Rational[11, 640]}}, {{0.45, 0}, {0.446796875,
          0.0171875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 20], Rational[1, 20]}, {
         Rational[57161, 128000], Rational[8289, 128000]}}, {{0.45, 0.05}, {
        0.4465703125, 0.0647578125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 20], Rational[1, 10]}, {
         Rational[14283, 32000], Rational[1797, 16000]}}, {{0.45, 0.1}, {
        0.44634375, 0.1123125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 20], Rational[3, 20]}, {
         Rational[57103, 128000], Rational[20461, 128000]}}, {{0.45, 0.15}, {
        0.4461171875, 0.1598515625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 20], Rational[1, 5]}, {
         Rational[28537, 64000], Rational[1659, 8000]}}, {{0.45, 0.2}, {
        0.445890625, 0.207375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 20], Rational[1, 4]}, {
         Rational[11409, 25600], Rational[261, 1024]}}, {{0.45, 0.25}, {
        0.4456640625, 0.2548828125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 20], Rational[3, 10]}, {
         Rational[7127, 16000], Rational[2419, 8000]}}, {{0.45, 0.3}, {
        0.4454375, 0.302375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 20], Rational[7, 20]}, {
         Rational[56987, 128000], Rational[44781, 128000]}}, {{0.45, 0.35}, {
        0.4452109375, 0.3498515625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 20], Rational[2, 5]}, {
         Rational[28479, 64000], Rational[6357, 16000]}}, {{0.45, 0.4}, {
        0.444984375, 0.3973125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 20], Rational[9, 20]}, {
         Rational[56929, 128000], Rational[56929, 128000]}}, {{0.45, 0.45}, {
        0.4447578125, 0.4447578125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 20], Rational[1, 2]}, {
         Rational[569, 1280], Rational[63, 128]}}, {{0.45, 0.5}, {0.44453125, 
        0.4921875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 20], Rational[11, 20]}, {
         Rational[56871, 128000], Rational[69069, 128000]}}, {{0.45, 0.55}, {
        0.4443046875, 0.5396015625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 20], Rational[3, 5]}, {
         Rational[28421, 64000], Rational[587, 1000]}}, {{0.45, 0.6}, {
        0.444078125, 0.587}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[
       NCache[{{Rational[9, 20], Rational[13, 20]}, {
         Rational[56813, 128000], Rational[81201, 128000]}}, {{0.45, 0.65}, {
        0.4438515625, 0.6343828125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 20], Rational[7, 10]}, {
         Rational[3549, 8000], Rational[2727, 4000]}}, {{0.45, 0.7}, {
        0.443625, 0.68175}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 20], Rational[3, 4]}, {
         Rational[11351, 25600], Rational[3733, 5120]}}, {{0.45, 0.75}, {
        0.4433984375, 0.7291015625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 20], Rational[4, 5]}, {
         Rational[28363, 64000], Rational[12423, 16000]}}, {{0.45, 0.8}, {
        0.443171875, 0.7764375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 20], Rational[17, 20]}, {
         Rational[56697, 128000], Rational[105441, 128000]}}, {{0.45, 0.85}, {
        0.4429453125, 0.8237578125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 20], Rational[9, 10]}, {
         Rational[14167, 32000], Rational[13937, 16000]}}, {{0.45, 0.9}, {
        0.44271875, 0.8710625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 20], Rational[19, 20]}, {
         Rational[56639, 128000], Rational[117549, 128000]}}, {{0.45, 0.95}, {
        0.4424921875, 0.9183515625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 20], 1}, {
         Rational[5661, 12800], Rational[309, 320]}}, {{0.45, 1}, {
         0.442265625, 0.965625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 2], 0}, {
         Rational[63, 128], Rational[1, 64]}}, {{0.5, 0}, {0.4921875, 
         0.015625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 2], Rational[1, 20]}, {
         Rational[63, 128], Rational[81, 1280]}}, {{0.5, 0.05}, {0.4921875, 
        0.06328125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 2], Rational[1, 10]}, {
         Rational[63, 128], Rational[71, 640]}}, {{0.5, 0.1}, {0.4921875, 
        0.1109375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[
       NCache[{{Rational[1, 2], Rational[3, 20]}, {
         Rational[63, 128], Rational[203, 1280]}}, {{0.5, 0.15}, {0.4921875, 
        0.15859375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 2], Rational[1, 5]}, {
         Rational[63, 128], Rational[33, 160]}}, {{0.5, 0.2}, {0.4921875, 
        0.20625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 2], Rational[1, 4]}, {
         Rational[63, 128], Rational[65, 256]}}, {{0.5, 0.25}, {0.4921875, 
        0.25390625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 2], Rational[3, 10]}, {
         Rational[63, 128], Rational[193, 640]}}, {{0.5, 0.3}, {0.4921875, 
        0.3015625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 2], Rational[7, 20]}, {
         Rational[63, 128], Rational[447, 1280]}}, {{0.5, 0.35}, {0.4921875, 
        0.34921875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 2], Rational[2, 5]}, {
         Rational[63, 128], Rational[127, 320]}}, {{0.5, 0.4}, {0.4921875, 
        0.396875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 2], Rational[9, 20]}, {
         Rational[63, 128], Rational[569, 1280]}}, {{0.5, 0.45}, {0.4921875, 
        0.44453125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 2], Rational[1, 2]}, {
         Rational[63, 128], Rational[63, 128]}}, {{0.5, 0.5}, {0.4921875, 
        0.4921875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 2], Rational[11, 20]}, {
         Rational[63, 128], Rational[691, 1280]}}, {{0.5, 0.55}, {0.4921875, 
        0.53984375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 2], Rational[3, 5]}, {
         Rational[63, 128], Rational[47, 80]}}, {{0.5, 0.6}, {0.4921875, 
        0.5875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 2], Rational[13, 20]}, {
         Rational[63, 128], Rational[813, 1280]}}, {{0.5, 0.65}, {0.4921875, 
        0.63515625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 2], Rational[7, 10]}, {
         Rational[63, 128], Rational[437, 640]}}, {{0.5, 0.7}, {0.4921875, 
        0.6828125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 2], Rational[3, 4]}, {
         Rational[63, 128], Rational[187, 256]}}, {{0.5, 0.75}, {0.4921875, 
        0.73046875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 2], Rational[4, 5]}, {
         Rational[63, 128], Rational[249, 320]}}, {{0.5, 0.8}, {0.4921875, 
        0.778125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 2], Rational[17, 20]}, {
         Rational[63, 128], Rational[1057, 1280]}}, {{0.5, 0.85}, {0.4921875, 
        0.82578125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 2], Rational[9, 10]}, {
         Rational[63, 128], Rational[559, 640]}}, {{0.5, 0.9}, {0.4921875, 
        0.8734375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 2], Rational[19, 20]}, {
         Rational[63, 128], Rational[1179, 1280]}}, {{0.5, 0.95}, {0.4921875, 
        0.92109375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[1, 2], 1}, {
         Rational[63, 128], Rational[31, 32]}}, {{0.5, 1}, {0.4921875, 
         0.96875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[11, 20], 0}, {
         Rational[6879, 12800], Rational[9, 640]}}, {{0.55, 0}, {0.537421875, 
         0.0140625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[11, 20], Rational[1, 20]}, {
         Rational[68821, 128000], Rational[7911, 128000]}}, {{0.55, 0.05}, {
        0.5376640625, 0.0618046875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[11, 20], Rational[1, 10]}, {
         Rational[17213, 32000], Rational[1753, 16000]}}, {{0.55, 0.1}, {
        0.53790625, 0.1095625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[11, 20], Rational[3, 20]}, {
         Rational[68883, 128000], Rational[20139, 128000]}}, {{0.55, 0.15}, {
        0.5381484375, 0.1573359375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[11, 20], Rational[1, 5]}, {
         Rational[34457, 64000], Rational[1641, 8000]}}, {{0.55, 0.2}, {
        0.538390625, 0.205125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[
       NCache[{{Rational[11, 20], Rational[1, 4]}, {
         Rational[13789, 25600], Rational[259, 1024]}}, {{0.55, 0.25}, {
        0.5386328125, 0.2529296875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[11, 20], Rational[3, 10]}, {
         Rational[4311, 8000], Rational[1203, 4000]}}, {{0.55, 0.3}, {
        0.538875, 0.30075}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[11, 20], Rational[7, 20]}, {
         Rational[69007, 128000], Rational[44619, 128000]}}, {{0.55, 0.35}, {
        0.5391171875, 0.3485859375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[11, 20], Rational[2, 5]}, {
         Rational[34519, 64000], Rational[6343, 16000]}}, {{0.55, 0.4}, {
        0.539359375, 0.3964375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[11, 20], Rational[9, 20]}, {
         Rational[69069, 128000], Rational[56871, 128000]}}, {{0.55, 0.45}, {
        0.5396015625, 0.4443046875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[11, 20], Rational[1, 2]}, {
         Rational[691, 1280], Rational[63, 128]}}, {{0.55, 0.5}, {0.53984375, 
        0.4921875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[11, 20], Rational[11, 20]}, {
         Rational[69131, 128000], Rational[69131, 128000]}}, {{0.55, 0.55}, {
        0.5400859375, 0.5400859375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[11, 20], Rational[3, 5]}, {
         Rational[34581, 64000], Rational[147, 250]}}, {{0.55, 0.6}, {
        0.540328125, 0.588}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[11, 20], Rational[13, 20]}, {
         Rational[69193, 128000], Rational[81399, 128000]}}, {{0.55, 0.65}, {
        0.5405703125, 0.6359296875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[11, 20], Rational[7, 10]}, {
         Rational[8653, 16000], Rational[5471, 8000]}}, {{0.55, 0.7}, {
        0.5408125, 0.683875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[11, 20], Rational[3, 4]}, {
         Rational[13851, 25600], Rational[3747, 5120]}}, {{0.55, 0.75}, {
        0.5410546875, 0.7318359375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[11, 20], Rational[4, 5]}, {
         Rational[34643, 64000], Rational[12477, 16000]}}, {{0.55, 0.8}, {
        0.541296875, 0.7798125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[11, 20], Rational[17, 20]}, {
         Rational[69317, 128000], Rational[105959, 128000]}}, {{0.55, 0.85}, {
        0.5415390625, 0.8278046875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[11, 20], Rational[9, 10]}, {
         Rational[17337, 32000], Rational[14013, 16000]}}, {{0.55, 0.9}, {
        0.54178125, 0.8758125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[11, 20], Rational[19, 20]}, {
         Rational[69379, 128000], Rational[118251, 128000]}}, {{0.55, 0.95}, {
        0.5420234375, 0.9238359375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[11, 20], 1}, {
         Rational[6941, 12800], Rational[311, 320]}}, {{0.55, 1}, {
         0.542265625, 0.971875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 5], 0}, {
         Rational[233, 400], Rational[1, 80]}}, {{0.6, 0}, {0.5825, 
         0.0125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 5], Rational[1, 20]}, {
         Rational[583, 1000], Rational[3861, 64000]}}, {{0.6, 0.05}, {0.583, 
        0.060328125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 5], Rational[1, 10]}, {
         Rational[1167, 2000], Rational[1731, 16000]}}, {{0.6, 0.1}, {0.5835, 
        0.1081875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 5], Rational[3, 20]}, {
         Rational[73, 125], Rational[9989, 64000]}}, {{0.6, 0.15}, {0.584, 
        0.156078125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 5], Rational[1, 5]}, {
         Rational[1169, 2000], Rational[51, 250]}}, {{0.6, 0.2}, {0.5845, 
        0.204}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 5], Rational[1, 4]}, {
         Rational[117, 200], Rational[129, 512]}}, {{0.6, 0.25}, {0.585, 
        0.251953125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 5], Rational[3, 10]}, {
         Rational[1171, 2000], Rational[4799, 16000]}}, {{0.6, 0.3}, {0.5855, 
        0.2999375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 5], Rational[7, 20]}, {
         Rational[293, 500], Rational[22269, 64000]}}, {{0.6, 0.35}, {0.586, 
        0.347953125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 5], Rational[2, 5]}, {
         Rational[1173, 2000], Rational[99, 250]}}, {{0.6, 0.4}, {0.5865, 
        0.396}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 5], Rational[9, 20]}, {
         Rational[587, 1000], Rational[28421, 64000]}}, {{0.6, 0.45}, {0.587, 
        0.444078125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 5], Rational[1, 2]}, {
         Rational[47, 80], Rational[63, 128]}}, {{0.6, 0.5}, {0.5875, 
        0.4921875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 5], Rational[11, 20]}, {
         Rational[147, 250], Rational[34581, 64000]}}, {{0.6, 0.55}, {0.588, 
        0.540328125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 5], Rational[3, 5]}, {
         Rational[1177, 2000], Rational[1177, 2000]}}, {{0.6, 0.6}, {0.5885, 
        0.5885}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 5], Rational[13, 20]}, {
         Rational[589, 1000], Rational[40749, 64000]}}, {{0.6, 0.65}, {0.589, 
        0.636703125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 5], Rational[7, 10]}, {
         Rational[1179, 2000], Rational[10959, 16000]}}, {{0.6, 0.7}, {0.5895,
         0.6849375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 5], Rational[3, 4]}, {
         Rational[59, 100], Rational[1877, 2560]}}, {{0.6, 0.75}, {0.59, 
        0.733203125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 5], Rational[4, 5]}, {
         Rational[1181, 2000], Rational[1563, 2000]}}, {{0.6, 0.8}, {0.5905, 
        0.7815}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 5], Rational[17, 20]}, {
         Rational[591, 1000], Rational[53109, 64000]}}, {{0.6, 0.85}, {0.591, 
        0.829828125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 5], Rational[9, 10]}, {
         Rational[1183, 2000], Rational[14051, 16000]}}, {{0.6, 0.9}, {0.5915,
         0.8781875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 5], Rational[19, 20]}, {
         Rational[74, 125], Rational[59301, 64000]}}, {{0.6, 0.95}, {0.592, 
        0.926578125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 5], 1}, {
         Rational[237, 400], Rational[39, 40]}}, {{0.6, 1}, {0.5925, 
         0.975}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[13, 20], 0}, {
         Rational[8031, 12800], Rational[7, 640]}}, {{0.65, 0}, {0.627421875, 
         0.0109375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[13, 20], Rational[1, 20]}, {
         Rational[80409, 128000], Rational[7533, 128000]}}, {{0.65, 0.05}, {
        0.6281953125, 0.0588515625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[13, 20], Rational[1, 10]}, {
         Rational[20127, 32000], Rational[1709, 16000]}}, {{0.65, 0.1}, {
        0.62896875, 0.1068125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[13, 20], Rational[3, 20]}, {
         Rational[80607, 128000], Rational[19817, 128000]}}, {{0.65, 0.15}, {
        0.6297421875, 0.1548203125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[13, 20], Rational[1, 5]}, {
         Rational[40353, 64000], Rational[1623, 8000]}}, {{0.65, 0.2}, {
        0.630515625, 0.202875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[13, 20], Rational[1, 4]}, {
         Rational[16161, 25600], Rational[257, 1024]}}, {{0.65, 0.25}, {
        0.6312890625, 0.2509765625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[13, 20], Rational[3, 10]}, {
         Rational[10113, 16000], Rational[2393, 8000]}}, {{0.65, 0.3}, {
        0.6320625, 0.299125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[13, 20], Rational[7, 20]}, {
         Rational[81003, 128000], Rational[44457, 128000]}}, {{0.65, 0.35}, {
        0.6328359375, 0.3473203125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[13, 20], Rational[2, 5]}, {
         Rational[40551, 64000], Rational[6329, 16000]}}, {{0.65, 0.4}, {
        0.633609375, 0.3955625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[13, 20], Rational[9, 20]}, {
         Rational[81201, 128000], Rational[56813, 128000]}}, {{0.65, 0.45}, {
        0.6343828125, 0.4438515625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[13, 20], Rational[1, 2]}, {
         Rational[813, 1280], Rational[63, 128]}}, {{0.65, 0.5}, {0.63515625, 
        0.4921875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[13, 20], Rational[11, 20]}, {
         Rational[81399, 128000], Rational[69193, 128000]}}, {{0.65, 0.55}, {
        0.6359296875, 0.5405703125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[13, 20], Rational[3, 5]}, {
         Rational[40749, 64000], Rational[589, 1000]}}, {{0.65, 0.6}, {
        0.636703125, 0.589}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[13, 20], Rational[13, 20]}, {
         Rational[81597, 128000], Rational[81597, 128000]}}, {{0.65, 0.65}, {
        0.6374765625, 0.6374765625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[13, 20], Rational[7, 10]}, {
         Rational[2553, 4000], Rational[343, 500]}}, {{0.65, 0.7}, {0.63825, 
        0.686}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[13, 20], Rational[3, 4]}, {
         Rational[16359, 25600], Rational[3761, 5120]}}, {{0.65, 0.75}, {
        0.6390234375, 0.7345703125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[13, 20], Rational[4, 5]}, {
         Rational[40947, 64000], Rational[12531, 16000]}}, {{0.65, 0.8}, {
        0.639796875, 0.7831875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[13, 20], Rational[17, 20]}, {
         Rational[81993, 128000], Rational[106477, 128000]}}, {{0.65, 0.85}, {
        0.6405703125, 0.8318515625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[13, 20], Rational[9, 10]}, {
         Rational[20523, 32000], Rational[14089, 16000]}}, {{0.65, 0.9}, {
        0.64134375, 0.8805625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[13, 20], Rational[19, 20]}, {
         Rational[82191, 128000], Rational[118953, 128000]}}, {{0.65, 0.95}, {
        0.6421171875, 0.9293203125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[13, 20], 1}, {
         Rational[8229, 12800], Rational[313, 320]}}, {{0.65, 1}, {
         0.642890625, 0.978125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 10], 0}, {
         Rational[2151, 3200], Rational[3, 320]}}, {{0.7, 0}, {0.6721875, 
         0.009375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 10], Rational[1, 20]}, {
         Rational[2693, 4000], Rational[459, 8000]}}, {{0.7, 0.05}, {0.67325, 
        0.057375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 10], Rational[1, 10]}, {
         Rational[10789, 16000], Rational[1687, 16000]}}, {{0.7, 0.1}, {
        0.6743125, 0.1054375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 10], Rational[3, 20]}, {
         Rational[5403, 8000], Rational[2457, 16000]}}, {{0.7, 0.15}, {
        0.675375, 0.1535625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 10], Rational[1, 5]}, {
         Rational[10823, 16000], Rational[807, 4000]}}, {{0.7, 0.2}, {
        0.6764375, 0.20175}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 10], Rational[1, 4]}, {
         Rational[271, 400], Rational[1, 4]}}, {{0.7, 0.25}, {0.6775, 
        0.25}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 10], Rational[3, 10]}, {
         Rational[10857, 16000], Rational[4773, 16000]}}, {{0.7, 0.3}, {
        0.6785625, 0.2983125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 10], Rational[7, 20]}, {
         Rational[5437, 8000], Rational[5547, 16000]}}, {{0.7, 0.35}, {
        0.679625, 0.3466875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 10], Rational[2, 5]}, {
         Rational[10891, 16000], Rational[3161, 8000]}}, {{0.7, 0.4}, {
        0.6806875, 0.395125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 10], Rational[9, 20]}, {
         Rational[2727, 4000], Rational[3549, 8000]}}, {{0.7, 0.45}, {0.68175,
         0.443625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 10], Rational[1, 2]}, {
         Rational[437, 640], Rational[63, 128]}}, {{0.7, 0.5}, {0.6828125, 
        0.4921875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 10], Rational[11, 20]}, {
         Rational[5471, 8000], Rational[8653, 16000]}}, {{0.7, 0.55}, {
        0.683875, 0.5408125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 10], Rational[3, 5]}, {
         Rational[10959, 16000], Rational[1179, 2000]}}, {{0.7, 0.6}, {
        0.6849375, 0.5895}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 10], Rational[13, 20]}, {
         Rational[343, 500], Rational[2553, 4000]}}, {{0.7, 0.65}, {0.686, 
        0.63825}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 10], Rational[7, 10]}, {
         Rational[10993, 16000], Rational[10993, 16000]}}, {{0.7, 0.7}, {
        0.6870625, 0.6870625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 10], Rational[3, 4]}, {
         Rational[1101, 1600], Rational[471, 640]}}, {{0.7, 0.75}, {0.688125, 
        0.7359375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 10], Rational[4, 5]}, {
         Rational[11027, 16000], Rational[6279, 8000]}}, {{0.7, 0.8}, {
        0.6891875, 0.784875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 10], Rational[17, 20]}, {
         Rational[2761, 4000], Rational[6671, 8000]}}, {{0.7, 0.85}, {0.69025,
         0.833875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 10], Rational[9, 10]}, {
         Rational[11061, 16000], Rational[14127, 16000]}}, {{0.7, 0.9}, {
        0.6913125, 0.8829375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 10], Rational[19, 20]}, {
         Rational[5539, 8000], Rational[14913, 16000]}}, {{0.7, 0.95}, {
        0.692375, 0.9320625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[7, 10], 1}, {
         Rational[2219, 3200], Rational[157, 160]}}, {{0.7, 1}, {0.6934375, 
         0.98125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 4], 0}, {
         Rational[367, 512], Rational[1, 128]}}, {{0.75, 0}, {0.716796875, 
         0.0078125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 4], Rational[1, 20]}, {
         Rational[3677, 5120], Rational[1431, 25600]}}, {{0.75, 0.05}, {
        0.7181640625, 0.0558984375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 4], Rational[1, 10]}, {
         Rational[921, 1280], Rational[333, 3200]}}, {{0.75, 0.1}, {
        0.71953125, 0.1040625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 4], Rational[3, 20]}, {
         Rational[3691, 5120], Rational[3899, 25600]}}, {{0.75, 0.15}, {
        0.7208984375, 0.1523046875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 4], Rational[1, 5]}, {
         Rational[1849, 2560], Rational[321, 1600]}}, {{0.75, 0.2}, {
        0.722265625, 0.200625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 4], Rational[1, 4]}, {
         Rational[741, 1024], Rational[255, 1024]}}, {{0.75, 0.25}, {
        0.7236328125, 0.2490234375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 4], Rational[3, 10]}, {
         Rational[29, 40], Rational[119, 400]}}, {{0.75, 0.3}, {0.725, 
        0.2975}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 4], Rational[7, 20]}, {
         Rational[3719, 5120], Rational[8859, 25600]}}, {{0.75, 0.35}, {
        0.7263671875, 0.3460546875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 4], Rational[2, 5]}, {
         Rational[1863, 2560], Rational[1263, 3200]}}, {{0.75, 0.4}, {
        0.727734375, 0.3946875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 4], Rational[9, 20]}, {
         Rational[3733, 5120], Rational[11351, 25600]}}, {{0.75, 0.45}, {
        0.7291015625, 0.4433984375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 4], Rational[1, 2]}, {
         Rational[187, 256], Rational[63, 128]}}, {{0.75, 0.5}, {0.73046875, 
        0.4921875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 4], Rational[11, 20]}, {
         Rational[3747, 5120], Rational[13851, 25600]}}, {{0.75, 0.55}, {
        0.7318359375, 0.5410546875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 4], Rational[3, 5]}, {
         Rational[1877, 2560], Rational[59, 100]}}, {{0.75, 0.6}, {
        0.733203125, 0.59}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 4], Rational[13, 20]}, {
         Rational[3761, 5120], Rational[16359, 25600]}}, {{0.75, 0.65}, {
        0.7345703125, 0.6390234375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 4], Rational[7, 10]}, {
         Rational[471, 640], Rational[1101, 1600]}}, {{0.75, 0.7}, {0.7359375,
         0.688125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 4], Rational[3, 4]}, {
         Rational[755, 1024], Rational[755, 1024]}}, {{0.75, 0.75}, {
        0.7373046875, 0.7373046875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 4], Rational[4, 5]}, {
         Rational[1891, 2560], Rational[2517, 3200]}}, {{0.75, 0.8}, {
        0.738671875, 0.7865625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 4], Rational[17, 20]}, {
         Rational[3789, 5120], Rational[21399, 25600]}}, {{0.75, 0.85}, {
        0.7400390625, 0.8358984375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 4], Rational[9, 10]}, {
         Rational[949, 1280], Rational[2833, 3200]}}, {{0.75, 0.9}, {
        0.74140625, 0.8853125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 4], Rational[19, 20]}, {
         Rational[3803, 5120], Rational[23931, 25600]}}, {{0.75, 0.95}, {
        0.7427734375, 0.9348046875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[3, 4], 1}, {
         Rational[381, 512], Rational[63, 64]}}, {{0.75, 1}, {0.744140625, 
         0.984375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[4, 5], 0}, {
         Rational[609, 800], Rational[1, 160]}}, {{0.8, 0}, {0.76125, 
         0.00625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[4, 5], Rational[1, 20]}, {
         Rational[12207, 16000], Rational[3483, 64000]}}, {{0.8, 0.05}, {
        0.7629375, 0.054421875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[4, 5], Rational[1, 10]}, {
         Rational[6117, 8000], Rational[1643, 16000]}}, {{0.8, 0.1}, {
        0.764625, 0.1026875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[4, 5], Rational[3, 20]}, {
         Rational[12261, 16000], Rational[9667, 64000]}}, {{0.8, 0.15}, {
        0.7663125, 0.151046875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[4, 5], Rational[1, 5]}, {
         Rational[96, 125], Rational[399, 2000]}}, {{0.8, 0.2}, {0.768, 
        0.1995}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[4, 5], Rational[1, 4]}, {
         Rational[2463, 3200], Rational[127, 512]}}, {{0.8, 0.25}, {0.7696875,
         0.248046875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[4, 5], Rational[3, 10]}, {
         Rational[6171, 8000], Rational[4747, 16000]}}, {{0.8, 0.3}, {
        0.771375, 0.2966875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[4, 5], Rational[7, 20]}, {
         Rational[12369, 16000], Rational[22107, 64000]}}, {{0.8, 0.35}, {
        0.7730625, 0.345421875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[4, 5], Rational[2, 5]}, {
         Rational[3099, 4000], Rational[1577, 4000]}}, {{0.8, 0.4}, {0.77475, 
        0.39425}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[4, 5], Rational[9, 20]}, {
         Rational[12423, 16000], Rational[28363, 64000]}}, {{0.8, 0.45}, {
        0.7764375, 0.443171875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[4, 5], Rational[1, 2]}, {
         Rational[249, 320], Rational[63, 128]}}, {{0.8, 0.5}, {0.778125, 
        0.4921875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[4, 5], Rational[11, 20]}, {
         Rational[12477, 16000], Rational[34643, 64000]}}, {{0.8, 0.55}, {
        0.7798125, 0.541296875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[4, 5], Rational[3, 5]}, {
         Rational[1563, 2000], Rational[1181, 2000]}}, {{0.8, 0.6}, {0.7815, 
        0.5905}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[4, 5], Rational[13, 20]}, {
         Rational[12531, 16000], Rational[40947, 64000]}}, {{0.8, 0.65}, {
        0.7831875, 0.639796875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[4, 5], Rational[7, 10]}, {
         Rational[6279, 8000], Rational[11027, 16000]}}, {{0.8, 0.7}, {
        0.784875, 0.6891875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[4, 5], Rational[3, 4]}, {
         Rational[2517, 3200], Rational[1891, 2560]}}, {{0.8, 0.75}, {
        0.7865625, 0.738671875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[4, 5], Rational[4, 5]}, {
         Rational[3153, 4000], Rational[3153, 4000]}}, {{0.8, 0.8}, {0.78825, 
        0.78825}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[4, 5], Rational[17, 20]}, {
         Rational[12639, 16000], Rational[53627, 64000]}}, {{0.8, 0.85}, {
        0.7899375, 0.837921875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[4, 5], Rational[9, 10]}, {
         Rational[6333, 8000], Rational[14203, 16000]}}, {{0.8, 0.9}, {
        0.791625, 0.8876875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[4, 5], Rational[19, 20]}, {
         Rational[12693, 16000], Rational[60003, 64000]}}, {{0.8, 0.95}, {
        0.7933125, 0.937546875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[4, 5], 1}, {
         Rational[159, 200], Rational[79, 80]}}, {{0.8, 1}, {0.795, 
         0.9875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[17, 20], 0}, {
         Rational[10311, 12800], Rational[3, 640]}}, {{0.85, 0}, {0.805546875,
          0.0046875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[17, 20], Rational[1, 20]}, {
         Rational[103369, 128000], Rational[6777, 128000]}}, {{0.85, 0.05}, {
        0.8075703125, 0.0529453125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[17, 20], Rational[1, 10]}, {
         Rational[25907, 32000], Rational[1621, 16000]}}, {{0.85, 0.1}, {
        0.80959375, 0.1013125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[17, 20], Rational[3, 20]}, {
         Rational[103887, 128000], Rational[19173, 128000]}}, {{0.85, 0.15}, {
        0.8116171875, 0.1497890625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[17, 20], Rational[1, 5]}, {
         Rational[52073, 64000], Rational[1587, 8000]}}, {{0.85, 0.2}, {
        0.813640625, 0.198375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[17, 20], Rational[1, 4]}, {
         Rational[20881, 25600], Rational[253, 1024]}}, {{0.85, 0.25}, {
        0.8156640625, 0.2470703125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[17, 20], Rational[3, 10]}, {
         Rational[13083, 16000], Rational[2367, 8000]}}, {{0.85, 0.3}, {
        0.8176875, 0.295875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[17, 20], Rational[7, 20]}, {
         Rational[104923, 128000], Rational[44133, 128000]}}, {{0.85, 0.35}, {
        0.8197109375, 0.3447890625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[17, 20], Rational[2, 5]}, {
         Rational[52591, 64000], Rational[6301, 16000]}}, {{0.85, 0.4}, {
        0.821734375, 0.3938125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[17, 20], Rational[9, 20]}, {
         Rational[105441, 128000], Rational[56697, 128000]}}, {{0.85, 0.45}, {
        0.8237578125, 0.4429453125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[17, 20], Rational[1, 2]}, {
         Rational[1057, 1280], Rational[63, 128]}}, {{0.85, 0.5}, {0.82578125,
         0.4921875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[17, 20], Rational[11, 20]}, {
         Rational[105959, 128000], Rational[69317, 128000]}}, {{0.85, 0.55}, {
        0.8278046875, 0.5415390625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[17, 20], Rational[3, 5]}, {
         Rational[53109, 64000], Rational[591, 1000]}}, {{0.85, 0.6}, {
        0.829828125, 0.591}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[17, 20], Rational[13, 20]}, {
         Rational[106477, 128000], Rational[81993, 128000]}}, {{0.85, 0.65}, {
        0.8318515625, 0.6405703125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[17, 20], Rational[7, 10]}, {
         Rational[6671, 8000], Rational[2761, 4000]}}, {{0.85, 0.7}, {
        0.833875, 0.69025}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[17, 20], Rational[3, 4]}, {
         Rational[21399, 25600], Rational[3789, 5120]}}, {{0.85, 0.75}, {
        0.8358984375, 0.7400390625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[17, 20], Rational[4, 5]}, {
         Rational[53627, 64000], Rational[12639, 16000]}}, {{0.85, 0.8}, {
        0.837921875, 0.7899375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[17, 20], Rational[17, 20]}, {
         Rational[107513, 128000], Rational[107513, 128000]}}, {{0.85, 
        0.85}, {0.8399453125, 0.8399453125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[17, 20], Rational[9, 10]}, {
         Rational[26943, 32000], Rational[14241, 16000]}}, {{0.85, 0.9}, {
        0.84196875, 0.8900625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[17, 20], Rational[19, 20]}, {
         Rational[108031, 128000], Rational[120357, 128000]}}, {{0.85, 
        0.95}, {0.8439921875, 0.9402890625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[17, 20], 1}, {
         Rational[10829, 12800], Rational[317, 320]}}, {{0.85, 1}, {
         0.846015625, 0.990625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 10], 0}, {
         Rational[2719, 3200], Rational[1, 320]}}, {{0.9, 0}, {0.8496875, 
         0.003125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 10], Rational[1, 20]}, {
         Rational[13633, 16000], Rational[1647, 32000]}}, {{0.9, 0.05}, {
        0.8520625, 0.05146875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 10], Rational[1, 10]}, {
         Rational[13671, 16000], Rational[1599, 16000]}}, {{0.9, 0.1}, {
        0.8544375, 0.0999375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 10], Rational[3, 20]}, {
         Rational[13709, 16000], Rational[4753, 32000]}}, {{0.9, 0.15}, {
        0.8568125, 0.14853125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 10], Rational[1, 5]}, {
         Rational[13747, 16000], Rational[789, 4000]}}, {{0.9, 0.2}, {
        0.8591875, 0.19725}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 10], Rational[1, 4]}, {
         Rational[2757, 3200], Rational[63, 256]}}, {{0.9, 0.25}, {0.8615625, 
        0.24609375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 10], Rational[3, 10]}, {
         Rational[13823, 16000], Rational[4721, 16000]}}, {{0.9, 0.3}, {
        0.8639375, 0.2950625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 10], Rational[7, 20]}, {
         Rational[13861, 16000], Rational[11013, 32000]}}, {{0.9, 0.35}, {
        0.8663125, 0.34415625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 10], Rational[2, 5]}, {
         Rational[13899, 16000], Rational[3147, 8000]}}, {{0.9, 0.4}, {
        0.8686875, 0.393375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 10], Rational[9, 20]}, {
         Rational[13937, 16000], Rational[14167, 32000]}}, {{0.9, 0.45}, {
        0.8710625, 0.44271875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 10], Rational[1, 2]}, {
         Rational[559, 640], Rational[63, 128]}}, {{0.9, 0.5}, {0.8734375, 
        0.4921875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 10], Rational[11, 20]}, {
         Rational[14013, 16000], Rational[17337, 32000]}}, {{0.9, 0.55}, {
        0.8758125, 0.54178125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 10], Rational[3, 5]}, {
         Rational[14051, 16000], Rational[1183, 2000]}}, {{0.9, 0.6}, {
        0.8781875, 0.5915}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 10], Rational[13, 20]}, {
         Rational[14089, 16000], Rational[20523, 32000]}}, {{0.9, 0.65}, {
        0.8805625, 0.64134375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 10], Rational[7, 10]}, {
         Rational[14127, 16000], Rational[11061, 16000]}}, {{0.9, 0.7}, {
        0.8829375, 0.6913125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 10], Rational[3, 4]}, {
         Rational[2833, 3200], Rational[949, 1280]}}, {{0.9, 0.75}, {
        0.8853125, 0.74140625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 10], Rational[4, 5]}, {
         Rational[14203, 16000], Rational[6333, 8000]}}, {{0.9, 0.8}, {
        0.8876875, 0.791625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 10], Rational[17, 20]}, {
         Rational[14241, 16000], Rational[26943, 32000]}}, {{0.9, 0.85}, {
        0.8900625, 0.84196875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 10], Rational[9, 10]}, {
         Rational[14279, 16000], Rational[14279, 16000]}}, {{0.9, 0.9}, {
        0.8924375, 0.8924375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 10], Rational[19, 20]}, {
         Rational[14317, 16000], Rational[30177, 32000]}}, {{0.9, 0.95}, {
        0.8948125, 0.94303125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[9, 10], 1}, {
         Rational[2871, 3200], Rational[159, 160]}}, {{0.9, 1}, {0.8971875, 
         0.99375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[19, 20], 0}, {
         Rational[11439, 12800], Rational[1, 640]}}, {{0.95, 0}, {0.893671875,
          0.0015625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[19, 20], Rational[1, 20]}, {
         Rational[114741, 128000], Rational[6399, 128000]}}, {{0.95, 0.05}, {
        0.8964140625, 0.0499921875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[19, 20], Rational[1, 10]}, {
         Rational[28773, 32000], Rational[1577, 16000]}}, {{0.95, 0.1}, {
        0.89915625, 0.0985625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[19, 20], Rational[3, 20]}, {
         Rational[115443, 128000], Rational[18851, 128000]}}, {{0.95, 0.15}, {
        0.9018984375, 0.1472734375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[19, 20], Rational[1, 5]}, {
         Rational[57897, 64000], Rational[1569, 8000]}}, {{0.95, 0.2}, {
        0.904640625, 0.196125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[19, 20], Rational[1, 4]}, {
         Rational[23229, 25600], Rational[251, 1024]}}, {{0.95, 0.25}, {
        0.9073828125, 0.2451171875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[19, 20], Rational[3, 10]}, {
         Rational[7281, 8000], Rational[1177, 4000]}}, {{0.95, 0.3}, {
        0.910125, 0.29425}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[19, 20], Rational[7, 20]}, {
         Rational[116847, 128000], Rational[43971, 128000]}}, {{0.95, 0.35}, {
        0.9128671875, 0.3435234375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[19, 20], Rational[2, 5]}, {
         Rational[58599, 64000], Rational[6287, 16000]}}, {{0.95, 0.4}, {
        0.915609375, 0.3929375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[19, 20], Rational[9, 20]}, {
         Rational[117549, 128000], Rational[56639, 128000]}}, {{0.95, 0.45}, {
        0.9183515625, 0.4424921875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[19, 20], Rational[1, 2]}, {
         Rational[1179, 1280], Rational[63, 128]}}, {{0.95, 0.5}, {0.92109375,
         0.4921875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[19, 20], Rational[11, 20]}, {
         Rational[118251, 128000], Rational[69379, 128000]}}, {{0.95, 0.55}, {
        0.9238359375, 0.5420234375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[19, 20], Rational[3, 5]}, {
         Rational[59301, 64000], Rational[74, 125]}}, {{0.95, 0.6}, {
        0.926578125, 0.592}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[19, 20], Rational[13, 20]}, {
         Rational[118953, 128000], Rational[82191, 128000]}}, {{0.95, 0.65}, {
        0.9293203125, 0.6421171875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[19, 20], Rational[7, 10]}, {
         Rational[14913, 16000], Rational[5539, 8000]}}, {{0.95, 0.7}, {
        0.9320625, 0.692375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[19, 20], Rational[3, 4]}, {
         Rational[23931, 25600], Rational[3803, 5120]}}, {{0.95, 0.75}, {
        0.9348046875, 0.7427734375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[19, 20], Rational[4, 5]}, {
         Rational[60003, 64000], Rational[12693, 16000]}}, {{0.95, 0.8}, {
        0.937546875, 0.7933125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[19, 20], Rational[17, 20]}, {
         Rational[120357, 128000], Rational[108031, 128000]}}, {{0.95, 
        0.85}, {0.9402890625, 0.8439921875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[19, 20], Rational[9, 10]}, {
         Rational[30177, 32000], Rational[14317, 16000]}}, {{0.95, 0.9}, {
        0.94303125, 0.8948125}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[19, 20], Rational[19, 20]}, {
         Rational[121059, 128000], Rational[121059, 128000]}}, {{0.95, 
        0.95}, {0.9457734375, 0.9457734375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{Rational[19, 20], 1}, {
         Rational[12141, 12800], Rational[319, 320]}}, {{0.95, 1}, {
         0.948515625, 0.996875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{1, 0}, {Rational[15, 16], 0}}, {{1, 0}, {
         0.9375, 0}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{1, Rational[1, 20]}, {
         Rational[301, 320], Rational[621, 12800]}}, {{1, 0.05}, {0.940625, 
         0.048515625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{1, Rational[1, 10]}, {
         Rational[151, 160], Rational[311, 3200]}}, {{1, 0.1}, {0.94375, 
         0.0971875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{1, Rational[3, 20]}, {
         Rational[303, 320], Rational[1869, 12800]}}, {{1, 0.15}, {0.946875, 
         0.146015625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{1, Rational[1, 5]}, {
         Rational[19, 20], Rational[39, 200]}}, {{1, 0.2}, {0.95, 
         0.195}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[
       NCache[{{1, Rational[1, 4]}, {
         Rational[61, 64], Rational[125, 512]}}, {{1, 0.25}, {0.953125, 
         0.244140625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{1, Rational[3, 10]}, {
         Rational[153, 160], Rational[939, 3200]}}, {{1, 0.3}, {0.95625, 
         0.2934375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{1, Rational[7, 20]}, {
         Rational[307, 320], Rational[4389, 12800]}}, {{1, 0.35}, {0.959375, 
         0.342890625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{1, Rational[2, 5]}, {
         Rational[77, 80], Rational[157, 400]}}, {{1, 0.4}, {0.9625, 
         0.3925}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{1, Rational[9, 20]}, {
         Rational[309, 320], Rational[5661, 12800]}}, {{1, 0.45}, {0.965625, 
         0.442265625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{1, Rational[1, 2]}, {
         Rational[31, 32], Rational[63, 128]}}, {{1, 0.5}, {0.96875, 
         0.4921875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{1, Rational[11, 20]}, {
         Rational[311, 320], Rational[6941, 12800]}}, {{1, 0.55}, {0.971875, 
         0.542265625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{1, Rational[3, 5]}, {
         Rational[39, 40], Rational[237, 400]}}, {{1, 0.6}, {0.975, 
         0.5925}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{1, Rational[13, 20]}, {
         Rational[313, 320], Rational[8229, 12800]}}, {{1, 0.65}, {0.978125, 
         0.642890625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{1, Rational[7, 10]}, {
         Rational[157, 160], Rational[2219, 3200]}}, {{1, 0.7}, {0.98125, 
         0.6934375}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{1, Rational[3, 4]}, {
         Rational[63, 64], Rational[381, 512]}}, {{1, 0.75}, {0.984375, 
         0.744140625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{1, Rational[4, 5]}, {
         Rational[79, 80], Rational[159, 200]}}, {{1, 0.8}, {0.9875, 
         0.795}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{1, Rational[17, 20]}, {
         Rational[317, 320], Rational[10829, 12800]}}, {{1, 0.85}, {0.990625, 
         0.846015625}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{1, Rational[9, 10]}, {
         Rational[159, 160], Rational[2871, 3200]}}, {{1, 0.9}, {0.99375, 
         0.8971875}}]]}, 
     {Arrowheads[0.02], 
      ArrowBox[NCache[{{1, Rational[19, 20]}, {
         Rational[319, 320], Rational[12141, 12800]}}, {{1, 0.95}, {0.996875, 
         0.948515625}}]]}, 
     {PointSize[0.008], PointBox[{1, 1}]}}, {
     {EdgeForm[Thickness[Large]], DiskBox[{1, 0}, 0.03]}, InsetBox[
      StyleBox["\<\"0\"\>",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[1],
       BackFaceColor->GrayLevel[1],
       GraphicsColor->GrayLevel[1],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[1]], {1, 0}], 
     {GrayLevel[0.475], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{Rational[15, 16], 0}, {0.9375, 0}], 0.03]}, InsetBox[
      StyleBox["1",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[15, 16], 0}, {0.9375, 0}]], 
     {GrayLevel[0.475], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{Rational[225, 256], 0}, {0.87890625, 0}], 0.03]}, 
     InsetBox[
      StyleBox["2",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[225, 256], 0}, {0.87890625, 0}]], 
     {GrayLevel[0.475], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{Rational[3375, 4096], 0}, {0.823974609375, 0}], 0.03]}, 
     InsetBox[
      StyleBox["3",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[3375, 4096], 0}, {0.823974609375, 0}]], 
     {GrayLevel[0.475], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{Rational[50625, 65536], 0}, {0.7724761962890625, 0}], 
       0.03]}, InsetBox[
      StyleBox["4",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[50625, 65536], 0}, {0.7724761962890625, 0}]], 
     {GrayLevel[0.475], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{Rational[759375, 1048576], 0}, {0.7241964340209961, 0}],
        0.03]}, InsetBox[
      StyleBox["5",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[759375, 1048576], 0}, {0.7241964340209961, 0}]], 
     {GrayLevel[0.475], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{Rational[24589201, 33554432], Rational[1, 32]}, {
        0.73281529545784, 0.03125}], 0.03]}, InsetBox[
      StyleBox["6",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[24589201, 33554432], Rational[1, 32]}, {
       0.73281529545784, 0.03125}]], 
     {GrayLevel[0.475], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{Rational[368838015, 536870912], Rational[15, 512]}, {
        0.687014339491725, 0.029296875}], 0.03]}, InsetBox[
      StyleBox["7",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[368838015, 536870912], Rational[15, 512]}, {
       0.687014339491725, 0.029296875}]], 
     {GrayLevel[0.475], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[11970849377, 17179869184], Rational[977, 16384]}, {
        0.6967951413826086, 0.05963134765625}], 0.03]}, InsetBox[
      StyleBox["8",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[11970849377, 17179869184], Rational[977, 16384]}, {
       0.6967951413826086, 0.05963134765625}]], 
     {GrayLevel[0.475], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[179562740655, 274877906944], Rational[14655, 262144]}, {
        0.6532454450461955, 0.055904388427734375`}], 0.03]}, InsetBox[
      StyleBox["9",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[179562740655, 274877906944], Rational[
        14655, 262144]}, {0.6532454450461955, 0.055904388427734375`}]], 
     {GrayLevel[0.6499999999999999], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[2693441109825, 4398046511104], Rational[219825, 4194304]}, {
        0.6124176047308083, 0.05241036415100098}], 0.03]}, InsetBox[
      StyleBox["10",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[2693441109825, 4398046511104], Rational[
        219825, 4194304]}, {0.6124176047308083, 0.05241036415100098}]], 
     {GrayLevel[0.6499999999999999], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[36296860316093948863233377, 77371252455336267181195264], 
         Rational[9906798371695584977, 73786976294838206464]}, {
        0.46912592421903554`, 0.13426215396210264`}], 0.03]}, InsetBox[
      StyleBox["20",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[
        36296860316093948863233377, 77371252455336267181195264], Rational[
        9906798371695584977, 73786976294838206464]}, {0.46912592421903554`, 
       0.13426215396210264`}]], 
     {GrayLevel[0.6499999999999999], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[
         502406936434574644152549838973385981825, 
          1361129467683753853853498429727072845824], Rational[
         219211090745847933011085842691825, 
          1298074214633706907132624082305024]}, {0.3691103222454841, 
        0.1688740815236865}], 0.03]}, InsetBox[
      StyleBox["30",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[
        502406936434574644152549838973385981825, 
         1361129467683753853853498429727072845824], Rational[
        219211090745847933011085842691825, 
         1298074214633706907132624082305024]}, {0.3691103222454841, 
       0.1688740815236865}]], 
     {GrayLevel[0.6499999999999999], EdgeForm[Thickness[Large]], 
      DiskBox[
       NCache[{Rational[
         80655497056306102443101282267760360493137353696139121, 
          191561942608236107294793378393788647952342390272950272], Rational[
         52784046175308079793450928125525952329509885921, 
          182687704666362864775460604089535377456991567872]}, {
        0.42104134024812484`, 0.28893047986839626`}], 0.03]}, InsetBox[
      StyleBox["40",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[
        80655497056306102443101282267760360493137353696139121, 
         191561942608236107294793378393788647952342390272950272], Rational[
        52784046175308079793450928125525952329509885921, 
         182687704666362864775460604089535377456991567872]}, {
       0.42104134024812484`, 0.28893047986839626`}]], 
     {GrayLevel[0.6499999999999999], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[
         5625730241310321680857161161594657398440233143955782979582187599985, 
          13479973333575319897333507543509815336818572211270286240551805124608\
], Rational[
         4280730595883425488117421146186118485598534572425266190837985, 
          12855504354071922204335696738729300820177623950262342682411008]}, {
        0.41733986426352954`, 0.3329881487323773}], 0.03]}, InsetBox[
      StyleBox["50",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[
        5625730241310321680857161161594657398440233143955782979582187599985, 
         13479973333575319897333507543509815336818572211270286240551805124608]\
, Rational[
        4280730595883425488117421146186118485598534572425266190837985, 
         12855504354071922204335696738729300820177623950262342682411008]}, {
       0.41733986426352954`, 0.3329881487323773}]], 
     {GrayLevel[0.6499999999999999], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[
         867911362330302908597815990250414920845527629288179713180989517907622\
457424413025, 
          18971375900641885458197870183823426822679754287618550012224730563856\
48716020711424], Rational[
         727014234371882598875196638851377963703338533387600619553928573320266\
083025, 1809251394333065553493296640760748560207343510400633813116524750123642\
650624]}, {0.457484668943246, 0.401831518079265}], 0.03]}, InsetBox[
      StyleBox["60",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[
        8679113623303029085978159902504149208455276292881797131809895179076224\
57424413025, 
         189713759006418854581978701838234268226797542876185500122247305638564\
8716020711424], Rational[
        7270142343718825988751966388513779637033385333876006195539285733202660\
83025, 18092513943330655534932966407607485602073435104006338131165247501236426\
50624]}, {0.457484668943246, 0.401831518079265}]], 
     {GrayLevel[0.6499999999999999], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[
         128840691589483651214886560548700077994709504779193950896454705469680\
190382519004402824339225425, 
          26699837949011376029937771327119401432533806529458159624338020097777\
7465722580068752870260867072], Rational[
         113522430998341677537487758571121736410488825174190850367739530386211\
346429264435810815425, 
          25462949704181076078355571105117227013143354920824203132951755616929\
7662470417088272924672]}, {0.48255233546934045`, 0.44583377934293694`}], 
       0.03]}, InsetBox[
      StyleBox["70",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[
        1288406915894836512148865605487000779947095047791939508964547054696801\
90382519004402824339225425, 
         266998379490113760299377713271194014325338065294581596243380200977777\
465722580068752870260867072], Rational[
        1135224309983416775374877585711217364104888251741908503677395303862113\
46429264435810815425, 
         254629497041810760783555711051172270131433549208242031329517556169297\
662470417088272924672]}, {0.48255233546934045`, 0.44583377934293694`}]], 
     {GrayLevel[0.6499999999999999], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[
         851529730530512119965283447796572962458547195087621363548551336087905\
9370262140000734445130071977399787551825, 
          18788340662190665823115844774314696219005460391266558965658327772257\
672200916867547709591987078149624255479808], Rational[
         770074275347046357181576200933304190346289682856250245071086703097294\
0059329617889197851580000000261825, 
          17917957937422433684459538244547554224973163977877196279199912807710\
334969441287563047019946172856926208]}, {0.4532224243964854, 
        0.42977792337524845`}], 0.03]}, InsetBox[
      StyleBox["80",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[
        8515297305305121199652834477965729624585471950876213635485513360879059\
370262140000734445130071977399787551825, 
         187883406621906658231158447743146962190054603912665589656583277722576\
72200916867547709591987078149624255479808], Rational[
        7700742753470463571815762009333041903462896828562502450710867030972940\
059329617889197851580000000261825, 
         179179579374224336844595382445475542249731639778771962791999128077103\
34969441287563047019946172856926208]}, {0.4532224243964854, 
       0.42977792337524845`}]], 
     {GrayLevel[0.6499999999999999], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[
         594325092130243530706700805441881633030302533803214097542082632855440\
146062108772634730078606490607683680095275618780347729, 
          13221119375804971979038306160655420796568093659285624385692975905488\
11582472622691650378420879430569695182424050046716608512], Rational[
         547918543141430358281352381658179293883996056671552882063305569004343\
425535166829893344328428866319054562588538580929, 
          12608641982846233347929292832045956417625516566548942933743453889358\
63096687910739565256520156317300505812095689818112]}, {0.4495270598780581, 
        0.43455793564989864`}], 0.03]}, InsetBox[
      StyleBox["90",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[
        5943250921302435307067008054418816330303025338032140975420826328554401\
46062108772634730078606490607683680095275618780347729, 
         132211193758049719790383061606554207965680936592856243856929759054881\
1582472622691650378420879430569695182424050046716608512], Rational[
        5479185431414303582813523816581792938839960566715528820633055690043434\
25535166829893344328428866319054562588538580929, 
         126086419828462333479292928320459564176255165665489429337434538893586\
3096687910739565256520156317300505812095689818112]}, {0.4495270598780581, 
       0.43455793564989864`}]], 
     {GrayLevel[0.825], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[
         410067895128300013762780101569994698635708900371953936588957943675786\
47322382411287510247050074968864676980359967070453285577562224361041, 
          93035356709837681990313447409664580397266094167976711716030745495121\
828878514934185752454491361736391777602765602070775492429008462675968], 
         Rational[
         382591140430546504907513621770562456145129482918419685496862043620506\
70906556933216202271211948923218488290051382344544037439643841, 
          88725430211866075506509253892578678509965986412026130405455346579667\
881849780019937279180995332466499116518750764914298527173050368]}, {
        0.4407656504260373, 0.43120798571160834`}], 0.03]}, InsetBox[
      StyleBox["100",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[
        4100678951283000137627801015699946986357089003719539365889579436757864\
7322382411287510247050074968864676980359967070453285577562224361041, 
         930353567098376819903134474096645803972660941679767117160307454951218\
28878514934185752454491361736391777602765602070775492429008462675968], 
        Rational[
        3825911404305465049075136217705624561451294829184196854968620436205067\
0906556933216202271211948923218488290051382344544037439643841, 
         887254302118660755065092538925786785099659864120261304054553465796678\
81849780019937279180995332466499116518750764914298527173050368]}, {
       0.4407656504260373, 0.43120798571160834`}]], 
     {GrayLevel[0.825], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[
         174790737151928742398272338065800367128005150341086415171037119565323\
067917919626941521945453200377261441834547152815268229522779435826742160077926\
330841034966560242307627766409474574110263160700805822934148185355424681462663\
865960875291295718048352404447442646712083270625, 
          54097359988292121226479593975451300507529966186098843865903176604331\
407621808625610180327002896096040414658047309529976717552390093074999014455191\
394605012675418796441498120618878107410066067563829681449800825692584758097177\
7599220570518424337445351925287506839283710296064], Rational[
         166652101763472409227480572320647189758520126291698973217555244086305\
435920437022177568312283826517720258866242446682691783826687512138824215626821\
664861687723283179705876384059299655625706482531966191865770031004300846812014\
624834797521206279356730922410696731020625, 
          51591262806217309214095682120753574855356184183214992395308662990886\
123296555162058048560145279022255339296386060266472547104253857684134497122947\
115521443057459637109277840250852687273088519634084397744942498867592580887964\
0197010584371971452184059071815020407947264]}, {0.3231040057957678, 
        0.3230238856324118}], 0.03]}, InsetBox[
      StyleBox["200",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[
        1747907371519287423982723380658003671280051503410864151710371195653230\
679179196269415219454532003772614418345471528152682295227794358267421600779263\
308410349665602423076277664094745741102631607008058229341481853554246814626638\
65960875291295718048352404447442646712083270625, 
         540973599882921212264795939754513005075299661860988438659031766043314\
076218086256101803270028960960404146580473095299767175523900930749990144551913\
946050126754187964414981206188781074100660675638296814498008256925847580971777\
599220570518424337445351925287506839283710296064], Rational[
        1666521017634724092274805723206471897585201262916989732175552440863054\
359204370221775683122838265177202588662424466826917838266875121388242156268216\
648616877232831797058763840592996556257064825319661918657700310043008468120146\
24834797521206279356730922410696731020625, 
         515912628062173092140956821207535748553561841832149923953086629908861\
232965551620580485601452790222553392963860602664725471042538576841344971229471\
155214430574596371092778402508526872730885196340843977449424988675925808879640\
197010584371971452184059071815020407947264]}, {0.3231040057957678, 
       0.3230238856324118}]], 
     {GrayLevel[0.825], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[
         189169042699210207557840153816370105007529065554506643168878485037926\
410088550965284110606136690029495155264855140892358077909828192583832835376367\
187957999198223732423321062594807213824205876950867603687488944107995548765655\
826823426017867181876803333283232443035973256418826507008481736706935481122802\
851798525179896737916866444694914156789019225578097491254167135944207562673646\
00475738385343795945010380849, 
          50329671835712579461854951999839402796773712173831143305398933677942\
504868153662569007716456159616982821530713710670704800369176833516771157840831\
040544211525995840640881306433555762781103205628168904428516728467610359876242\
665010819584903491101881621459858238920230794858106249910735868760873823350608\
300758583725766161321207232378065317633941744167913507807938722144096190182876\
581485726422392912374977789952], Rational[
         180405289930229740907003821470503369410460586212935479834513606201688\
580106855081520494212654673666152035642197558012509288215144354486702514880074\
007489224458478694859453538411212946565147870072273503723867113146425950804480\
852072165085799069461420495844947622206539169669487488911471288060720633691701\
795511153637073922351685569917569774715089509594889352721304285237352126157861\
11431704343056259110049, 
          47998115382874087774138404846038248821996414350348609261893209150259\
499424127256936080662208709351523229151452742262558746689965089337130697098570\
862335406805034485474473291810565722256758885982674507549778679339990959049456\
276903934082892886258966084918840636177283091409784555350051754723428557730301\
190146049237981950112540466669144933351461166541970737274111482757660093481899\
816022612020867264151552]}, {0.3758598770854312, 0.37585911132377303`}], 
       0.03]}, InsetBox[
      StyleBox["300",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[
        1891690426992102075578401538163701050075290655545066431688784850379264\
100885509652841106061366900294951552648551408923580779098281925838328353763671\
879579991982237324233210625948072138242058769508676036874889441079955487656558\
268234260178671818768033332832324430359732564188265070084817367069354811228028\
517985251798967379168664446949141567890192255780974912541671359442075626736460\
0475738385343795945010380849, 
         503296718357125794618549519998394027967737121738311433053989336779425\
048681536625690077164561596169828215307137106707048003691768335167711578408310\
405442115259958406408813064335557627811032056281689044285167284676103598762426\
650108195849034911018816214598582389202307948581062499107358687608738233506083\
007585837257661613212072323780653176339417441679135078079387221440961901828765\
81485726422392912374977789952], Rational[
        1804052899302297409070038214705033694104605862129354798345136062016885\
801068550815204942126546736661520356421975580125092882151443544867025148800740\
074892244584786948594535384112129465651478700722735037238671131464259508044808\
520721650857990694614204958449476222065391696694874889114712880607206336917017\
955111536370739223516855699175697747150895095948893527213042852373521261578611\
1431704343056259110049, 
         479981153828740877741384048460382488219964143503486092618932091502594\
994241272569360806622087093515232291514527422625587466899650893371306970985708\
623354068050344854744732918105657222567588859826745075497786793399909590494562\
769039340828928862589660849188406361772830914097845553500517547234285577303011\
901460492379819501125404666691449333514611665419707372741114827576600934818998\
16022612020867264151552]}, {0.3758598770854312, 0.37585911132377303`}]], 
     {GrayLevel[0.825], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[
         191433342880268681173943694090044601138213931556845956363443914673241\
599663110403546935805856193778110631763235156595735808568582612573722300010339\
168808831769889885564127687382567681354063615238212931388242315550215285493122\
631821726357350741978516420644154636605540276662057833156791918159608000379534\
359130468547832778920004801503316178309843252079564719550232693419808740398510\
352925315556555278923189885453782603613613807913378359122471852029672355373125\
525560003548675729285979193122566657744951763525689163626252472639852269327070\
9112171905, 
          46824389723245909351073450900209440301978295630881767207530212221868\
830416779921762656899530867487563837261969559347149331825945407926952785404508\
332337414971407465283828265763561741564303406605672962394937083588231950210051\
536995629834843013023028995441824081188708633748954942913520019752389340465347\
479067837482375000993447034001909327539057178975824554205238387485485165871153\
345105266294952652415674641825461376980007536540526009964548257670402403489644\
596081532378684955935480917560959967125634060314895680761560618929075375277555\
60542273536], Rational[
         182565059140435805256139053952829664723423041062315070469342673379199\
424836087226778391982226772586571375904618484877024642084615024856216638586183\
095434954929969335336635842773612939665530708630161126430683759260701457943794\
223022089066049996712725470864092560990186507466816729936818389872740011452522\
012635741648848985778131946627198544629719373822962277204146410667430083983664\
760241784762779119100746123106871483514420852483267130672925676182902873818649\
019633950147720917516557785079537482843163753213033561207771666884913726709694\
5905, 446552178604563802252516278268904116649420696553056404185583231180847458\
045767991663521762188601375234959239669412108891790637449340123679975552638362\
287664140772488439829499850861945765527788216333030652399860269851209736361856\
418894146375780325212435167542278182112061967420033583831975482839016583895483\
663916419744501051397647875874781981059827574010412266143679480411204062970591\
595328282858394772287767653096933174205174832592105527384354309104952713437996\
688197886323508601006675347900077110615351818997199645620526591066124702030233\
6]}, {0.40883254221086374`, 0.4088325348919706}], 0.03]}, InsetBox[
      StyleBox["400",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[
        1914333428802686811739436940900446011382139315568459563634439146732415\
996631104035469358058561937781106317632351565957358085685826125737223000103391\
688088317698898855641276873825676813540636152382129313882423155502152854931226\
318217263573507419785164206441546366055402766620578331567919181596080003795343\
591304685478327789200048015033161783098432520795647195502326934198087403985103\
529253155565552789231898854537826036136138079133783591224718520296723553731255\
255600035486757292859791931225666577449517635256891636262524726398522693270709\
112171905, 
         468243897232459093510734509002094403019782956308817672075302122218688\
304167799217626568995308674875638372619695593471493318259454079269527854045083\
323374149714074652838282657635617415643034066056729623949370835882319502100515\
369956298348430130230289954418240811887086337489549429135200197523893404653474\
790678374823750009934470340019093275390571789758245542052383874854851658711533\
451052662949526524156746418254613769800075365405260099645482576704024034896445\
960815323786849559354809175609599671256340603148956807615606189290753752775556\
0542273536], Rational[
        1825650591404358052561390539528296647234230410623150704693426733791994\
248360872267783919822267725865713759046184848770246420846150248562166385861830\
954349549299693353366358427736129396655307086301611264306837592607014579437942\
230220890660499967127254708640925609901865074668167299368183898727400114525220\
126357416488489857781319466271985446297193738229622772041464106674300839836647\
602417847627791191007461231068714835144208524832671306729256761829028738186490\
196339501477209175165577850795374828431637532130335612077716668849137267096945\
905, 4465521786045638022525162782689041166494206965530564041855832311808474580\
457679916635217621886013752349592396694121088917906374493401236799755526383622\
876641407724884398294998508619457655277882163330306523998602698512097363618564\
188941463757803252124351675422781821120619674200335838319754828390165838954836\
639164197445010513976478758747819810598275740104122661436794804112040629705915\
953282828583947722877676530969331742051748325921055273843543091049527134379966\
881978863235086010066753479000771106153518189971996456205265910661247020302336\
]}, {0.40883254221086374`, 0.4088325348919706}]], 
     {GrayLevel[0.825], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[
         649665555274451997007375578109339147513341413745452921200541121372455\
866681240004574087201691107532369337816074611390960490518715974730435054494837\
868850991898094162338117844437296457165841339058331495487092667389041232423609\
681351327569271721055815179363160818870699885112252046103517898828340810846612\
449569894859854157838926425926555505974550236206565033671586080024505087210754\
724814933661931692865290019904843683114984885929756752687873045219832842619296\
069048434696645821072563192869348442153835685616504338275411661358347605894571\
447304202775678972550750070257571706955517104114808017978282369804310893047240\
929955431848784484551038512293326781602272625414242466436761683810481, 
          17425295202490563655123113531332101948680024703627339887187157029820\
495538782049740980958799570468321334111169184543621187334324441159350187144667\
869576057463486491927888208006961965154191891046831049571877745286266750402802\
923597972456181738080732850374492114413384604593594881998888162597776110531927\
019616591809554023795774691598283209282378383061411933660243200200204065501156\
461998967733000507626975367675028153846752159909440105970501218393657054952604\
057116806254631669407496167440594758219324768708413537597576881981606548031051\
734842225054168513526558565429959176450771827971141554820060053946666659937615\
27547105656127708028861905978284863688229753943906920953645204758331392], 
         Rational[
         619569354194925104550964849504857034295850862232774372853024756708702\
294444424912807425529691538107551096025679999458114434846155179840911259332609\
506701586551540777871991592745997517068159136605335460212952775359981468389104\
185747582400958294025417586700526175002038468925740795618395036553476565621745\
185793374191943569867838815552182168876304120696239885846108290248367646229914\
232750658577643309181943297176095991483105049285441017674160675822619918325874\
109162429100929076120528246605284393806316482819264320864173758127658467356302\
172366095177143331041205915628428683277651586174379000955099775407570283468044\
619556552271563826002666710486922459051213639231787643426645281, 
          16618056490412295966265786677677251766853356078746166121661335973568\
435229093599072438200759478061982473479432282012578189215015832099294840950649\
137092645133482448509109695441209759859268084570723580905797715460078001406481\
669996235328847635346157884954921831525215725511164552687538302037979231388022\
441498367127946876331114474867137154848459609090244229946368408394054475308567\
487715690358162410380339973139789728018524322423400979967595308679253630592922\
265164190535194081695076148453325994700741547306455171201302415830236957579662\
070123887113731874014433446340521980715534046145574145145473531672159824311843\
18110566764953334835874467829022277534703973716647072747845844992]}, {
        0.37282900962366283`, 0.37282900954897014`}], 0.03]}, InsetBox[
      StyleBox["500",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[
        6496655552744519970073755781093391475133414137454529212005411213724558\
666812400045740872016911075323693378160746113909604905187159747304350544948378\
688509918980941623381178444372964571658413390583314954870926673890412324236096\
813513275692717210558151793631608188706998851122520461035178988283408108466124\
495698948598541578389264259265555059745502362065650336715860800245050872107547\
248149336619316928652900199048436831149848859297567526878730452198328426192960\
690484346966458210725631928693484421538356856165043382754116613583476058945714\
473042027756789725507500702575717069555171041148080179782823698043108930472409\
29955431848784484551038512293326781602272625414242466436761683810481, 
         174252952024905636551231135313321019486800247036273398871871570298204\
955387820497409809587995704683213341111691845436211873343244411593501871446678\
695760574634864919278882080069619651541918910468310495718777452862667504028029\
235979724561817380807328503744921144133846045935948819988881625977761105319270\
196165918095540237957746915982832092823783830614119336602432002002040655011564\
619989677330005076269753676750281538467521599094401059705012183936570549526040\
571168062546316694074961674405947582193247687084135375975768819816065480310517\
348422250541685135265585654299591764507718279711415548200600539466666599376152\
7547105656127708028861905978284863688229753943906920953645204758331392], 
        Rational[
        6195693541949251045509648495048570342958508622327743728530247567087022\
944444249128074255296915381075510960256799994581144348461551798409112593326095\
067015865515407778719915927459975170681591366053354602129527753599814683891041\
857475824009582940254175867005261750020384689257407956183950365534765656217451\
857933741919435698678388155521821688763041206962398858461082902483676462299142\
327506585776433091819432971760959914831050492854410176741606758226199183258741\
091624291009290761205282466052843938063164828192643208641737581276584673563021\
723660951771433310412059156284286832776515861743790009550997754075702834680446\
19556552271563826002666710486922459051213639231787643426645281, 
         166180564904122959662657866776772517668533560787461661216613359735684\
352290935990724382007594780619824734794322820125781892150158320992948409506491\
370926451334824485091096954412097598592680845707235809057977154600780014064816\
699962353288476353461578849549218315252157255111645526875383020379792313880224\
414983671279468763311144748671371548484596090902442299463684083940544753085674\
877156903581624103803399731397897280185243224234009799675953086792536305929222\
651641905351940816950761484533259947007415473064551712013024158302369575796620\
701238871137318740144334463405219807155340461455741451454735316721598243118431\
8110566764953334835874467829022277534703973716647072747845844992]}, {
       0.37282900962366283`, 0.37282900954897014`}]], 
     {GrayLevel[0.825], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[
         698685614672448643398620413744071355927655261000844457838000505185940\
842326428282995033157451115895174050977966159420866546365857041748031946701536\
250018652935557447958967537808479847367386363020352892979981445182849635633187\
746706488172164503531113036506350150816141300264696322718533289044616990614610\
829825155439548565602108709087668315105462279938979983753373103061891313996529\
610772712253322247746306962005027960495032214815176780975364704451262303080970\
150849197160125029395562521674368809601787686623607351634955223551633311919116\
767918593800370774577592849334814481817933903253963767779767709153460812170507\
299306241650981257447176782648610276570197039446968712123549113134082859764730\
404706035246251454760662401204362975574149106215366275357772449900608710720841\
16189143266857670178949937964519995586341152992769, 
          16211685549379328308278713846608932633089203656398944239658283835809\
716671871814374223889843025418234788946582021683798616380919876627343592710694\
325309129530334660822099506970338928717092497853223976493426506661447396890779\
875043606734975971186989181787125050655801788047890437570044497197100343758641\
283401014320740725889485598384180021821247206491641337476657210991889936116941\
704090600329267392367966235124027870089497380393315931194087779838909253242903\
271286021388401216007718460978911882748892539921210699479206004323405760794082\
325908969752411803471719217683636930816169460627161913708625743179827126103660\
600304395940207673799890704639913577147285334253113706096320357669057671361742\
740921297234730512486918828543776145801912590284331144855828191883831349510246\
5912726696962751051318023405498085337938318858387456], Rational[
         666318525954524336993395589994698475191919222073800584600519514184184\
865140336719494556836834358809009089481358836365325920732464700732882636590722\
537607290640445085777403204357736878788785137517704698499374792491887807283278\
677624740619506658950328562218441078906079840466175403193114063914832912202472\
937777352066332401455848921441974778425255787424736592938184972384391270552101\
478388932400068982464682267461239709975361042823617739127440263466167865564127\
418875140297275430626823803907871527811388800715121034567797526455380208813489\
029632553839236567720991406223726491514830789047795620420910829655256750959280\
140775212896516914961285172503095631463662992253172402862598930411020269817461\
028686648127338831897673373991507843786766881668802779654694266756853713019367\
16414335647710656487031719281431338815257969, 
          15460668134097412403372491690262730248536304146193451156290325008210\
865661498846410964860766435068354405352193853076742760067863346698134987555212\
331112985163054142782306200952853134839146135190223671430040842687079808131008\
029025656447387667834271604334950495391656673477068364687008378216839164503709\
109688772507420278443799589523487111874816137782708489872605525009050308339063\
362207985238330261581388697742488737191674595254245692438209323729428532832053\
443227788341904846198767147997772104977505245133600902060705189059644470972139\
669331521751796534988135545428883486572427235247766412457109206371142507651959\
038071056308944391059771256103433205745015463116754251571960790318544074403517\
476006791338663589941901043456817766000664320263224739890888397106009816656347\
8386618325197936106985114484308324182451552256]}, {0.4309765400669261, 
        0.43097654006621217`}], 0.03]}, InsetBox[
      StyleBox["600",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[
        6986856146724486433986204137440713559276552610008444578380005051859408\
423264282829950331574511158951740509779661594208665463658570417480319467015362\
500186529355574479589675378084798473673863630203528929799814451828496356331877\
467064881721645035311130365063501508161413002646963227185332890446169906146108\
298251554395485656021087090876683151054622799389799837533731030618913139965296\
107727122533222477463069620050279604950322148151767809753647044512623030809701\
508491971601250293955625216743688096017876866236073516349552235516333119191167\
679185938003707745775928493348144818179339032539637677797677091534608121705072\
993062416509812574471767826486102765701970394469687121235491131340828597647304\
047060352462514547606624012043629755741491062153662753577724499006087107208411\
6189143266857670178949937964519995586341152992769, 
         162116855493793283082787138466089326330892036563989442396582838358097\
166718718143742238898430254182347889465820216837986163809198766273435927106943\
253091295303346608220995069703389287170924978532239764934265066614473968907798\
750436067349759711869891817871250506558017880478904375700444971971003437586412\
834010143207407258894855983841800218212472064916413374766572109918899361169417\
040906003292673923679662351240278700894973803933159311940877798389092532429032\
712860213884012160077184609789118827488925399212106994792060043234057607940823\
259089697524118034717192176836369308161694606271619137086257431798271261036606\
003043959402076737998907046399135771472853342531137060963203576690576713617427\
409212972347305124869188285437761458019125902843311448558281918838313495102465\
912726696962751051318023405498085337938318858387456], Rational[
        6663185259545243369933955899946984751919192220738005846005195141841848\
651403367194945568368343588090090894813588363653259207324647007328826365907225\
376072906404450857774032043577368787887851375177046984993747924918878072832786\
776247406195066589503285622184410789060798404661754031931140639148329122024729\
377773520663324014558489214419747784252557874247365929381849723843912705521014\
783889324000689824646822674612397099753610428236177391274402634661678655641274\
188751402972754306268238039078715278113888007151210345677975264553802088134890\
296325538392365677209914062237264915148307890477956204209108296552567509592801\
407752128965169149612851725030956314636629922531724028625989304110202698174610\
286866481273388318976733739915078437867668816688027796546942667568537130193671\
6414335647710656487031719281431338815257969, 
         154606681340974124033724916902627302485363041461934511562903250082108\
656614988464109648607664350683544053521938530767427600678633466981349875552123\
311129851630541427823062009528531348391461351902236714300408426870798081310080\
290256564473876678342716043349504953916566734770683646870083782168391645037091\
096887725074202784437995895234871118748161377827084898726055250090503083390633\
622079852383302615813886977424887371916745952542456924382093237294285328320534\
432277883419048461987671479977721049775052451336009020607051890596444709721396\
693315217517965349881355454288834865724272352477664124571092063711425076519590\
380710563089443910597712561034332057450154631167542515719607903185440744035174\
760067913386635899419010434568177660006643202632247398908883971060098166563478\
386618325197936106985114484308324182451552256]}, {0.4309765400669261, 
       0.43097654006621217`}]], 
     {GrayLevel[0.825], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[
         593743912555263732657395445538417823984553943023419563311241602851358\
786222832328082406239170174420767978328699373742006195097079042846874194810214\
686455369515007584743968576981490437394158835361127695206714395108017721435448\
171583357265470201882626756624510303731961135937286410633910965952966526384752\
908971433043866023852768205186667233778009340779537606156010911020961178638025\
316518205616038279678444290631462455892531684873130024434872919696724527257164\
160419207890558023711925140301935372821345699763245321304108904712184963335338\
457067790005966970398403710009642637424776352385733454742050701959287866813821\
691277236009370717126237493781359293133427289643892775241432172594518058026692\
751474054906621981800780714049231853279893196376445975726319372318219667274977\
297972267267177544904024912904302805658889381894501554596379807611981121595407\
917352770394659814421244891935090747823485588422757831614359883868345349201434\
691469333656551942557965239425, 
          18853249349427833496610893629436143305925280405290354050810486890395\
551691951285617411573877092486029618208357841154369630508118224592691506432144\
495011892454427042982054725399790354363078576153610232554720103205820167973343\
481658304351106113336002006620098138314284159891012493013333840019065263134549\
207874654380505474417864803828149966170449842094139360317078602943517059582945\
462082752813112435242212240629187144195092987688908405335427147637464270286531\
481687162686293334460315942518920454165516262704946235074631340053932224665840\
771325037467181138276245015062858587889476842418787554440453521414487565106338\
777110945502757076530025704387604141308301904126230579126629121329596570732428\
754232443541424744426099855529130373011928610294432424640457912704593549824837\
378783891577650456101766909838343167695644970204699635497511889381730609292526\
685356238473849312015236039617321691811172942860134759741943870696147469342285\
03510645087380779977589890482176], Rational[
         566238319926502298405930179684088342702678185830342891785379139773366\
745345801461754001032603044295187564824367307747065214670903047884429523009322\
717587459973505473883884506366978307996219650762537832445233435943683891361470\
304319988652319137277537169335011675905152976123154049012566392956725989529773\
870422934866224353773746414992557216705628465095779874938824661910456663197417\
571015519587061181870191775461176516018247586756488135996688832451930200118688\
183998755537393625326796059314161908806435388219826848272206255594346678607106\
218152794958391902970583250067079562795433439107034933719376820069714895429634\
154427059284177183220220034787277589963393331861228377175338016438990623896965\
796868731092341488144092445859669750710279314945106322868609006610649027016641\
390640273512894801566707372605361242754085145391099955780397492214058195217254\
576007727630916914015800515590133128523891837821152283807652282416137742611270\
772714191111108548029425, 
          17979859685352166649447339658199446969914703755655626345453726663966\
705028487477891360830189793096570604523046342043275480754965042679492479736465\
926181690649439852697424626731672624934271408227548821024627783971614997838347\
894342712737184632621767050380800379099163207903873913777669754046502364286946\
494936613445764040391793063953542677088212816328181610409811594909207400877900\
564272644818413195841037979726016182131855952919872670493533275258507032667666\
894614374815266928158107702750130132833019507126756892275458660177166199365463\
992428815333539140964741721213205898179509012621676973762944718756187024217928\
673850007536656452684426979434589520748426345945578173758153077439877100689343\
218071406880783790994739394692545292865685091299469399109323418335526990723454\
836639300897264915563361081922858398147244425015163074014198197728853806774641\
690593946908807098403202094666787807284520094738135108701652403541705579130444\
56015248381977825143422976]}, {0.31492922071456236`, 0.31492922071455615`}], 
       0.03]}, InsetBox[
      StyleBox["700",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[
        5937439125552637326573954455384178239845539430234195633112416028513587\
862228323280824062391701744207679783286993737420061950970790428468741948102146\
864553695150075847439685769814904373941588353611276952067143951080177214354481\
715833572654702018826267566245103037319611359372864106339109659529665263847529\
089714330438660238527682051866672337780093407795376061560109110209611786380253\
165182056160382796784442906314624558925316848731300244348729196967245272571641\
604192078905580237119251403019353728213456997632453213041089047121849633353384\
570677900059669703984037100096426374247763523857334547420507019592878668138216\
912772360093707171262374937813592931334272896438927752414321725945180580266927\
514740549066219818007807140492318532798931963764459757263193723182196672749772\
979722672671775449040249129043028056588893818945015545963798076119811215954079\
173527703946598144212448919350907478234855884227578316143598838683453492014346\
91469333656551942557965239425, 
         188532493494278334966108936294361433059252804052903540508104868903955\
516919512856174115738770924860296182083578411543696305081182245926915064321444\
950118924544270429820547253997903543630785761536102325547201032058201679733434\
816583043511061133360020066200981383142841598910124930133338400190652631345492\
078746543805054744178648038281499661704498420941393603170786029435170595829454\
620827528131124352422122406291871441950929876889084053354271476374642702865314\
816871626862933344603159425189204541655162627049462350746313400539322246658407\
713250374671811382762450150628585878894768424187875544404535214144875651063387\
771109455027570765300257043876041413083019041262305791266291213295965707324287\
542324435414247444260998555291303730119286102944324246404579127045935498248373\
787838915776504561017669098383431676956449702046996354975118893817306092925266\
853562384738493120152360396173216918111729428601347597419438706961474693422850\
3510645087380779977589890482176], Rational[
        5662383199265022984059301796840883427026781858303428917853791397733667\
453458014617540010326030442951875648243673077470652146709030478844295230093227\
175874599735054738838845063669783079962196507625378324452334359436838913614703\
043199886523191372775371693350116759051529761231540490125663929567259895297738\
704229348662243537737464149925572167056284650957798749388246619104566631974175\
710155195870611818701917754611765160182475867564881359966888324519302001186881\
839987555373936253267960593141619088064353882198268482722062555943466786071062\
181527949583919029705832500670795627954334391070349337193768200697148954296341\
544270592841771832202200347872775899633933318612283771753380164389906238969657\
968687310923414881440924458596697507102793149451063228686090066106490270166413\
906402735128948015667073726053612427540851453910999557803974922140581952172545\
760077276309169140158005155901331285238918378211522838076522824161377426112707\
72714191111108548029425, 
         179798596853521666494473396581994469699147037556556263454537266639667\
050284874778913608301897930965706045230463420432754807549650426794924797364659\
261816906494398526974246267316726249342714082275488210246277839716149978383478\
943427127371846326217670503808003790991632079038739137776697540465023642869464\
949366134457640403917930639535426770882128163281816104098115949092074008779005\
642726448184131958410379797260161821318559529198726704935332752585070326676668\
946143748152669281581077027501301328330195071267568922754586601771661993654639\
924288153335391409647417212132058981795090126216769737629447187561870242179286\
738500075366564526844269794345895207484263459455781737581530774398771006893432\
180714068807837909947393946925452928656850912994693991093234183355269907234548\
366393008972649155633610819228583981472444250151630740141981977288538067746416\
905939469088070984032020946667878072845200947381351087016524035417055791304445\
6015248381977825143422976]}, {0.31492922071456236`, 0.31492922071455615`}]], 
     {GrayLevel[0.825], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[
         284059274291958784502787875674066206703882972908997878554156475202325\
279540319407645292504826308102762745083583323543913875481759232333008035289855\
062191502437561991381187786943925207689065868310387622626991825061321849260659\
592551423948877874155412837444812712311821469033004552025901457414121178557995\
590274086245754231335178168161964218930978202799866632191062136046679484475716\
660702663913190025780411971624058249198459223332506187179964418006328721620216\
895152797001406294744208261937429596956492496602240730001952374126111096251363\
320441468513486724977371463112373042428653271263657792004002554187218625338141\
391748594650345901947482524181170536193039117352108172708797029637087760240099\
277077183575981381284061111113586824682210545914725667580510031817355748041266\
202304805353509028874743788667336847973223533272873067084327707815606502182557\
398590598636547897122875850235183059386895306123856389792251023986767566257287\
375249626268865368370483520924771275902767660200386289535502825620022411755701\
979671286523956019340706731083431197066497856254200488151981162342383301435153\
00249319905, 
          87700938918176685092457882324350775830979047140305562970698468681601\
712723938606534876854518822052284195950678142265083784598250616575863200844432\
121244879645034909776075415830886381757281307780685255686086944561924743240145\
167703680646236551126636157797025763747529838461278379940875180400147845486144\
708090975778800482659227319574973617367235238580368737771810662830981784359587\
134044913726283379352134725565592377505794817774341319400287603736926732596959\
408521902382535123915446735794536673138567835383405669352562076604497197823433\
095961129026456484910532711151781117741182478375545993553449807843102480705580\
056173141137563721482201876438760683411529587100521493423699232506824704769796\
122775287713921170166049278692375425064859544294353779872966040622360181201955\
087123872481965688440068031660946760515220271676117034141071276377363789720621\
819895589282539599124124560237508317142405906742587070304585057702687106018584\
345521638193164365339503751878880579098275632635820006572778668421107398214615\
244697340662990847693660004512115889606905058681273014619364074013484046495123\
631383773184], Rational[
         270900034229239210453664250992507620200205202240777015695314782248671\
859101322245251148834757168896557963723845880209522483983491180129632680339727\
345179396901444400388975632839142075519471241558628479103821652889933165338770\
927424460722579966225394105010438624976412241453143388005538441223987413838320\
933496104748884245527026529826905385813292094230795993785530014974951487778100\
742315767620537447704073380598838455913447972733709129744795166149117079130480\
086153423856370019894671682683856637174788464747672886514379966781933582684106\
053864453110702402819861250326108244071748619727036393843405089067755089181872\
060633902779909953349573430929129551882865360489324223365074569934679786239254\
467967599734750533890880451607093372085526938503920696191620730284982388858655\
031597661195901408966976883118881152296993871255044273707787809459571153671204\
626036134026884431307200059262827071610964050639449900638321237423690913039328\
948445659890240266323522373928844811126523720426914697895707595557383325096547\
755194380196586604656975542245001157128334595097265009921626383980442617085524\
93905, 83638132970978436558206446003294730978945777073197901697824925119020188\
068331343207241873282262851986118269613401665767464254618279052603913158828850\
979690213236722732615867453466779477387721806226020513617462694096320381302993\
491821905361701132427366063142551181344831906584148350596599960468144880432804\
194427279282076510646171164487473838076819019669282695589697676641258582675107\
998765684398059227118230405418756013674562239018744850432971703459484669646652\
719404585394977488943801683937714708869777091413182594835354427811811278756233\
178261782127842817814551498204343548948744178338998368692214816191178041057640\
240803849757882578088642538796122943429553127786153243731720454048828859134791\
159904207154436269807127659202027382716697973588733551946678755150014116244399\
188873750653923454349548016497383609028121639363321438857342126239576073285884\
757603914775466083645401227482144491582781546198911957345063879668336886009545\
823705857433667506698371771698550318027145992107397625712078496081732000937695\
214596426955077832851414215198411566643770867608084315647195828899427886127120\
384]}, {0.32389536280447434`, 0.32389536280447423`}], 0.03]}, InsetBox[
      StyleBox["800",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[
        2840592742919587845027878756740662067038829729089978785541564752023252\
795403194076452925048263081027627450835833235439138754817592323330080352898550\
621915024375619913811877869439252076890658683103876226269918250613218492606595\
925514239488778741554128374448127123118214690330045520259014574141211785579955\
902740862457542313351781681619642189309782027998666321910621360466794844757166\
607026639131900257804119716240582491984592233325061871799644180063287216202168\
951527970014062947442082619374295969564924966022407300019523741261110962513633\
204414685134867249773714631123730424286532712636577920040025541872186253381413\
917485946503459019474825241811705361930391173521081727087970296370877602400992\
770771835759813812840611111135868246822105459147256675805100318173557480412662\
023048053535090288747437886673368479732235332728730670843277078156065021825573\
985905986365478971228758502351830593868953061238563897922510239867675662572873\
752496262688653683704835209247712759027676602003862895355028256200224117557019\
796712865239560193407067310834311970664978562542004881519811623423833014351530\
0249319905, 
         877009389181766850924578823243507758309790471403055629706984686816017\
127239386065348768545188220522841959506781422650837845982506165758632008444321\
212448796450349097760754158308863817572813077806852556860869445619247432401451\
677036806462365511266361577970257637475298384612783799408751804001478454861447\
080909757788004826592273195749736173672352385803687377718106628309817843595871\
340449137262833793521347255655923775057948177743413194002876037369267325969594\
085219023825351239154467357945366731385678353834056693525620766044971978234330\
959611290264564849105327111517811177411824783755459935534498078431024807055800\
561731411375637214822018764387606834115295871005214934236992325068247047697961\
227752877139211701660492786923754250648595442943537798729660406223601812019550\
871238724819656884400680316609467605152202716761170341410712763773637897206218\
198955892825395991241245602375083171424059067425870703045850577026871060185843\
455216381931643653395037518788805790982756326358200065727786684211073982146152\
446973406629908476936600045121158896069050586812730146193640740134840464951236\
31383773184], Rational[
        2709000342292392104536642509925076202002052022407770156953147822486718\
591013222452511488347571688965579637238458802095224839834911801296326803397273\
451793969014444003889756328391420755194712415586284791038216528899331653387709\
274244607225799662253941050104386249764122414531433880055384412239874138383209\
334961047488842455270265298269053858132920942307959937855300149749514877781007\
423157676205374477040733805988384559134479727337091297447951661491170791304800\
861534238563700198946716826838566371747884647476728865143799667819335826841060\
538644531107024028198612503261082440717486197270363938434050890677550891818720\
606339027799099533495734309291295518828653604893242233650745699346797862392544\
679675997347505338908804516070933720855269385039206961916207302849823888586550\
315976611959014089669768831188811522969938712550442737077878094595711536712046\
260361340268844313072000592628270716109640506394499006383212374236909130393289\
484456598902402663235223739288448111265237204269146978957075955573833250965477\
551943801965866046569755422450011571283345950972650099216263839804426170855249\
3905, 836381329709784365582064460032947309789457770731979016978249251190201880\
683313432072418732822628519861182696134016657674642546182790526039131588288509\
796902132367227326158674534667794773877218062260205136174626940963203813029934\
918219053617011324273660631425511813448319065841483505965999604681448804328041\
944272792820765106461711644874738380768190196692826955896976766412585826751079\
987656843980592271182304054187560136745622390187448504329717034594846696466527\
194045853949774889438016839377147088697770914131825948353544278118112787562331\
782617821278428178145514982043435489487441783389983686922148161911780410576402\
408038497578825780886425387961229434295531277861532437317204540488288591347911\
599042071544362698071276592020273827166979735887335519466787551500141162443991\
888737506539234543495480164973836090281216393633214388573421262395760732858847\
576039147754660836454012274821444915827815461989119573450638796683368860095458\
237058574336675066983717716985503180271459921073976257120784960817320009376952\
145964269550778328514142151984115666437708676080843156471958288994278861271203\
84]}, {0.32389536280447434`, 0.32389536280447423`}]], 
     {GrayLevel[0.825], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[
         961726484138534336945970163430610776006143085868934292218736300607930\
691982646997248527664987386128008441803389677412607241872048737468425177567823\
648709460091756203344058550962236498751279021517040679429361448390714286231925\
363651756976982867979047818854306624924226282685684216017869450059916162144700\
657464266295486493785590920977557603352660643369874321210099779875882353710589\
288733875535062366430791997762861371632401304382729646574694946703410714307447\
076424811551262245375135720391257387968048198451511818300568309942231343340338\
051622147683431328908337190214803866199109003276344725022739455638564242884662\
672297188448830623328903581869926018895915932732467297678288558561865426042999\
126823544241452348380648577534287266759642136442618864321244706705772084974831\
675964848020748466319651463090096719718026107583230733837722333973093936418334\
446776623421381797575736209038293266163090732898606105357421409554068544330431\
238331890196102136707794830163219388674666033960897766184968986116650387528477\
989743777342258735335073113933757301133602052128439303081350577097055933987635\
710191612393235287359959644443306942492375568196235795045596493968337114310612\
66414999625222106895248604136204540359524855230192315493293440337339361, 
          26109722035328812667293817767915609564499106226184594509605837082098\
847699288936421220670298374938958522252667860981570949689335954644840181580902\
196284131948648924413592749958509039753359592957860701750296398655659407970984\
942818641808367108614665437420197717645092601782101218502965227861699444589950\
725167173474422044694648672640754756523514989486335820586732575667411076475625\
399309996692855388542345888997132287157955947860862418352195296815987411877504\
726033725210426541877341708346263775824302206738769249590409235298325380344920\
645929702295841418780532962321159203138755649957510308619621564891862304865425\
595162647831140270643295884502190215552570856754942455057829225441950166879887\
126998040910484257134378119600372678978386499569762834990288794856777670778352\
264606822106994788871244573858088362926630581726534872649692325053074084892194\
571973711015400185323641872995576264291059428870408034515776147572903423167708\
571411018261197499297544536644086830596256681326497494899902269986730044365620\
442961246686391481254458226761827985829138770189205546164293659332422122820488\
007936425061023165422771853709626960298245113074546433474441202578152147575032\
5603366797431668304122877782900730195434508359022560951177085100788547584], 
         Rational[
         917173847330602965607023148209711420257046832124619608435144507612425\
411049259143625392726328231758506630187338529572955916402188606442478428765889\
493783312737694200083732588752698572811272581310232379348947939627845211076274\
838310346901285420113935609938048119264765402815689000504096770342416599363401\
817649914691012788877679192322367362649069304404332430683439909129342157158501\
696233746237038131644667787582783065995892348543884451587918141405554189301371\
688275949962815302752175070133729503858283511823248623751321107254007002571069\
658784314289699682449675719555384741204535219181571880642515633691101125899440\
175578662473436810621064307713939465748086686097059917422692278749941604881014\
808707473699467372434190177729827256335868214211300614555661384780162769383657\
099683001043428596243156838817036798025523493528650530849536450712906856154544\
087755285169799999653021686201318109186191696881007357719486522245381586429202\
428334053950479445112744490339639015243006315880266536174751799640508862675013\
496990881177387487303465253067161342461605813002878124076881756974012239628356\
617555491052287516610235770889581326714642733697355692630780882523040211645215\
90184144086515991247366711285983524555122391730479624446339278161, 
          24900171313599407832425897376933679165362459398445696363073193628405\
425738610207005711241052985133131525280635701161929082574211077351417714672949\
024471408795021938718407392462262191537246315915928556204124830871257217379555\
647677079971663578619637906475255696911900140554524630072560527669619984235716\
557662175630971951193474457398180729411616315351806469523174834887896610713601\
493177410786490810911508454320080077321964214192259233810611054244983112218384\
481462216577936689259854992243064666580488402117509126272591815279317264885826\
726846411033479136257679903336676791323428773839483555431005062953817658296037\
287867210227146406787200817587080207398005348925535636003331399385404745941054\
465292015943989045271280402756092719057451724595797381391800684792306586054184\
212309667689318455573315214021767008711462575651678917550747227719377598659700\
939153395667457757304803727145744575778064183111579927936340472767737792175015\
040789621602246760652107750553213911625153237654206747913267393099527401319141\
810380217253104668859918810617282853917254228772359415211003932316228983707893\
379150795994780698225757459363581619547124016832872804140511705949928424429924\
5456091687614124588129880698109369464334972723982392264535031414784]}, {
        0.3683403763690902, 0.3683403763690902}], 0.03]}, InsetBox[
      StyleBox["900",
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[
        9617264841385343369459701634306107760061430858689342922187363006079306\
919826469972485276649873861280084418033896774126072418720487374684251775678236\
487094600917562033440585509622364987512790215170406794293614483907142862319253\
636517569769828679790478188543066249242262826856842160178694500599161621447006\
574642662954864937855909209775576033526606433698743212100997798758823537105892\
887338755350623664307919977628613716324013043827296465746949467034107143074470\
764248115512622453751357203912573879680481984515118183005683099422313433403380\
516221476834313289083371902148038661991090032763447250227394556385642428846626\
722971884488306233289035818699260188959159327324672976782885585618654260429991\
268235442414523483806485775342872667596421364426188643212447067057720849748316\
759648480207484663196514630900967197180261075832307338377223339730939364183344\
467766234213817975757362090382932661630907328986061053574214095540685443304312\
383318901961021367077948301632193886746660339608977661849689861166503875284779\
897437773422587353350731139337573011336020521284393030813505770970559339876357\
101916123932352873599596444433069424923755681962357950455964939683371143106126\
6414999625222106895248604136204540359524855230192315493293440337339361, 
         261097220353288126672938177679156095644991062261845945096058370820988\
476992889364212206702983749389585222526678609815709496893359546448401815809021\
962841319486489244135927499585090397533595929578607017502963986556594079709849\
428186418083671086146654374201977176450926017821012185029652278616994445899507\
251671734744220446946486726407547565235149894863358205867325756674110764756253\
993099966928553885423458889971322871579559478608624183521952968159874118775047\
260337252104265418773417083462637758243022067387692495904092352983253803449206\
459297022958414187805329623211592031387556499575103086196215648918623048654255\
951626478311402706432958845021902155525708567549424550578292254419501668798871\
269980409104842571343781196003726789783864995697628349902887948567776707783522\
646068221069947888712445738580883629266305817265348726496923250530740848921945\
719737110154001853236418729955762642910594288704080345157761475729034231677085\
714110182611974992975445366440868305962566813264974948999022699867300443656204\
429612466863914812544582267618279858291387701892055461642936593324221228204880\
079364250610231654227718537096269602982451130745464334744412025781521475750325\
603366797431668304122877782900730195434508359022560951177085100788547584], 
        Rational[
        9171738473306029656070231482097114202570468321246196084351445076124254\
110492591436253927263282317585066301873385295729559164021886064424784287658894\
937833127376942000837325887526985728112725813102323793489479396278452110762748\
383103469012854201139356099380481192647654028156890005040967703424165993634018\
176499146910127888776791923223673626490693044043324306834399091293421571585016\
962337462370381316446677875827830659958923485438844515879181414055541893013716\
882759499628153027521750701337295038582835118232486237513211072540070025710696\
587843142896996824496757195553847412045352191815718806425156336911011258994401\
755786624734368106210643077139394657480866860970599174226922787499416048810148\
087074736994673724341901777298272563358682142113006145556613847801627693836570\
996830010434285962431568388170367980255234935286505308495364507129068561545440\
877552851697999996530216862013181091861916968810073577194865222453815864292024\
283340539504794451127444903396390152430063158802665361747517996405088626750134\
969908811773874873034652530671613424616058130028781240768817569740122396283566\
175554910522875166102357708895813267146427336973556926307808825230402116452159\
0184144086515991247366711285983524555122391730479624446339278161, 
         249001713135994078324258973769336791653624593984456963630731936284054\
257386102070057112410529851331315252806357011619290825742110773514177146729490\
244714087950219387184073924622621915372463159159285562041248308712572173795556\
476770799716635786196379064752556969119001405545246300725605276696199842357165\
576621756309719511934744573981807294116163153518064695231748348878966107136014\
931774107864908109115084543200800773219642141922592338106110542449831122183844\
814622165779366892598549922430646665804884021175091262725918152793172648858267\
268464110334791362576799033366767913234287738394835554310050629538176582960372\
878672102271464067872008175870802073980053489255356360033313993854047459410544\
652920159439890452712804027560927190574517245957973813918006847923065860541842\
123096676893184555733152140217670087114625756516789175507472277193775986597009\
391533956674577573048037271457445757780641831115799279363404727677377921750150\
407896216022467606521077505532139116251532376542067479132673930995274013191418\
103802172531046688599188106172828539172542287723594152110039323162289837078933\
791507959947806982257574593635816195471240168328728041405117059499284244299245\
456091687614124588129880698109369464334972723982392264535031414784]}, {
       0.3683403763690902, 0.3683403763690902}]], 
     {GrayLevel[1.], EdgeForm[Thickness[Large]], 
      DiskBox[NCache[{
        Rational[
         472506323851370505105375763270134888243204152058203443213621846528546\
749059566804219342217828382995948401407712827835779429237693387592022576884383\
828048207594311658436083918420948932918161211717023072408605470331639808601018\
425548264039060730604677812610242305513334252473373660454021360168365029860117\
508685592049939502726330598916288445040963729658748299213563038210544827719186\
182994374068503828924144729989071765359878080930885899561380471815941229988340\
833745242437683864896799381596867890109092263953009745297714584840561401159961\
889385898080761550253524923878504298930760977960287139059565542174944062453244\
709803179824666090595140350771653751600620213379255738489603682331339512810408\
681072259801048008090825025651083762077650119859052439060860542578409603035874\
130710549638067102494757519946644343746648876144223867285666012143796934947899\
901944394730431160216704498247839933073451319634026898265282748135337358070419\
573519068411611810753740422946371402285911365380899952963473622966740044400016\
321782022111006198114486654544362822977197531607886651613380670419764213490146\
124126592742695682544644724213616959272968318812969855693843254164326739890155\
239865703699901809575897363436133712650051563751952649408602217741976960393761\
158992404305753548354964158561837557490493638366265799245373144581653510789459\
7560364720645352311596628817482440834077882013482305, 
          12145636515757626152641015942934914183306135689834766664034914621066\
143716596133932945145202411051808655092363969934023048479052111565019111529119\
378387845739923535593655184092482134672090830279019490849291306847720070837589\
830083229438417164066912246566233438174537835752821001925139627363595193221504\
839238303799208474810252732704269661512773211578756328602878425920089532009571\
084344918106051206067060935176568371567662653009325613802597135319373967195570\
692930994255391136769744252838134874844654289212625647043243826646056440241693\
058499978000654473834201568963391102273149683530946631563511732859302874630111\
790835444565277481075766745598661455202265626442357037040601830164129838532411\
661488244574135448048658823208671298981521582888773240327136963602031476604224\
343726891611974341404369548873236495023027928894340996277444130035793643150482\
043572995767639269605111802525241679612537062759620824296276452100044933319573\
432695276106050639141786485398181069350917160487280410506642409324150861914556\
768456682514713292110381940051167347154329016111805694768410505904326238077584\
128204904206284730682617078797501893404713313365156446046216339400501252047373\
028797898962307183394596795639356427134329960850486604803955538717893889291579\
530766600794682211132368949236385456990068017428331661913736730161891180672040\
723446682911005144473853542730500346487817744370630656], Rational[
         450617145396585946176662874624210577619170113713570457653754204819902\
279926957977739586413441032543159134630221275106499888366276155637770405926146\
979741321629822017274163298585876534676501998800894902887985801073358700419472\
111230309553237540648130098732258348378009593529279726710345774058126103743702\
933745136732375745603258964747790288089566233613827385687154237948442892843786\
342613297740969624294732193160006195196332783617245733974784386442238541121302\
672515206197912773541041878415501573495845882309731847614270994794222551568863\
841421047733597385402022687072472841845348119436521673641315297008440746936779\
549683909561870386606550746643434071870608100239937248918846999831497193189530\
878689131229138284788814090560059573090814681558786177897212502744225420770220\
689875807441298881120310564679393815560995575631046268052146248785653148981069\
231782901915513592455220197697339860137648589122176294116033877187478927369890\
941113454024311206395005707727113433820464867783527720510336682607343286338252\
621323065659457277420687709672717523752613635332670290818410494000060912638173\
066525834049558937166329446858049192756248036201930539030013370130044170527461\
578712835964120920378879252085615194414786201945421255885185678647914733773834\
981735007955233666036032181300452704771539363232417033914114398575764565590654\
6721865115166066215734271438994759425926576305, 
          11582981601483942177430168097433962043100486459574476875338472958627\
837864490636761613030626689006622939197887391981146858672191726269740211037749\
651325078716205154031424697964174399063196974066752901887217814300270148122396\
307070950926224865023529287878259123014962993386097909855975749362559502812867\
011297515677650904474499447540540372383855067805057839014891076965417415628024\
181694906335879522387562689949577685897505429276776899149510512656568495936937\
992983812575713288087600949133047938198713578426957747500652147909218254319851\
931095102310804818948937958682433225892209704905459052623283131465247034673797\
407947010579373818469778771971379714205041529123646771469690160907869185001765\
882004017423758934067400763710662173253556807411931267096650088884383656124328\
941084758388494817165727185128437514327075890440312382008976106677812235975725\
215504642264975804905998041653863601315056860694523643776203586673779424018453\
056998516183901442662989125631505078650395546424179468638079079937125074305111\
664253885760033886061078968096892687944726005660825438278589731125189054563125\
732617286878857355768792227551938908962930024495274015470711078072072269484875\
706479929888064559359165950431209971556024514055716137699084795682805909434871\
226088143152887545711869191395173508634632127216655408776985864793673687622109\
149405177031521934961179297190189692008798355456]}, {0.3890338091695281, 
        0.3890338091695281}], 0.03]}, InsetBox[
      StyleBox[
       TagBox[
        SuperscriptBox[
         TagBox["10",
          Power,
          Editable->True,
          Selectable->True], 
         TagBox["3",
          Power,
          Editable->True,
          Selectable->True]],
        InterpretTemplate[Superscript[#, #2]& ],
        Editable->False,
        Selectable->False],
       StripOnInput->False,
       FrontFaceColor->GrayLevel[0],
       BackFaceColor->GrayLevel[0],
       GraphicsColor->GrayLevel[0],
       FontFamily->"Times",
       FontSize->16,
       FontWeight->Bold,
       FontColor->GrayLevel[0]], 
      NCache[{Rational[
        4725063238513705051053757632701348882432041520582034432136218465285467\
490595668042193422178283829959484014077128278357794292376933875920225768843838\
280482075943116584360839184209489329181612117170230724086054703316398086010184\
255482640390607306046778126102423055133342524733736604540213601683650298601175\
086855920499395027263305989162884450409637296587482992135630382105448277191861\
829943740685038289241447299890717653598780809308858995613804718159412299883408\
337452424376838648967993815968678901090922639530097452977145848405614011599618\
893858980807615502535249238785042989307609779602871390595655421749440624532447\
098031798246660905951403507716537516006202133792557384896036823313395128104086\
810722598010480080908250256510837620776501198590524390608605425784096030358741\
307105496380671024947575199466443437466488761442238672856660121437969349478999\
019443947304311602167044982478399330734513196340268982652827481353373580704195\
735190684116118107537404229463714022859113653808999529634736229667400444000163\
217820221110061981144866545443628229771975316078866516133806704197642134901461\
241265927426956825446447242136169592729683188129698556938432541643267398901552\
398657036999018095758973634361337126500515637519526494086022177419769603937611\
589924043057535483549641585618375574904936383662657992453731445816535107894597\
560364720645352311596628817482440834077882013482305, 
         121456365157576261526410159429349141833061356898347666640349146210661\
437165961339329451452024110518086550923639699340230484790521115650191115291193\
783878457399235355936551840924821346720908302790194908492913068477200708375898\
300832294384171640669122465662334381745378357528210019251396273635951932215048\
392383037992084748102527327042696615127732115787563286028784259200895320095710\
843449181060512060670609351765683715676626530093256138025971353193739671955706\
929309942553911367697442528381348748446542892126256470432438266460564402416930\
584999780006544738342015689633911022731496835309466315635117328593028746301117\
908354445652774810757667455986614552022656264423570370406018301641298385324116\
614882445741354480486588232086712989815215828887732403271369636020314766042243\
437268916119743414043695488732364950230279288943409962774441300357936431504820\
435729957676392696051118025252416796125370627596208242962764521000449333195734\
326952761060506391417864853981810693509171604872804105066424093241508619145567\
684566825147132921103819400511673471543290161118056947684105059043262380775841\
282049042062847306826170787975018934047133133651564460462163394005012520473730\
287978989623071833945967956393564271343299608504866048039555387178938892915795\
307666007946822111323689492363854569900680174283316619137367301618911806720407\
23446682911005144473853542730500346487817744370630656], Rational[
        4506171453965859461766628746242105776191701137135704576537542048199022\
799269579777395864134410325431591346302212751064998883662761556377704059261469\
797413216298220172741632985858765346765019988008949028879858010733587004194721\
112303095532375406481300987322583483780095935292797267103457740581261037437029\
337451367323757456032589647477902880895662336138273856871542379484428928437863\
426132977409696242947321931600061951963327836172457339747843864422385411213026\
725152061979127735410418784155015734958458823097318476142709947942225515688638\
414210477335973854020226870724728418453481194365216736413152970084407469367795\
496839095618703866065507466434340718706081002399372489188469998314971931895308\
786891312291382847888140905600595730908146815587861778972125027442254207702206\
898758074412988811203105646793938155609955756310462680521462487856531489810692\
317829019155135924552201976973398601376485891221762941160338771874789273698909\
411134540243112063950057077271134338204648677835277205103366826073432863382526\
213230656594572774206877096727175237526136353326702908184104940000609126381730\
665258340495589371663294468580491927562480362019305390300133701300441705274615\
787128359641209203788792520856151944147862019454212558851856786479147337738349\
817350079552336660360321813004527047715393632324170339141143985757645655906546\
721865115166066215734271438994759425926576305, 
         115829816014839421774301680974339620431004864595744768753384729586278\
378644906367616130306266890066229391978873919811468586721917262697402110377496\
513250787162051540314246979641743990631969740667529018872178143002701481223963\
070709509262248650235292878782591230149629933860979098559757493625595028128670\
112975156776509044744994475405403723838550678050578390148910769654174156280241\
816949063358795223875626899495776858975054292767768991495105126565684959369379\
929838125757132880876009491330479381987135784269577475006521479092182543198519\
310951023108048189489379586824332258922097049054590526232831314652470346737974\
079470105793738184697787719713797142050415291236467714696901609078691850017658\
820040174237589340674007637106621732535568074119312670966500888843836561243289\
410847583884948171657271851284375143270758904403123820089761066778122359757252\
155046422649758049059980416538636013150568606945236437762035866737794240184530\
569985161839014426629891256315050786503955464241794686380790799371250743051116\
642538857600338860610789680968926879447260056608254382785897311251890545631257\
326172868788573557687922275519389089629300244952740154707110780720722694848757\
064799298880645593591659504312099715560245140557161376990847956828059094348712\
260881431528875457118691913951735086346321272166554087769858647936736876221091\
49405177031521934961179297190189692008798355456]}, {0.3890338091695281, 
       0.3890338091695281}]]}}},
  AspectRatio->1,
  BaseStyle->Directive[FontFamily -> "Times", FontSize -> 20],
  Frame->True,
  FrameLabel->{{
     FormBox[
      InterpretationBox[
       Cell[
        BoxData[
         FormBox[
          StyleBox[
          "\"Probability of Cooperating, Player1\"", FontSize -> 26, 
           FontFamily -> "Times", StripOnInput -> False], TraditionalForm]], 
        "Text", "TR"], 
       Text[
        Style[
        "Probability of Cooperating, Player1", FontSize -> 26, FontFamily -> 
         "Times"]]], TraditionalForm], None}, {
     FormBox[
      InterpretationBox[
       Cell[
        BoxData[
         FormBox[
          StyleBox[
          "\"Probability of Cooperating, Player2\"", FontSize -> 26, 
           FontFamily -> "Times", StripOnInput -> False], TraditionalForm]], 
        "Text", "TR"], 
       Text[
        Style[
        "Probability of Cooperating, Player2", FontSize -> 26, FontFamily -> 
         "Times"]]], TraditionalForm], None}},
  FrameStyle->Thickness[Large],
  FrameTicks->{{{{0, 
       FormBox["\" 0 \"", TraditionalForm], 0.02}, {0.2, 
       FormBox["\" 0.2 \"", TraditionalForm], 0.02}, {0.4, 
       FormBox["\" 0.4 \"", TraditionalForm], 0.02}, {0.6, 
       FormBox["\" 0.6 \"", TraditionalForm], 0.02}, {0.8, 
       FormBox["\" 0.8 \"", TraditionalForm], 0.02}, {1, 
       FormBox["\" 1 \"", TraditionalForm], 0.02}}, None}, {{{0, 
       FormBox["0", TraditionalForm], 0.02}, {0.2, 
       FormBox["0.2`", TraditionalForm], 0.02}, {0.4, 
       FormBox["0.4`", TraditionalForm], 0.02}, {0.6, 
       FormBox["0.6`", TraditionalForm], 0.02}, {0.8, 
       FormBox["0.8`", TraditionalForm], 0.02}, {1, 
       FormBox["1", TraditionalForm], 0.02}}, None}},
  FrameTicksStyle->Thickness[Large],
  ImageSize->{703., Automatic},
  PlotRange->{{-0.04, 1.04}, {-0.04, 1.04}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.392777606640625*^9, 3.392777638609375*^9, 3.392777698265625*^9, {
   3.39277777125*^9, 3.392777825125*^9}, 3.392855044703125*^9, 
   3.3928552813125*^9, 3.392855404328125*^9, 3.39285544228125*^9, 
   3.39285549921875*^9, 3.392856978609375*^9, {3.392857069359375*^9, 
   3.392857093125*^9}, 3.392859517609375*^9, 3.392859777625*^9, 
   3.392860168046875*^9, {3.3928602115625*^9, 3.3928602308125*^9}, 
   3.392860291671875*^9, 3.392860633234375*^9, 3.3928636300625*^9, 
   3.392863720625*^9, 3.392863767703125*^9, 3.392868790203125*^9, {
   3.392868856875*^9, 3.392868898921875*^9}, 3.392869205046875*^9, 
   3.392869681921875*^9, {3.3933077139375*^9, 3.393307759671875*^9}, 
   3.393307859546875*^9, 3.393309673953125*^9, 3.3933097405*^9, 
   3.393367292734375*^9, 3.393367423875*^9, {3.393367461671875*^9, 
   3.393367477515625*^9}, {3.393367647078125*^9, 3.3933676843125*^9}, {
   3.39336781121875*^9, 3.393367881375*^9}, {3.39336799065625*^9, 
   3.39336800090625*^9}, 3.393368160921875*^9, 3.39336820884375*^9, 
   3.393368260046875*^9, 3.393368300296875*^9, {3.393368333703125*^9, 
   3.393368348515625*^9}, {3.39336839353125*^9, 3.393368397796875*^9}, {
   3.393368435109375*^9, 3.39336849796875*^9}, 3.393368777703125*^9, {
   3.393368857375*^9, 3.39336897275*^9}, 3.393369011625*^9, {
   3.39336904196875*^9, 3.39336908425*^9}, {3.393369129203125*^9, 
   3.393369135828125*^9}, {3.393369277109375*^9, 3.393369295234375*^9}, 
   3.39336956675*^9, 3.393385192703125*^9, 3.3933852555*^9, 
   3.393407922515625*^9, 3.393448541703125*^9, 3.393448611234375*^9, 
   3.393471411578125*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Figure - Saving to file", "Section"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"numberOfExtensions", "=", "  ", 
    RowBox[{"Length", "[", "extensions", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"j", "=", "1"}], ",", " ", 
    RowBox[{"j", "\[LessEqual]", "numberOfExtensions"}], ",", 
    RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Export", "[", 
      RowBox[{
       RowBox[{"StringJoin", "[", 
        RowBox[{"\"\<fig2\>\"", ",", 
         RowBox[{"extensions", "[", 
          RowBox[{"[", "j", "]"}], "]"}]}], "]"}], ",", "gFigure", ",", 
       RowBox[{"ImageSize", "\[Rule]", 
        RowBox[{"{", "figureSize", "}"}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Export", "[", 
      RowBox[{
       RowBox[{"StringJoin", "[", 
        RowBox[{"\"\<fig2-legend\>\"", ",", 
         RowBox[{"extensions", "[", 
          RowBox[{"[", "j", "]"}], "]"}]}], "]"}], ",", "myLegend", ",", 
       RowBox[{"ImageSize", "\[Rule]", " ", 
        RowBox[{"{", 
         RowBox[{"figureSize", "/", "2"}], "}"}]}]}], "]"}], ";"}]}], 
   "\[IndentingNewLine]", "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.3927586769375*^9, 3.392758688484375*^9}, {
   3.3927592378125*^9, 3.3927592385*^9}, {3.392759381578125*^9, 
   3.39275939021875*^9}, {3.39275943190625*^9, 3.3927594331875*^9}, {
   3.3927595433125*^9, 3.3927595620625*^9}, {3.392759641953125*^9, 
   3.39275971225*^9}, {3.39275974796875*^9, 3.3927598060625*^9}, {
   3.392759892609375*^9, 3.392759892984375*^9}, {3.392759983203125*^9, 
   3.392760003234375*^9}, {3.392760053984375*^9, 3.392760073734375*^9}, {
   3.392760146625*^9, 3.392760194484375*^9}, {3.39276023546875*^9, 
   3.3927602358125*^9}, {3.392760511796875*^9, 3.392760512796875*^9}, {
   3.39276069621875*^9, 3.392760696453125*^9}, {3.39276156046875*^9, 
   3.392761561390625*^9}, {3.3927631243125*^9, 3.392763155984375*^9}, 
   3.3927631870625*^9, {3.392763245265625*^9, 3.392763267328125*^9}, {
   3.39276351321875*^9, 3.392763513734375*^9}, {3.392764418703125*^9, 
   3.392764439859375*^9}, {3.39276453215625*^9, 3.392764557671875*^9}, {
   3.392860613421875*^9, 3.392860624828125*^9}, {3.3928606578125*^9, 
   3.392860657984375*^9}, {3.3928687808125*^9, 3.3928687825*^9}, {
   3.393369280875*^9, 3.393369290875*^9}, {3.393448529734375*^9, 
   3.39344853384375*^9}}]
}, Closed]]
},
CellGrouping->Manual,
WindowSize->{1432, 790},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (June 19, 2007)",
StyleDefinitions->"DemoText.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 277, 6, 56, "Title"],
Cell[848, 29, 65, 0, 37, "Subtitle"],
Cell[916, 31, 714, 13, 90, "Subsubtitle"],
Cell[CellGroupData[{
Cell[1655, 48, 57, 0, 52, "Section"],
Cell[1715, 50, 779, 17, 70, "Subsubtitle"]
}, Closed]],
Cell[CellGroupData[{
Cell[2531, 72, 42, 0, 32, "Section"],
Cell[2576, 74, 156, 3, 38, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[2769, 82, 29, 0, 32, "Section"],
Cell[2801, 84, 3493, 81, 659, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[6331, 170, 53, 0, 32, "Section"],
Cell[6387, 172, 9634, 256, 839, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[16058, 433, 65, 0, 32, "Section"],
Cell[16126, 435, 201, 6, 59, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[16364, 446, 59, 0, 32, "Section"],
Cell[CellGroupData[{
Cell[16448, 450, 3613, 93, 361, "Input"],
Cell[20064, 545, 82819, 1798, 297, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[102932, 2349, 46, 0, 32, "Section"],
Cell[102981, 2351, 923, 25, 179, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[103941, 2381, 41, 0, 32, "Section"],
Cell[CellGroupData[{
Cell[104007, 2385, 12609, 293, 1151, "Input"],
Cell[116619, 2680, 84269, 1344, 597, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[200937, 4030, 36, 0, 32, "Section"],
Cell[CellGroupData[{
Cell[200998, 4034, 14326, 289, 399, "Input"],
Cell[215327, 4325, 191459, 3507, 722, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[406835, 7838, 42, 0, 32, "Section"],
Cell[406880, 7840, 2389, 49, 139, "Input"]
}, Closed]]
}
]
*)

(* End of internal cache information *)
